@@ -1,4 +1,4 @@
-<?php # $Id: comments.inc.php 2109 2008-02-10 10:01:32Z brockhaus $
+<?php # $Id: comments.inc.php 2362 2008-10-23 13:50:54Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -167,6 +167,11 @@ if (isset($serendipity['GET']['adminAction']) && ($serendipity['GET']['adminActi
         }
     }
 
+    if (!empty($data['url']) && substr($data['url'], 0, 7) != 'http://' &&
+         substr($data['url'], 0, 8) != 'https://') {
+         $data['url'] = 'http://' . $data['url'];
+    }
+                                
     serendipity_displayCommentForm(
       $serendipity['GET']['entry_id'],
       $target_url,
@@ -415,6 +420,12 @@ foreach ($sql as $rs) {
         $class .= ' serendipity_admin_comment_pending'; 
     }
     $header_class = ($comment['status'] == 'pending' ? 'serendipityAdminMsgNote serendipity_admin_comment_pending_header' : '');
+
+    if (!empty($comment['url']) && substr($comment['url'], 0, 7) != 'http://' &&
+         substr($comment['url'], 0, 8) != 'https://') {
+         $comment['url'] = 'http://' . $comment['url'];
+    }
+                                
 ?>
 <tr>
     <td class="<?php echo $header_class; ?>">
