@@ -1,4 +1,4 @@
-<?php # $Id: entries.inc.php 2103 2008-02-02 11:05:35Z garvinhicking $
+<?php # $Id: entries.inc.php 2383 2008-11-25 19:57:49Z slothman $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -282,7 +282,7 @@ function serendipity_drawList() {
 
                         </td>
                         <td align="right">
-                            <?php if (serendipity_db_bool($entry['isdraft'])) { ?>
+                            <?php if (serendipity_db_bool($entry['isdraft']) || (!$serendipity['showFutureEntries'] && $entry['timestamp'] >= serendipity_serverOffsetHour())) { ?>
                             <a target="_blank" href="<?php echo $entry['preview_link']; ?>" title="<?php echo PREVIEW . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo PREVIEW; ?>" /><?php echo PREVIEW ?></a>
                             <?php } else { ?>
                             <a target="_blank" href="<?php echo $entry['link']; ?>" title="<?php echo VIEW . ' #' . $entry['id']; ?>" class="serendipityIconLink"><img src="<?php echo serendipity_getTemplateFile('admin/img/zoom.png'); ?>" alt="<?php echo VIEW; ?>" /><?php echo VIEW ?></a>
@@ -378,7 +378,9 @@ switch($serendipity['GET']['adminAction']) {
                        'isdraft'            => $serendipity['POST']['isdraft'],
                        'allow_comments'     => $serendipity['POST']['allow_comments'],
                        'moderate_comments'  => $serendipity['POST']['moderate_comments'],
-                       'exflag'             => (!empty($serendipity['POST']['extended']) ? true : false)
+                       'exflag'             => (!empty($serendipity['POST']['extended']) ? true : false),
+                       // Messing with other attributes causes problems when entry is saved
+
             );
         }
 
@@ -428,6 +430,11 @@ switch($serendipity['GET']['adminAction']) {
             } else {
                 // Only display the preview
                 $serendipity['hidefooter'] = true;
+                // Advanced templates use this to show update status and elapsed time
+                if (!is_numeric($entry['last_modified'])) {
+                    $entry['last_modified'] = time();
+                }
+
                 if (!is_numeric($entry['timestamp'])) {
                     $entry['timestamp']  = time();
                 }
