@@ -1,4 +1,4 @@
-<?php # $Id: generic.inc.php 1994 2007-10-23 13:56:12Z garvinhicking $
+<?php # $Id: generic.inc.php 2289 2008-06-30 09:41:07Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -316,7 +316,7 @@ class Serendipity_Import_Generic extends Serendipity_Import {
     function import() {
         global $serendipity;
 
-        if ($this->data['wpxrss']) {
+        if (serendipity_db_bool($this->data['wpxrss'])) {
             return $this->import_wpxrss();
         }
 
