@@ -1,4 +1,4 @@
-<?php # $Id: installer.inc.php 2100 2008-02-01 14:10:14Z garvinhicking $
+<?php # $Id: installer.inc.php 2328 2008-08-29 07:54:02Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -37,14 +37,14 @@ if (defined('S9Y_DATA_PATH')) {
 function serendipity_installerResultDiagnose($result, $s) {
     global $errorCount;
     if ( $result === S9Y_I_SUCCESS ) {
-        return '<span style="color: green; font-weight: bold">'. $s .'</span>';
+        return '<span class="serendipityAdminMsgSuccessInstall" style="color: green; font-weight: bold">'. $s .'</span>';
     }
     if ( $result === S9Y_I_WARNING ) {
-        return '<span style="color: orange; font-weight: bold">'. $s .' [?]</span>';
+        return '<span class="serendipityAdminMsgWarningInstall" style="color: orange; font-weight: bold">'. $s .' [?]</span>';
     }
     if ( $result === S9Y_I_ERROR ) {
         $errorCount++;
-        return '<span style="color: red; font-weight: bold">'. $s .' [!]</span>';
+        return '<span class="serendipityAdminMsgErrorInstall" style="color: red; font-weight: bold">'. $s .' [!]</span>';
     }
 }
 
@@ -95,6 +95,31 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
 
 <?php $errorCount = 0 ?>
 <div align="center">
+<table class="serendipity_admin_list_item serendipity_admin_list_item_even" width="90%" align="center">
+    <tr>
+        <td colspan="2" style="font-weight: bold"><?php echo INTEGRITY ?></td>
+    </tr>
+<?php if (is_readable(S9Y_INCLUDE_PATH . 'checksums.inc.php')) {
+    $badsums = serendipity_verifyFTPChecksums();
+?>
+    <?php if (empty($badsums)) {?>
+    <tr>
+      <td colspan="2"><?php echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, CHECKSUMS_PASS); ?></td>
+    </tr>
+    <?php } else { 
+        foreach ($badsums as $file => $sum) {
+?>
+    <tr>
+      <td colspan="2"><?php echo serendipity_installerResultDiagnose(S9Y_I_WARNING, sprintf(CHECKSUM_FAILED, $file)); ?></td>
+    </tr>
+    <?php } 
+    }
+} else { ?>
+    <tr>
+      <td colspan="2"><?php echo serendipity_installerResultDiagnose(S9Y_I_WARNING, CHECKSUMS_NOT_FOUND); ?></td>
+    </tr>
+<?php } ?>
+</table>
 <table class="serendipity_admin_list_item serendipity_admin_list_item_even" width="90%" align="center">
     <tr>
         <td colspan="2" style="font-weight: bold"><?php echo PHP_INSTALLATION ?></td>
@@ -318,6 +343,18 @@ if ( (int)$serendipity['GET']['step'] == 0 ) {
             }
      ?></td>
     </tr>
+    <tr>
+      <td>memory_limit</td>
+      <td width="150"><strong><?php echo (PHP_INT_SIZE == 4 ? '8M' : '16M'); ?></strong></td>
+      <td width="150"><?php
+            if ( serendipity_ini_bytesize(ini_get('memory_limit')) >= ((PHP_INT_SIZE == 4 ? 8 : 16)*1024*1024) ) {
+                echo serendipity_installerResultDiagnose(S9Y_I_SUCCESS, ini_get('memory_limit'));
+            } else {
+                echo serendipity_installerResultDiagnose(S9Y_I_WARNING, ini_get('memory_limit'));
+            }
+     ?></td>
+    </tr>
+
 </table>
 
 <br />
