@@ -1,4 +1,4 @@
-<?php # $Id: postgres.inc.php 1178 2006-05-01 13:53:40Z garvinhicking $
+<?php # $Id: postgres.inc.php 1786 2007-07-17 11:31:20Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -279,7 +279,7 @@ function serendipity_db_schema_import($query) {
     }
 
     $query = trim(str_replace($search, $replace, $query));
-    if ($query{0} == '@') {
+    if ($query[0] == '@') {
         // Errors are expected to happen (like duplicate index creation)
         return serendipity_db_query(substr($query, 1), false, 'both', false, false, false, true);
     } else {
