@@ -1,4 +1,4 @@
-<?php # $Id: sqlite.inc.php 1786 2007-07-17 11:31:20Z garvinhicking $
+<?php # $Id: sqlite.inc.php 2327 2008-08-29 07:10:31Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -51,7 +51,11 @@ function serendipity_db_connect()
     }
 
 
-    $serendipity['dbConn'] = $function($serendipity['serendipityPath'] . $serendipity['dbName'] . '.db');
+    if (defined('S9Y_DATA_PATH')) {
+        $serendipity['dbConn'] = $function(S9Y_DATA_PATH . $serendipity['dbName'] . '.db');
+    } else {
+        $serendipity['dbConn'] = $function($serendipity['dbName'] . '.db');
+    }
 
     return $serendipity['dbConn'];
 }
