@@ -1,4 +1,4 @@
-<?php # $Id: functions.inc.php 2213 2008-04-10 15:35:29Z donchambers $
+<?php # $Id: functions.inc.php 2363 2008-10-28 12:32:30Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -533,7 +533,15 @@ function serendipity_sendMail($to, $subject, $message, $fromMail, $headers = NUL
         }
     }
 
-    return mail($maildata['to'], $maildata['subject'], $maildata['message'], implode("\n", $maildata['headers']));
+    if ($serendipity['dumpMail']) {
+        $fp = fopen($serendipity['serendipityPath'] . '/templates_c/mail.log', 'a');
+        fwrite($fp, date('Y-m-d H:i') . "\n" . print_r($maildata, true));
+        fclose($fp);
+    }
+
+    if (!isset($maildata['skip_native'])) {
+        return mail($maildata['to'], $maildata['subject'], $maildata['message'], implode("\n", $maildata['headers']));
+    }
 }
 
 /**
