@@ -1,4 +1,4 @@
-<?php # $Id: functions_comments.inc.php 2172 2008-03-17 08:58:32Z garvinhicking $
+<?php # $Id: functions_comments.inc.php 2376 2008-11-14 10:06:54Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -11,6 +11,106 @@ if (defined('S9Y_FRAMEWORK_COMMENTS')) {
 }
 @define('S9Y_FRAMEWORK_COMMENTS', true);
 
+/**
+ * Check if a comment token (from comment notification email) is valid for a given comment id.
+ *
+ * @param string    The Token
+ * @param int       The comment id
+ * @access public
+ * @return bool
+ */
+function serendipity_checkCommentToken($token, $cid) {
+    global $serendipity;
+
+    $goodtoken = false;
+    if ($serendipity['useCommentTokens']) {
+        // Delete any comment tokens older than 1 week.
+        serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options
+                              WHERE okey LIKE 'comment_%' AND name < " . (time() - 604800) );
+        // Get the token for this comment id
+        $tokencheck =& serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}options
+                                             WHERE okey = 'comment_" . $cid . "' LIMIT 1", true, 'assoc');
+        // Verify it against the passed key
+        if (is_array($tokencheck)) {
+            if ($tokencheck['value'] == $token) {
+                $goodtoken = true;  // use this to bypass security checks later
+                // if using tokens, delete this comment from that list no matter how we got here
+                serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options
+                                            WHERE okey = 'comment_" . $cid . "'");
+
+            }
+        }
+    }
+    
+    return $goodtoken;
+}
+
+/**
+ * Check if a comment token was submitted to the serendipity main framework.
+ * This function can kill the workflow completely, if moderation was wanted.
+ *
+ * @param  string   The current base URI
+ * @access public
+ * @return null
+ */
+function serendipity_checkCommentTokenModeration($uri) {
+    global $serendipity;
+
+    // token based comment moderation starts here
+    if ($serendipity['useCommentTokens'] === true && preg_match(PAT_DELETE, $uri, $res)) {
+        $return_msg = "Error.\n";
+        $tokenparse = explode("_",$res[1]);
+        // check that we got a 32 char token
+        if (is_array($tokenparse)) {
+            if (strlen($tokenparse[2]) == 32) {
+                if ($tokenparse[0] == 'comment') {
+                    if (serendipity_deleteComment($res[2], $res[3], 'comments', $tokenparse[2])) {
+                        $return_msg = sprintf (COMMENT_DELETED, $res[2])."\n";
+                    } else {
+                        $return_msg = sprintf (COMMENT_NOTOKENMATCH, $res[2])."\n";
+                    }
+                } elseif ($tokenparse[0] == 'trackback') {
+                    if (serendipity_deleteComment($res[2], $res[3], 'trackbacks', $tokenparse[2])) {
+                        $return_msg = sprintf (TRACKBACK_DELETED, $res[2])."\n";
+                    } else {
+                        $return_msg = sprintf (TRACKBACK_NOTOKENMATCH, $res[2])."\n";
+                    }
+                }
+            } else {
+                $return_msg = sprintf (BADTOKEN)."\n";
+            }
+            header('Content-Type: text/plain; charset='. LANG_CHARSET);
+            die($return_msg);
+        }
+    }
+    if ($serendipity['useCommentTokens'] === true && preg_match(PAT_APPROVE, $uri, $res)) {
+        $return_msg = "Error.\n";
+        $tokenparse = explode("_",$res[1]);
+        // check that we got a 32 char token
+        if (is_array($tokenparse)) {
+            if (strlen($tokenparse[2]) == 32) {
+                if ($tokenparse[0] == 'comment') {
+                    if (serendipity_approveComment($res[2], $res[3], false, false, $tokenparse[2])) {
+                        $return_msg = sprintf (COMMENT_APPROVED, $res[2])."\n";
+                    } else {
+                        $return_msg = sprintf (COMMENT_NOTOKENMATCH, $res[2])."\n";
+                    }
+                } elseif ($tokenparse[0] == 'trackback') {
+                    if (serendipity_approveComment($res[2], $res[3], false, false, $tokenparse[2])) {
+                        $return_msg = sprintf (TRACKBACK_APPROVED, $res[2])."\n";
+                    } else {
+                        $return_msg = sprintf (TRACKBACK_NOTOKENMATCH, $res[2])."\n";
+                    }
+                }
+            } else {
+                $return_msg = sprintf (BADTOKEN)."\n";
+            }
+            header('Content-Type: text/plain; charset='. LANG_CHARSET);
+            die($return_msg);
+        }
+    }
+}
+
 /**
  * Store the personal details of a commenting user in a cookie (or delete that cookie)
  *
@@ -86,7 +186,11 @@ function serendipity_displayCommentForm($id, $url = '', $comments = NULL, $data
     global $serendipity;
 
     if ($comments == NULL) {
-        $comments = serendipity_fetchComments($id);
+        if (empty($id)) {
+            $comments = array();
+        } else {
+            $comments = serendipity_fetchComments($id);
+        }
     }
 
     $commentform_data = array(
@@ -100,7 +204,7 @@ function serendipity_displayCommentForm($id, $url = '', $comments = NULL, $data
         'commentform_subscribe'      => isset($data['subscribe']) ? 'checked="checked"' : '',
         'commentform_data'           => isset($data['comment'])   ? htmlspecialchars($data['comment']) : '',
         'is_commentform_showToolbar' => $showToolbar,
-        'is_allowSubscriptions'      => $serendipity['allowSubscriptions'],
+        'is_allowSubscriptions'      => (serendipity_db_bool($serendipity['allowSubscriptions']) || $serendipity['allowSubscriptions'] === 'fulltext' ? true : false),
         'is_moderate_comments'       => $moderate_comments,
         'commentform_entry'          => $entry
     );
@@ -401,9 +505,10 @@ function serendipity_printCommentsByAuthor() {
  * @param   int     The ID of the comment to delete
  * @param   int     The ID of the entry the comment belongs to [safety]
  * @param   string  The type of a comment (comments/trackback)
+ * @param   string  The 32 character token [if using token based moderation]
  * @return  boolean Return whether the action was successful)
  */
-function serendipity_deleteComment($id, $entry_id, $type='comments') {
+function serendipity_deleteComment($id, $entry_id, $type='comments', $token=false) {
     global $serendipity;
 
     $id       = (int)$id;
@@ -412,9 +517,11 @@ function serendipity_deleteComment($id, $entry_id, $type='comments') {
         return false;
     }
 
-    if ($_SESSION['serendipityAuthedUser'] === true) {
+    $goodtoken = serendipity_checkCommentToken($token, $id);
+
+    if ($_SESSION['serendipityAuthedUser'] === true || $goodtoken) {
         $admin = '';
-        if (!serendipity_checkPermission('adminEntriesMaintainOthers')) {
+        if (!$goodtoken && !serendipity_checkPermission('adminEntriesMaintainOthers')) {
             $admin = " AND authorid = " . (int)$_SESSION['serendipityAuthorid'];
         }
 
@@ -485,7 +592,9 @@ function serendipity_allowCommentsToggle($entry_id, $switch = 'disable') {
         $query = "UPDATE {$serendipity['dbPrefix']}entries SET allow_comments = '" . ($switch == 'disable' ? 'false' : 'true') . "' WHERE id = '". (int)$entry_id ."' $admin";
         serendipity_db_query($query);
         if (serendipity_isResponseClean($_SERVER['HTTP_REFERER'])) {
+            header('Status: 302 Found');
             header('Location: '. $_SERVER['HTTP_REFERER']);
+            exit;
         }
     } else {
         die('What are you up to? You need to be an admin to close comments');
@@ -498,15 +607,18 @@ function serendipity_allowCommentsToggle($entry_id, $switch = 'disable') {
  * LONG
  *
  * @access public
- * @param   int         The ID of the comment to approve
- * @param   int         The ID of the entry a comment belongs to
- * @param   boolean     Whether to force approving a comment despite of its current status
- * @param  boolean      If set to true, a comment will be moderated instead of approved.
- * @return boolean      Success or failure
+ * @param  int         The ID of the comment to approve
+ * @param  int         The ID of the entry a comment belongs to
+ * @param  boolean     Whether to force approving a comment despite of its current status
+ * @param  boolean     If set to true, a comment will be moderated instead of approved.
++ * @param  string     The 32 character token [if using token based moderation]
+ * @return boolean     Success or failure
  */
-function serendipity_approveComment($cid, $entry_id, $force = false, $moderate = false) {
+function serendipity_approveComment($cid, $entry_id, $force = false, $moderate = false, $token = false) {
     global $serendipity;
 
+    $goodtoken = serendipity_checkCommentToken($token, $cid);
+
     /* Get data about the comment, we need this query because this function can be called from anywhere */
     /* This also makes sure we are either the author of the comment, or a USERLEVEL_ADMIN */
     $sql = "SELECT c.*, e.title, a.email as authoremail, a.mail_comments, e.timestamp AS entry_timestamp, e.last_modified AS entry_last_modified
@@ -514,14 +626,10 @@ function serendipity_approveComment($cid, $entry_id, $force = false, $moderate =
                 LEFT JOIN {$serendipity['dbPrefix']}entries e ON (e.id = c.entry_id)
                 LEFT JOIN {$serendipity['dbPrefix']}authors a ON (e.authorid = a.authorid)
                 WHERE c.id = '". (int)$cid ."'
-                    ". ((!serendipity_checkPermission('adminEntriesMaintainOthers') && $force !== true) ? "AND e.authorid = '". (int)$serendipity['authorid'] ."'" : '') ."
+                    ". ((!serendipity_checkPermission('adminEntriesMaintainOthers') && $force !== true && !$goodtoken) ? "AND e.authorid = '". (int)$serendipity['authorid'] ."'" : '') ."
                     ". (($force === true) ? "" : "AND status = 'pending'");
     $rs  = serendipity_db_query($sql, true);
 
-    /* It's already approved, don't spam people */
-    if ( $rs === false ) {
-        return false;
-    }
 
     if ($moderate) {
         $sql = "UPDATE {$serendipity['dbPrefix']}comments SET status = 'pending' WHERE id = ". (int)$cid;
@@ -540,15 +648,36 @@ function serendipity_approveComment($cid, $entry_id, $force = false, $moderate =
         $lm = (int)$rs['entry_last_modified'];
     }
 
-    if ($moderate) {
-        $query = "UPDATE {$serendipity['dbPrefix']}entries SET $field=$field-1, last_modified=". $lm ." WHERE id='". (int)$entry_id ."'";
-    } else {
-        $query = "UPDATE {$serendipity['dbPrefix']}entries SET $field=$field+1, last_modified=". $lm ." WHERE id='". (int)$entry_id ."'";
-    }
+    $counter_comments = serendipity_db_query("SELECT count(id) AS counter 
+                                                FROM {$serendipity['dbPrefix']}comments 
+                                               WHERE status = 'approved' 
+                                                 AND type   = 'NORMAL'
+                                                 AND entry_id = " . (int)$entry_id . "
+                                            GROUP BY entry_id", true);
+    
+    $counter_tb = serendipity_db_query("SELECT count(id) AS counter 
+                                          FROM {$serendipity['dbPrefix']}comments 
+                                         WHERE status = 'approved' 
+                                           AND type   = 'TRACKBACK'
+                                           AND entry_id = " . (int)$entry_id . "
+                                      GROUP BY entry_id", true);
+
+    $query = "UPDATE {$serendipity['dbPrefix']}entries 
+                 SET comments      = " . (int)$counter_comments['counter'] . ",
+                     trackbacks    = " . (int)$counter_tb['counter'] . ", 
+                     last_modified = ". $lm ." 
+               WHERE id = ". (int)$entry_id;
     serendipity_db_query($query);
 
+    /* It's already approved, don't spam people */
+    if ( $rs === false ) {
+        return false;
+    }
+
     if (!$moderate) {
-        if ($serendipity['allowSubscriptions']) {
+        if ($serendipity['allowSubscriptions'] === 'fulltext') {
+            serendipity_mailSubscribers($entry_id, $rs['author'], $rs['email'], $rs['title'], $rs['authoremail'], $cid, $rs['body']);
+        } elseif (serendipity_db_bool($serendipity['allowSubscriptions'])) {
             serendipity_mailSubscribers($entry_id, $rs['author'], $rs['email'], $rs['title'], $rs['authoremail'], $cid);
         }
 
@@ -558,6 +687,251 @@ function serendipity_approveComment($cid, $entry_id, $force = false, $moderate =
     return true;
 }
 
+/**
+ * Confirm a mail authentication request
+ *
+ * @access public
+ * @param   int     The ID of a comment
+ * @param   string  The confirmation hash
+ * @return  boolean
+ */
+function serendipity_confirmMail($cid, $hash) {
+    global $serendipity;
+    
+    $q = "SELECT c.entry_id, e.title, e.timestamp, e.id
+            FROM {$serendipity['dbPrefix']}comments AS c
+            JOIN {$serendipity['dbPrefix']}entries AS e
+              ON (e.id = c.entry_id)
+           WHERE c.status = 'confirm" . serendipity_db_escape_string($hash) . "'
+             AND c.id     = '" . (int)$cid . "'";
+    $confirm = serendipity_db_query($q, true);
+
+    if ($confirm['entry_id'] > 0) {
+        serendipity_db_query("UPDATE {$serendipity['dbPrefix']}options
+                                 SET okey = 'mail_confirm'
+                               WHERE okey = 'mail_confirm" . serendipity_db_escape_string($hash) . "'");
+
+        serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments
+                                 SET status = 'pending'
+                               WHERE status = 'confirm" . serendipity_db_escape_string($hash) . "'
+                                 AND id     = '" . (int)$cid . "'");
+
+        // TODO?
+        /* if (serendipity_db_bool($confirm['mail_comments'])) {
+            serendipity_sendComment($cid, $row['email'], $name, $email, $url, $id, $row['title'], $comments, $type, serendipity_db_bool($ca['moderate_comments']));
+        }
+        */
+        
+        serendipity_approveComment($cid, $confirm['entry_id'], true);
+        return $confirm;
+    } else {
+        return false;
+    }
+}
+
+/**
+ * Store the comment made by a visitor in the database
+ *
+ * @access public
+ * @param   int     The ID of an entry
+ * @param   array   An array that holds the input data from the visitor
+ * @param   string  The type of a comment (normal/trackback)
+ * @param   string  Where did a comment come from? (internal|trackback|plugin)
+ * @param   string  Additional plugin data (spamblock plugin etc.)
+ * @return  boolean Returns true if the comment could be added
+ */
+function serendipity_insertComment($id, $commentInfo, $type = 'NORMAL', $source = 'internal', $ca = array()) {
+    global $serendipity;
+
+    if (!empty($ca['status'])) {
+        $commentInfo['status'] = $ca['status'];
+    }
+
+    $title         = serendipity_db_escape_string(isset($commentInfo['title']) ? $commentInfo['title'] : '');
+    $comments      = $commentInfo['comment'];
+    $ip            = serendipity_db_escape_string(isset($commentInfo['ip']) ? $commentInfo['ip'] : $_SERVER['REMOTE_ADDR']);
+    $commentsFixed = serendipity_db_escape_string($commentInfo['comment']);
+    $name          = serendipity_db_escape_string($commentInfo['name']);
+    $url           = serendipity_db_escape_string($commentInfo['url']);
+    $email         = serendipity_db_escape_string($commentInfo['email']);
+    $parentid      = (isset($commentInfo['parent_id']) && is_numeric($commentInfo['parent_id'])) ? $commentInfo['parent_id'] : 0;
+    $status        = serendipity_db_escape_string(isset($commentInfo['status']) ? $commentInfo['status'] : (serendipity_db_bool($ca['moderate_comments']) ? 'pending' : 'approved'));
+    $t             = serendipity_db_escape_string(isset($commentInfo['time']) ? $commentInfo['time'] : time());
+    $referer       = substr((isset($_SESSION['HTTP_REFERER']) ? serendipity_db_escape_string($_SESSION['HTTP_REFERER']) : ''), 0, 200);
+
+    $query = "SELECT a.email, e.title, a.mail_comments, a.mail_trackbacks
+                FROM {$serendipity['dbPrefix']}entries AS e
+     LEFT OUTER JOIN {$serendipity['dbPrefix']}authors AS a
+                  ON a.authorid = e.authorid
+             WHERE e.id  = '". (int)$id ."'
+               AND e.isdraft = 'false'";
+    if (!serendipity_db_bool($serendipity['showFutureEntries'])) {
+        $query .= " AND e.timestamp <= " . serendipity_db_time();
+    }
+
+    $row = serendipity_db_query($query, true); // Get info on author/entry
+    if (!is_array($row) || empty($id)) {
+        // No associated entry found.
+        if ($GLOBALS['tb_logging']) {
+            $fp = fopen('trackback2.log', 'a');
+            fwrite($fp, '[' . date('d.m.Y H:i') . '] entry reference not found: ' . $query . "\n");
+            fclose($fp);
+        }
+
+        return false;
+    }
+
+    $send_optin = false;
+    if (isset($commentInfo['subscribe'])) {
+        if (!isset($serendipity['allowSubscriptionsOptIn']) || $serendipity['allowSubscriptionsOptIn']) {
+            $subscribe = 'false';
+            $send_optin = true;
+        } else {
+            $subscribe = 'true';
+        }
+    } else {
+        $subscribe = 'false';
+    }
+    
+    $dbhash   = md5(uniqid(rand(), true));
+
+    if ($status == 'confirm') {
+        $dbstatus = 'confirm' . $dbhash;
+    } elseif ($status == 'confirm1') {
+        $auth = serendipity_db_query("SELECT *
+                                        FROM {$serendipity['dbPrefix']}options
+                                       WHERE okey  = 'mail_confirm'
+                                         AND name  = '" . $email . "'
+                                         AND value = '" . $name . "'", true);
+        if (!is_array($auth)) {
+            serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (okey, name, value)
+                                       VALUES ('mail_confirm{$dbhash}', '{$email}', '{$name}')");
+            $dbstatus = 'confirm' . $dbhash;
+        } else {
+            $serendipity['csuccess'] = 'true';
+            $status = $dbstatus = 'approved';
+        }
+    } else {
+        $dbstatus = $status;
+    }
+
+    $query  = "INSERT INTO {$serendipity['dbPrefix']}comments (entry_id, parent_id, ip, author, email, url, body, type, timestamp, title, subscribed, status, referer)";
+    $query .= " VALUES ('". (int)$id ."', '$parentid', '$ip', '$name', '$email', '$url', '$commentsFixed', '$type', '$t', '$title', '$subscribe', '$dbstatus', '$referer')";
+
+    if ($GLOBALS['tb_logging']) {
+        $fp = fopen('trackback2.log', 'a');
+        fwrite($fp, '[' . date('d.m.Y H:i') . '] SQL: ' . $query . "\n");
+    }
+
+    serendipity_db_query($query);
+    $cid = serendipity_db_insert_id('comments', 'id');
+
+    // Send mail to the author if he chose to receive these mails, or if the comment is awaiting moderation
+    if ($status != 'confirm' && (serendipity_db_bool($ca['moderate_comments'])
+        || ($type == 'NORMAL' && serendipity_db_bool($row['mail_comments']))
+        || ($type == 'TRACKBACK' && serendipity_db_bool($row['mail_trackbacks'])))) {
+        serendipity_sendComment($cid, $row['email'], $name, $email, $url, $id, $row['title'], $comments, $type, serendipity_db_bool($ca['moderate_comments']));
+    }
+
+    // Approve with force, if moderation is disabled
+    if ($GLOBALS['tb_logging']) {
+        fwrite($fp, '[' . date('d.m.Y H:i') . '] status: ' . $status . ', moderate: ' . $ca['moderate_comments'] . "\n");
+    }
+
+    if ($status != 'confirm' && (empty($ca['moderate_comments']) || serendipity_db_bool($ca['moderate_comments']) == false)) {
+        if ($GLOBALS['tb_logging']) {
+            fwrite($fp, '[' . date('d.m.Y H:i') . '] Approving...' . "\n");
+        }
+        serendipity_approveComment($cid, $id, true);
+    } elseif ($GLOBALS['tb_logging']) {
+        fwrite($fp, '[' . date('d.m.Y H:i') . '] No need to approve...' . "\n");
+    }
+
+    if ($status == 'confirm') {
+        $subject = sprintf(NEW_COMMENT_TO_SUBSCRIBED_ENTRY, $row['title']);
+        $message = sprintf(CONFIRMATION_MAIL_ALWAYS,
+                            $name,
+                            $row['title'],
+                            $commentsFixed,
+                            $serendipity['baseURL'] . 'comment.php?c=' . $cid . '&hash=' . $dbhash);
+
+        serendipity_sendMail($email, $subject, $message, $serendipity['blogMail']);
+    } elseif ($status == 'confirm1') {
+        $subject = sprintf(NEW_COMMENT_TO_SUBSCRIBED_ENTRY, $row['title']);
+        $message = sprintf(CONFIRMATION_MAIL_ONCE,
+                            $name,
+                            $row['title'],
+                            $commentsFixed,
+                            $serendipity['baseURL'] . 'comment.php?c=' . $cid . '&hash=' . $dbhash);
+
+        serendipity_sendMail($email, $subject, $message, $serendipity['blogMail']);
+    }
+
+    if ($send_optin) {
+        $dupe_check = serendipity_db_query("SELECT count(entry_id) AS counter
+                                              FROM {$serendipity['dbPrefix']}comments
+                                             WHERE entry_id = " . (int)$id . "
+                                               AND email = '$email'
+                                               AND subscribed = 'true'", true);
+        if (!is_array($dupe_check) || $dupe_check['counter'] < 1) {
+            serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (okey, name, value)
+                                       VALUES ('commentsub_{$dbhash}', '" . time() . "', '{$cid}')");
+
+            $subject = sprintf(NEW_COMMENT_TO_SUBSCRIBED_ENTRY, $row['title']);
+            $message = sprintf(CONFIRMATION_MAIL_SUBSCRIPTION,
+                                $name,
+                                $row['title'],
+                                serendipity_archiveURL($id, $row['title'], 'baseURL'),
+                                $serendipity['baseURL'] . 'comment.php?optin=' . $dbhash);
+
+            serendipity_sendMail($email, $subject, $message, $serendipity['blogMail']);
+        }
+    }
+
+    serendipity_purgeEntry($id, $t);
+
+    if ($GLOBALS['tb_logging']) {
+        fclose($fp);
+    }
+}
+
+/**
+ * Confirm a comment subscription
+ *
+ * @access public
+ * @param   string  The confirmation hash
+ * @return  boolean
+ */
+function serendipity_commentSubscriptionConfirm($hash) {
+    global $serendipity;
+
+    // Delete possible current cookie. Also delete any confirmation hashs that smell like 3-week-old, dead fish.
+    if (stristr($serendipity['dbType'], 'sqlite')) {
+        $cast = "name";
+    } else {
+        // Adds explicits casting for mysql, postgresql and others.
+        $cast = "cast(name as integer)";
+    }
+
+    serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options
+                                WHERE okey LIKE 'commentsub_%' AND $cast < " . (time() - 1814400) . ")");
+
+    $hashinfo = serendipity_db_query("SELECT value
+                                        FROM {$serendipity['dbPrefix']}options
+                                       WHERE okey = 'commentsub_" . serendipity_db_escape_string($hash) . "'", true);
+    if (is_array($hashinfo) && $hashinfo['value'] > 0) {
+        $cid = (int)$hashinfo['value'];
+        serendipity_db_query("UPDATE {$serendipity['dbPrefix']}comments
+                                 SET subscribed = 'true'
+                               WHERE id = $cid");
+
+        serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options
+                                    WHERE okey = 'commentsub_" . serendipity_db_escape_string($hash) . "'");
+
+        return $cid;
+    }
+}
+
 /**
  * Save a comment made by a visitor
  *
@@ -578,60 +952,23 @@ function serendipity_saveComment($id, $commentInfo, $type = 'NORMAL', $source =
     $commentInfo['source'] = $source;
     serendipity_plugin_api::hook_event('frontend_saveComment', $ca, $commentInfo);
     if (!is_array($ca) || serendipity_db_bool($ca['allow_comments'])) {
-        $title         = serendipity_db_escape_string(isset($commentInfo['title']) ? $commentInfo['title'] : '');
-        $comments      = $commentInfo['comment'];
-        $ip            = serendipity_db_escape_string(isset($commentInfo['ip']) ? $commentInfo['ip'] : $_SERVER['REMOTE_ADDR']);
-        $commentsFixed = serendipity_db_escape_string($commentInfo['comment']);
-        $name          = serendipity_db_escape_string($commentInfo['name']);
-        $url           = serendipity_db_escape_string($commentInfo['url']);
-        $email         = serendipity_db_escape_string($commentInfo['email']);
-        $parentid      = (isset($commentInfo['parent_id']) && is_numeric($commentInfo['parent_id'])) ? $commentInfo['parent_id'] : 0;
-        $status        = serendipity_db_escape_string(isset($commentInfo['status']) ? $commentInfo['status'] : (serendipity_db_bool($ca['moderate_comments']) ? 'pending' : 'approved'));
-        $t             = serendipity_db_escape_string(isset($commentInfo['time']) ? $commentInfo['time'] : time());
-        $referer       = substr((isset($_SESSION['HTTP_REFERER']) ? serendipity_db_escape_string($_SESSION['HTTP_REFERER']) : ''), 0, 200);
-
-        $query = "SELECT a.email, e.title, a.mail_comments, a.mail_trackbacks
-                 FROM {$serendipity['dbPrefix']}entries e, {$serendipity['dbPrefix']}authors a
-                 WHERE e.id  = '". (int)$id ."'
-                   AND e.isdraft = 'false'
-                   AND e.authorid = a.authorid";
-        if (!serendipity_db_bool($serendipity['showFutureEntries'])) {
-            $query .= " AND e.timestamp <= " . serendipity_db_time();
-
+        if ($GLOBALS['tb_logging']) {
+            $fp = fopen('trackback2.log', 'a');
+            fwrite($fp, '[' . date('d.m.Y H:i') . '] insert comment into DB' . "\n");
+            fclose($fp);
         }
-
-        $row = serendipity_db_query($query, true); // Get info on author/entry
-        if (!is_array($row) || empty($id)) {
-            // No associated entry found.
-            return false;
-        }
-
-        if (isset($commentInfo['subscribe'])) {
-            $subscribe = 'true';
-        } else {
-            $subscribe = 'false';
-        }
-
-        $query  = "INSERT INTO {$serendipity['dbPrefix']}comments (entry_id, parent_id, ip, author, email, url, body, type, timestamp, title, subscribed, status, referer)";
-        $query .= " VALUES ('". (int)$id ."', '$parentid', '$ip', '$name', '$email', '$url', '$commentsFixed', '$type', '$t', '$title', '$subscribe', '$status', '$referer')";
-
-        serendipity_db_query($query);
-        $cid = serendipity_db_insert_id('comments', 'id');
-
-        // Send mail to the author if he chose to receive these mails, or if the comment is awaiting moderation
-        if (serendipity_db_bool($ca['moderate_comments'])
-            || ($type == 'NORMAL' && serendipity_db_bool($row['mail_comments']))
-            || ($type == 'TRACKBACK' && serendipity_db_bool($row['mail_trackbacks']))) {
-            serendipity_sendComment($cid, $row['email'], $name, $email, $url, $id, $row['title'], $comments, $type, serendipity_db_bool($ca['moderate_comments']));
-        }
-
-        // Approve with force, if moderation is disabled
-        if (empty($ca['moderate_comments']) || serendipity_db_bool($ca['moderate_comments']) == false) {
-            serendipity_approveComment($cid, $id, true);
-        }
-        serendipity_purgeEntry($id, $t);
+                        
+        serendipity_insertComment($id, $commentInfo, $type, $source, $ca);
+        $commentInfo['comment_id'] = $id;
+        serendipity_plugin_api::hook_event('frontend_saveComment_finish', $ca, $commentInfo);
         return true;
     } else {
+        if ($GLOBALS['tb_logging']) {
+            $fp = fopen('trackback2.log', 'a');
+            fwrite($fp, '[' . date('d.m.Y H:i') . '] discarding comment from DB' . "\n");
+            fclose($fp);
+        }
+
         return false;
     }
 }
@@ -646,9 +983,10 @@ function serendipity_saveComment($id, $commentInfo, $type = 'NORMAL', $source =
  * @param   string  The title of the entry
  * @param   string  The mail address used to send emails from
  * @param   int     The ID of the comment that has been made
+ * @param   string  The body of the comment that has been made
  * @return null
  */
-function serendipity_mailSubscribers($entry_id, $poster, $posterMail, $title, $fromEmail = 'none@example.com', $cid = null) {
+function serendipity_mailSubscribers($entry_id, $poster, $posterMail, $title, $fromEmail = 'none@example.com', $cid = null, $body = null) {
     global $serendipity;
 
     $entryURI = serendipity_archiveURL($entry_id, $title, 'baseURL') . ($cid > 0 ? '#c' . $cid : '');
@@ -684,7 +1022,7 @@ function serendipity_mailSubscribers($entry_id, $poster, $posterMail, $title, $f
                       $serendipity['blogTitle'],
                       $title,
                       $poster,
-                      $entryURI,
+                      ($body ? "\n\n" . $body . "\n" : '') . $entryURI,
                       serendipity_rewriteURL('unsubscribe/' . urlencode($subscriber['email']) . '/' . (int)$entry_id, 'baseURL')
             );
         } else {
@@ -695,7 +1033,7 @@ function serendipity_mailSubscribers($entry_id, $poster, $posterMail, $title, $f
                       $serendipity['blogTitle'],
                       $title,
                       $poster,
-                      $entryURI,
+                      ($body ? "\n\n" . $body . "\n" : '') . $entryURI,
                       serendipity_rewriteURL('unsubscribe/' . urlencode($subscriber['email']) . '/' . (int)$entry_id, 'baseURL')
             );
         }
@@ -747,6 +1085,21 @@ function serendipity_sendComment($comment_id, $to, $fromName, $fromEmail, $fromU
 
     $entryURI   = serendipity_archiveURL($id, $title, 'baseURL');
     $path       = ($type == 'TRACKBACK') ? 'trackback' : 'comment';
+
+    // Check for using Tokens
+    if ($serendipity['useCommentTokens']) {
+        $token = md5(uniqid(rand(),1));
+        $path = $path . "_token_" . $token;
+
+        //Delete any comment tokens older than 1 week.
+        serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options
+                              WHERE okey LIKE 'comment_%' AND name < " . (time() - 604800) );
+
+        // Issue new comment moderation hash
+        serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (name, value, okey)
+                              VALUES ('" . time() . "', '" . $token . "', 'comment_" . $comment_id ."')");
+    }
+
     $deleteURI  = serendipity_rewriteURL(PATH_DELETE . '/'. $path .'/' . $comment_id . '/' . $id . '-' . serendipity_makeFilename($title)  . '.html', 'baseURL');
     $approveURI = serendipity_rewriteURL(PATH_APPROVE . '/'. $path .'/' . $comment_id . '/' . $id . '-' . serendipity_makeFilename($title)  . '.html', 'baseURL');
 
