@@ -1,4 +1,4 @@
-<?php # $Id: functions_config.inc.php 1975 2007-10-12 09:12:48Z garvinhicking $
+<?php # $Id: functions_config.inc.php 2409 2008-12-20 17:51:46Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -423,9 +423,16 @@ function serendipity_issueAutologin($array) {
     $rnd = md5(uniqid(time(), true) . $_SERVER['REMOTE_ADDR']);
 
     // Delete possible current cookie. Also delete any autologin keys that smell like 3-week-old, dead fish.
+    if (stristr($serendipity['dbType'], 'sqlite')) {
+        $cast = "name";
+    } else {
+        // Adds explicits casting for mysql, postgresql and others.
+        $cast = "cast(name as integer)";
+    }
+
     serendipity_db_query("DELETE FROM {$serendipity['dbPrefix']}options 
                                 WHERE okey = 'l_" . serendipity_db_escape_string($serendipity['COOKIE']['author_information']) . "'
-                                   OR (okey LIKE 'l_%' AND name < " . (time() - 1814400) . ")");
+                                   OR (okey LIKE 'l_%' AND $cast < " . (time() - 1814400) . ")");
 
     // Issue new autologin cookie
     serendipity_db_query("INSERT INTO {$serendipity['dbPrefix']}options (name, value, okey) VALUES ('" . time() . "', '" . serendipity_db_escape_string($package) . "', 'l_" . $rnd . "')");
@@ -620,7 +627,7 @@ function serendipity_setCookie($name, $value, $securebyprot = true) {
     
     // If HTTP-Hosts like "localhost" are used, current browsers reject cookies.
     // In this case, we disregard the HTTP host to be able to set that cookie.
-    if (substr_count($host, '.') < 2) {
+    if (substr_count($host, '.') < 1) {
         $host = '';
     }
 
@@ -646,6 +653,12 @@ function serendipity_deleteCookie($name) {
         $host = substr($host, 0, $pos);
     }
 
+    // If HTTP-Hosts like "localhost" are used, current browsers reject cookies.
+    // In this case, we disregard the HTTP host to be able to set that cookie.
+    if (substr_count($host, '.') < 1) {
+        $host = '';
+    }
+                        
     setcookie("serendipity[$name]", '', time()-4000, $serendipity['serendipityHTTPPath'], $host);
     unset($_COOKIE[$name]);
     unset($serendipity['COOKIE'][$name]);
@@ -732,9 +745,9 @@ function serendipity_iframe(&$entry, $mode = null, $use_smarty = true) {
             break;
 
         case 'preview':
-            echo '<div style="float: left; height: 225px"></div>';
+            echo '<div id="serendipity_preview_spacer" style="float: left; height: 225px"></div>';
             serendipity_printEntries(array($entry), ($entry['extended'] != '' ? 1 : 0), true);
-            echo '<br style="clear: both" />';
+            echo '<br id="serendipity_preview_spacer2" style="clear: both" />';
 
             $show = true;
             break;
@@ -874,6 +887,9 @@ function serendipity_getSessionLanguage() {
         return $serendipity['lang'];
     }
 */
+    if (isset($serendipity['lang']) && !isset($serendipity['languages'][$serendipity['lang']])) {
+        $serendipity['lang'] = $serendipity['autolang'];
+    }
 
     if (isset($_REQUEST['user_language']) && (!empty($serendipity['languages'][$_REQUEST['user_language']])) && !headers_sent()) {
         serendipity_setCookie('serendipityLanguage', $_REQUEST['user_language'], false);
