@@ -1,4 +1,4 @@
-<?php # $Id: functions_entries.inc.php 2191 2008-03-20 09:17:25Z garvinhicking $
+<?php # $Id: functions_entries.inc.php 2395 2008-12-09 10:05:33Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -339,23 +339,23 @@ function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fe
         }
     }
 
-    serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('noCache' => $noCache, 'noSticky' => $noSticky, 'source' => 'entries'));
-
     if ($serendipity['dbType'] == 'postgres' ||
         $serendipity['dbType'] == 'pdo-postgres') {
-        $group    = '';
-        $distinct = 'DISTINCT';
+        $cond['group']    = '';
+        $cond['distinct'] = 'DISTINCT';
     } else {
-        $group    = 'GROUP BY e.id';
-        $distinct = '';
+        $cond['group']    = 'GROUP BY e.id';
+        $cond['distinct'] = '';
     }
 
     if (!is_null($group_by)) {
-        $group = $group_by;
+        $cond['group'] = $group_by;
     }
 
+    serendipity_plugin_api::hook_event('frontend_fetchentries', $cond, array('noCache' => $noCache, 'noSticky' => $noSticky, 'source' => 'entries'));
+
     if (is_null($select_key)) {
-        $select_key = "$distinct
+        $select_key = "{$cond['distinct']}
                     {$cond['addkey']}
 
                     e.id,
@@ -406,8 +406,9 @@ function &serendipity_fetchEntries($range = null, $full = true, $limit = '', $fe
     $query = "SELECT $select_key
                      $body
                      {$serendipity['fullCountQuery']}
-                     $group
-            ORDER BY {$cond['orderby']}
+                     {$cond['group']}
+                     {$cond['having']}
+                     " . (!empty($cond['orderby']) ? "ORDER BY {$cond['orderby']}" : "") . "
                      $limit";
 
     // DEBUG:
@@ -537,6 +538,10 @@ function &serendipity_fetchEntry($key, $val, $full = true, $fetchDrafts = 'false
                      WHERE
                             e.$key " . ($key == 'id' ? '=' : 'LIKE') . " '" . serendipity_db_escape_string($val) . "'
                             {$cond['and']}
+
+                            {$cond['single_group']}
+                            {$cond['single_having']}
+                            {$cond['single_orderby']}
                      LIMIT  1";
 
     $ret =& serendipity_db_query($querystring, true, 'assoc');
@@ -736,20 +741,34 @@ function &serendipity_searchEntries($term, $limit = '') {
     $cond = array();
     if ($serendipity['dbType'] == 'postgres' ||
         $serendipity['dbType'] == 'pdo-postgres') {
-        $group     = '';
-        $distinct  = 'DISTINCT';
-        $cond['find_part'] = "(title ILIKE '%$term%' OR body ILIKE '%$term%' OR extended ILIKE '%$term%')";
+        $cond['group']     = '';
+        $cond['distinct']  = 'DISTINCT';
+            
+        $r = serendipity_db_query("SELECT count(routine_name) AS counter
+                                     FROM information_schema.routines
+                                    WHERE routine_name LIKE 'to_tsvector'
+                                      AND specific_catalog = '" . $serendipity['dbName'] . "'");
+        if (is_array($r) && $r[0]['counter'] > 0) {
+            $term = str_replace('&amp;', '&', $term);
+            $cond['find_part'] = "(
+            to_tsvector('english', title)    @@to_tsquery('$term') OR
+            to_tsvector('english', body)     @@to_tsquery('$term') OR
+            to_tsvector('english', extended) @@to_tsquery('$term')
+            )"; 
+        } else {
+            $cond['find_part'] = "(title ILIKE '%$term%' OR body ILIKE '%$term%' OR extended ILIKE '%$term%')";
+        }
     } elseif ($serendipity['dbType'] == 'sqlite' || $serendipity['dbType'] == 'sqlite3') {
         // Very extensive SQLite search. There currently seems no other way to perform fulltext search in SQLite
         // But it's better than no search at all :-D
-        $group     = 'GROUP BY e.id';
-        $distinct  = '';
-        $term      = serendipity_mb('strtolower', $term);
+        $cond['group']     = 'GROUP BY e.id';
+        $cond['distinct']  = '';
+        $term              = serendipity_mb('strtolower', $term);
         $cond['find_part'] = "(lower(title) LIKE '%$term%' OR lower(body) LIKE '%$term%' OR lower(extended) LIKE '%$term%')";
     } else {
-        $group     = 'GROUP BY e.id';
-        $distinct  = '';
-        $term      = str_replace('&quot;', '"', $term);
+        $cond['group']    = 'GROUP BY e.id';
+        $cond['distinct'] = '';
+        $term             = str_replace('&quot;', '"', $term);
         if (preg_match('@["\+\-\*~<>\(\)]+@', $term)) {
             $cond['find_part'] = "MATCH(title,body,extended) AGAINST('$term' IN BOOLEAN MODE)";
         } else {
@@ -773,7 +792,7 @@ function &serendipity_searchEntries($term, $limit = '') {
                             ({$cond['find_part']})
                             {$cond['and']}";
 
-    $querystring = "SELECT $distinct
+    $querystring = "SELECT {$cond['distinct']}
                             e.id,
                             e.authorid,
                             a.realname AS author,
@@ -786,9 +805,13 @@ function &serendipity_searchEntries($term, $limit = '') {
                             e.body,
                             e.extended,
                             e.trackbacks,
-                            e.exflag
+                            e.exflag,
+                            e.isdraft,
+                            e.last_modified,
+                            a.username AS loginname
                     {$serendipity['fullCountQuery']}
-                    $group
+                    {$cond['group']}
+                    {$cond['having']}
                   ORDER BY  timestamp DESC
                     $limit";
 
@@ -1290,7 +1313,7 @@ function serendipity_updertEntry($entry) {
 
     serendipity_purgeEntry($entry['id'], $entry['timestamp']);
 
-    if (!serendipity_db_bool($entry['isdraft'])) {
+    if (!serendipity_db_bool($entry['isdraft']) && $entry['timestamp'] <= serendipity_serverOffsetHour()) {
         // When saving an entry, first all references need to be gathered. But trackbacks to them
         // shall only be send at the end of the execution flow. However, certain plugins depend on
         // the existance of handled references. Thus we store the current references at this point,
@@ -1307,7 +1330,7 @@ function serendipity_updertEntry($entry) {
         serendipity_plugin_api::hook_event('backend_save', $entry, $newEntry);
     }
 
-    if (!serendipity_db_bool($entry['isdraft'])) {
+    if (!serendipity_db_bool($entry['isdraft']) && $entry['timestamp'] <= serendipity_serverOffsetHour()) {
         // Now that plugins are executed, we go ahead into the Temple of Doom and send possibly failing trackbacks.
         // First, original list of references is restored (inside the function call)
         serendipity_handle_references($entry['id'], $serendipity['blogTitle'], $drafted_entry['title'], $drafted_entry['body'] . $drafted_entry['extended'], false);
@@ -1477,7 +1500,7 @@ function serendipity_printArchives() {
             $thisMonth  = persian_date_utf('m', serendipity_serverOffsetHour());
             break;
     }
-    $max = 0;
+    $max = 1;
 
     if (isset($serendipity['GET']['category'])) {
         $cat_sql = serendipity_getMultiCategoriesSQL($serendipity['GET']['category']);
@@ -1493,7 +1516,14 @@ function serendipity_printArchives() {
         $author_get = '';
     }
 
-    $q = "SELECT e.timestamp
+    if ($serendipity['dbType'] == 'postgres' ||
+        $serendipity['dbType'] == 'pdo-postgres') {
+        $distinct = 'DISTINCT e.id,';
+    } else {
+        $distinct = '';
+    }
+
+    $q = "SELECT $distinct e.timestamp
             FROM {$serendipity['dbPrefix']}entries e
             " . (!empty($cat_sql) ? "
        LEFT JOIN {$serendipity['dbPrefix']}entrycat ec
@@ -1508,8 +1538,10 @@ function serendipity_printArchives() {
     $entries =& serendipity_db_query($q, false, 'assoc');
 
     $group = array();
-    foreach($entries AS $entry) {
-        $group[date('Ym', $entry['timestamp'])]++;
+    if (is_array($entries)) {
+        foreach($entries AS $entry) {
+            $group[date('Ym', $entry['timestamp'])]++;
+        }
     }
 
     $output = array();
@@ -1594,3 +1626,22 @@ function serendipity_getTotalCount($what) {
 
     }
 }
+
+/**
+ * Get a path of all parent categories to a given category.
+ *
+ * @access public
+ * @param   string      The id of the category, whose parents you want to fetch
+ * @return  array       An Array with all category information, ordered from root to the ID you supplied.
+ */
+function serendipity_getCategoryRoot($id) {
+    global $serendipity;
+
+    $r = serendipity_db_query("SELECT p.*
+                                 FROM {$serendipity['dbPrefix']}category n,
+                                      {$serendipity['dbPrefix']}category p
+                                WHERE n.category_left BETWEEN p.category_left AND p.category_right
+                                  AND n.categoryid = " . (int)$id . "
+                             ORDER BY n.category_left DESC, p.category_left ASC");
+    return $r;
+}
\ No newline at end of file
