@@ -548,17 +548,23 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
             return true;
         }
 
+        if (file_exists($serendipity['serendipityPath'] . 'htmlarea/XinhaCore.js')) {
+            $xinha = true;
+        } else {
+            $xinha = false;
+        }
+
         if (!$init) {
 ?>
     <script type="text/javascript">
         _editor_url = "<?php echo $serendipity['serendipityHTTPPath'] . 'htmlarea/'; ?>";
-        _editor_lang = "<?php echo WYSIWYG_LANG; ?>";
+        _editor_lang = "<?php echo ($xinha ? $serendipity['lang'] : WYSIWYG_LANG); ?>";
+        _editor_skin = "silva";
         var editorref = '';
     </script>
-    <script type="text/javascript" src="htmlarea/htmlarea.js"></script>
-    <script type="text/javascript" src="htmlarea/lang/<?php echo WYSIWYG_LANG; ?>.js"></script>
-    <script type="text/javascript" src="htmlarea/dialog.js"></script>
-    <style  type="text/css">@import url(htmlarea/htmlarea.css);</style>
+    <?php if ($xinha) { ?><script type="text/javascript" src="htmlarea/XinhaCore.js"></script>
+    <?php } else { ?><script type="text/javascript" src="htmlarea/htmlarea.js"></script>
+    <?php } ?>
 <?php
         }
 
@@ -593,6 +599,60 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
 	<?php } else  { ?>
     var editor<?php echo $jsname; ?> = null; var config<?php echo $jsname; ?> = null;
 	<?php } // end if ?>
+    <?php if (is_array($eventData['buttons'])) { ?>
+    var btn_callbacks = new Array();
+    // Serendipity standardized editor functions
+    function serendipity_editor_getSelected(editor_id) {
+        var editor = findXinha(editor_id);
+        if (editor == 'undefined') {
+            editor = findHtmlArea(editor_id);
+        }
+        var html = editor.getSelectedHTML();
+        return html;
+    }
+    function serendipity_editor_replaceSelected(editor_id, str) {
+        var editor = findXinha(editor_id);
+        if (editor == 'undefined') {
+            editor = findHtmlArea(editor_id);
+        }
+        editor.insertHTML(str);
+    }
+    function serendipity_editor_getAll(editor_id) {
+        var editor = findXinha(editor_id);
+        if (editor == 'undefined') {
+            editor = findHtmlArea(editor_id);
+        }
+        return editor.getEditorContent();
+    }
+    function serendipity_editor_replaceAll(editor_id, str) {
+        var editor = findXinha(editor_id);
+        if (editor == 'undefined') {
+            editor = findHtmlArea(editor_id);
+        }
+        editor.setEditorContent(str);
+    }
+    // Serendipity standardized editor convenience function
+    function findXinha(editor_id) {
+        if (typeof(xinha_editors) != 'undefined') {
+            for (var editorName in xinha_editors) {
+                if (editor_id == xinha_editors[editorName]._textArea.name) {
+                    return xinha_editors[editorName];
+                }
+            }
+        }
+        return 'undefined';
+    }
+    function findHtmlArea(editor_id) {
+        if (editor_id == 'serendipity[body]') {
+            return editorbody;
+        } else if (editor_id == 'serendipity[extended]') {
+            return editorextended;
+        } else if (typeof(htmlarea_editors) != 'undefined') {
+            return htmlarea_editors[editor_id];
+        } 
+        return 'undefined';
+    }
+    <?php } ?>
     function Spawn<?php echo $jsname; ?>(<?php echo $spawnMulti ? 'id' : ''; ?>) {
 		editor<?php echo $jsname; ?> = new HTMLArea("<?php echo $item; ?>"<?php echo $spawnMulti ? ' + id' : ''; ?>);
         <?php if($spawnMulti) { ?>
@@ -602,25 +662,72 @@ function serendipity_emit_htmlarea_code($item, $jsname, $spawnMulti = false) {
         config<?php echo $jsname; ?>.registerButton('image_selector', '<?PHP echo MANAGE_IMAGES; ?>', '<?php echo $serendipity['serendipityHTTPPath']; ?>htmlarea/images/ed_s9yimage.gif', false,
             function(editor, id) {
                 window.open('<?php echo $serendipity['serendipityHTTPPath']; ?>serendipity_admin_image_selector.php?serendipity[textarea]=<?php echo $jsname . ($spawnMulti ? "' + editor._textArea.id + '" : ''); ?>', 'ImageSel', 'width=800,height=600,toolbar=no,scrollbars=1,scrollbars,resize=1,resizable=1');
-                editorref = editor<?php echo $jsname; ?>;
+                // editorref = editor<?php echo $jsname; ?>;
+                editorref = editor;
             }
         );
         config<?php echo $jsname; ?>.toolbar.push([ "image_selector"]);
-        config<?php echo $jsname; ?>.cssFile = '<?php echo $csscode; ?>';
+        <?php 
+            if (is_array($eventData['buttons'])) {
+                foreach($eventData['buttons'] as $button) {
+                    echo "btn_callbacks['{$button['id']}'] = {$button['javascript']};\n";
+                    echo "var cb_{$button['id']} = btn_callbacks['{$button['id']}'];\n";
+                    echo "config$jsname.registerButton('{$button['id']}', '{$button['name']}', '{$button['img_url']}', false, function (editor, id) { btn_callbacks['{$button['id']}'](editor._textArea.id, id); });\n";
+                    echo "config$jsname.toolbar.push([\"{$button['id']}\"]);\n";
+                    // Sort buttons into toolbar lists for later additions
+                    switch($button['toolbar']) {
+                    case S9Y_WYSIWYG_TOOLBAR_FORMATTING:
+                        $toolbar[S9Y_WYSIWYG_TOOLBAR_FORMATTING][] = $button;
+                        break;
+                    case S9Y_WYSIWYG_TOOLBAR_MEDIA:
+                    case S9Y_WYSIWYG_TOOLBAR_WEB:
+                        $toolbar[S9Y_WYSIWYG_WEB][] = $button;
+                        break;
+                    default:
+                        $toolbar['other'][] = $button;
+                        break;
+                    }
+                }
+            }
+            ?>
+        <?php if ($xinha) { ?>config<?php echo $jsname; ?>.pageStyle = '<?php echo $csscode; ?>';
+        <?php } else { ?>config<?php echo $jsname; ?>.cssFile = '<?php echo $csscode; ?>';
+        <?php } ?>
+
         config<?php echo $jsname; ?>.toolbar = [
             [ "fontname", "space",
               "fontsize", "space",
               "formatblock", "space",
               "bold", "italic", "underline", "strikethrough", "separator",
-              "subscript", "superscript", "separator",
+              "subscript", "superscript", "separator", <?php
+                  if (is_array($toolbar[S9Y_WYSIWYG_TOOLBAR_FORMATTING])) {
+                      foreach($toolbar[S9Y_WYSIWYG_TOOLBAR_FORMATTING] as $button) {
+                          echo '"' . $button['id'] . '",';
+                      }
+                      echo '"separator",' . "\n";
+                  } ?>
               "copy", "cut", "paste", "space", "undo", "redo" ],
 
             [ "justifyleft", "justifycenter", "justifyright", "justifyfull", "separator",
               "lefttoright", "righttoleft", "separator",
               "orderedlist", "unorderedlist", "outdent", "indent", "separator",
               "forecolor", "hilitecolor", "separator",
-              "inserthorizontalrule", "createlink", "insertimage", "image_selector", "inserttable", "htmlmode", "separator",
-              "popupeditor", "separator", "showhelp", "about" ]
+              "inserthorizontalrule", "createlink", "insertimage", "image_selector", "inserttable", "htmlmode", "separator", <?php
+                  if (is_array($toolbar[S9Y_WYSIWYG_TOOLBAR_WEB])) {
+                      foreach($toolbar[S9Y_WYSIWYG_TOOLBAR_WEB] as $button) {
+                          echo '"' . $button['id'] . '",';
+                      }
+                      echo '"separator",' . "\n";
+                  } ?>
+              "popupeditor", "separator", "showhelp", "about" ] <?php
+                  if (is_array($toolbar['other'])) {
+                      echo ",\n    [ ";
+                      foreach($toolbar['other'] as $button) {
+                          echo '"' . $button['id'] . '", ';
+                      }
+                      echo '"separator" ]' . "\n";
+                  } ?>
+              
         ];
         // editor<?php echo $jsname; ?>.registerPlugin(SpellChecker);  // [SPELLCHECK]
         editor<?php echo $jsname; ?>.generate();
