@@ -1,4 +1,4 @@
-<?php # $Id: functions_installer.inc.php 2195 2008-03-25 12:39:14Z garvinhicking $
+<?php # $Id: functions_installer.inc.php 2397 2008-12-09 10:41:48Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -386,20 +386,28 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
     switch ($type) {
         case 'bool':
             $value = serendipity_get_bool($value);
+            if ($value === null) {
+                $value = $default;
+            }
+            
             echo '<input class="input_radio" id="radio_cfg_' . $name . '_yes" type="radio" name="' . $name . '" value="true" ';
             echo (($value == true) ? 'checked="checked"' : ''). ' /><label for="radio_cfg_' . $name . '_yes"> ' . YES . '</label>&nbsp;';
             echo '<input class="input_radio" id="radio_cfg_' . $name . '_no" type="radio" name="' . $name . '" value="false" ';
             echo (($value == true) ? '' : 'checked="checked"'). ' /><label for="radio_cfg_' . $name . '_no"> ' . NO . '</label>';
             break;
 
+        case 'fullprotected':
+            echo '<input autocomplete="off" class="input_textbox" type="password" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
+            break;
+
         case 'protected':
             echo '<input class="input_textbox" type="password" size="30" name="' . $name . '" value="' . htmlspecialchars($value) . '" />';
             break;
 
         case 'multilist':
             echo '<select name="'. $name .'[]" multiple="multiple" size="5">';
+
             foreach ((array)$default as $k => $v) {
-                print_r($v);
                 $selected = false;
                 foreach((array)$value AS $vk => $vv) {
                     if ($vv['confkey'] == $v['confkey']) {
@@ -417,9 +425,12 @@ function serendipity_guessInput($type, $name, $value='', $default='') {
 
         case 'list':
             echo '<select name="'. $name .'">';
-
+            $cval = (string)$value;
             foreach ((array)$default as $k => $v) {
-                $selected = ($k == $value);
+                $selected = ((string)$k == (string)$value);
+                if (empty($cval) && ((string)$k === 'false' || (string)$k === null)) {
+                    $selected = true;
+                }
 
                 printf('<option value="%s"%s>%s</option>'. "\n",
                       $k,
@@ -1182,3 +1193,127 @@ global $serendipity;
     }
 }
 
+/**
+ * Retrieve an FTP-compatible checksum for a file.
+ *
+ * @access public
+ * @param string filename is the path to the file to checksum
+ * @param string type forces a particular interpretation of newlines.  Mime
+ *    types and strings starting with 'text' will cause newlines to be stripped
+ *    before the checksum is calculated (default: null, determine from finfo 
+ *    and extension)
+ * @return string An MD5 checksum of the file, with newlines removed if it's 
+ *    an ASCII type; or false if the file cannot be read
+ */
+function serendipity_FTPChecksum($filename, $type = null) {
+    /** Only read the finfo database once */
+    static $debug_exts = array();
+
+    // Must be able to read the file 
+    if (!is_readable($filename)) {
+        return false;
+    }
+
+    // Figure out whether it's binary or text by extension
+    if ($type == null) {
+        $parts = pathinfo($filename);
+        $ext = '';
+        // Some PHP versions throw a warning if the index doesn't exist
+        if (isset($parts['extension'])) {
+            $ext = $parts['extension'];
+        }
+        // If they're case-insensitive equal, strcasecmp() returns 0, or
+        // 'false'.  So I use && to find if any of them are 0, in the
+        // most likely fail-fast order.
+        if (strcasecmp($ext, 'php') && 
+            strcasecmp($ext, 'tpl') &&
+            strcasecmp($ext, 'sql') &&
+            strcasecmp($ext, 'js') && 
+            strcasecmp($ext, 'txt') && 
+            strcasecmp($ext, 'htc') && 
+            strcasecmp($ext, 'css') && 
+            strcasecmp($ext, 'dist') && 
+            strcasecmp($ext, 'lib') && 
+            strcasecmp($ext, 'sh') && 
+            strcasecmp($ext, 'html') &&
+            strcasecmp($ext, 'htm') &&
+            !empty($ext)) {
+            if (!in_array($ext, array_keys($debug_exts))) {
+                $debug_exts[$ext] = $filename;
+            }
+            $type = 'bin';
+        } else {
+            $type = 'text';
+        }
+    }
+
+    // Calculate the checksum
+    $md5 = false;
+    if (stristr($type, 'text')) {
+        // This is a text-type file.  We need to remove linefeeds before 
+        // calculating a checksum, to account for possible FTP conversions
+        // that are inconvenient, but still valid.  But we don't want to
+        // allow newlines anywhere; just different *kinds* of newlines.
+        $newlines = array("#\r\n#", "#\r#", "#\n#");
+        $file = file_get_contents($filename);
+        $file = preg_replace($newlines, ' ', $file);
+        $md5 = md5($file);
+    } else {
+        // Just get its md5sum
+        $md5 = md5_file($filename);
+    }
+
+    return $md5;
+}
+
+/**
+ * Validate checksums for all required files.
+ * 
+ * @return A list of all files that failed checksum, where keys are the 
+ *    relative path of the file, and values are the bad checksum
+ */
+function serendipity_verifyFTPChecksums() {
+    global $serendipity;
+
+    $badsums = array();
+
+    // Load the checksums
+    $f = S9Y_INCLUDE_PATH . 'checksums.inc.php';
+    
+    if (!file_exists($f) || filesize($f) < 1) {
+        return $badsums;
+    }
+
+    require_once $f;
+    // Verify that every file in the checksum list was uploaded correctly
+    $basedir = realpath(dirname(__FILE__) . '/../');
+
+    if (!is_array($serendipity['checksums_' . $serendipity['version']])) {
+        return $badsums;
+    }
+
+    foreach ($serendipity['checksums_' . $serendipity['version']] as $prel => $sum) {
+        $path = $basedir . '/' . $prel;
+        // Don't take checksums of directories
+        if (is_dir($path)) {
+            // Weird that it's even here. 
+            continue;
+        }
+
+        // Can't checksum unreadable or nonexistent files
+        if (!is_readable($path)) {
+            $badsums[$prel] = 'missing';
+            continue;
+        }
+
+        // Validate checksum
+        $calcsum = serendipity_FTPChecksum($path);
+        if ($sum != $calcsum) {
+            $badsums[$prel] = $calcsum;
+            continue;
+        }
+    }
+
+    return $badsums;
+}
+/* vim: set sts=4 ts=4 sw=4 expandtab : */
