@@ -139,7 +139,7 @@ function show_plugins($event_only = false, $sidebars = null)
         $ptitle = $opts[$plugin_placement];
         $pid    = $plugin_placement;
 
-        echo '<td class="pluginmanager_side">';
+        echo '<td class="pluginmanager_side pluginmanager_' . ($event_only ? 'event' : 'sidebar') . '">';
         echo '<div class="heading">' . $ptitle . '</div>';
         echo '<ol id="' . $pid . '_col" class="pluginmanager_container">';
         if ($is_invisible) {
@@ -219,7 +219,7 @@ function show_plugins($event_only = false, $sidebars = null)
 
                     <span class="pluginmanager_title">
                 <?php if ( $can_configure ) { ?>
-                    <a href="?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=<?php echo $key ?>"><?php echo $title; ?></a>
+                    <a title="<?php echo $plugin_data['name']; ?>" href="?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=<?php echo $key ?>"><?php echo $title; ?></a>
                 <?php } else { ?>
                     <?php echo $title; ?>
                 <?php } ?></span><br />
@@ -360,6 +360,17 @@ function placement_box($name, $val, $is_plugin_editable = false, $is_event = fal
 function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_names, $showTable = true, $showSubmit = true, $showExample = true, $spawnNuggets = true, $postKey = 'plugin') {
     global $serendipity;
 
+    if (empty($config_names)) {
+        return false;
+    }
+
+    if ($showSubmit && $postKey != 'plugin') { 
+?>
+    <div style="margin: 0px auto 0px 0px; text-align: right">
+        <input type="submit" name="SAVECONF" value="<?php echo SAVE; ?>" class="serendipityPrettyButton input_button" />
+    </div>
+<?php }
+
     if ($showTable) {
 ?>
     <table id="serendipity_plugin_config" border="0" cellspacing="0" cellpadding="3" width="100%">
@@ -368,6 +379,7 @@ function serendipity_plugin_config(&$plugin, &$bag, &$name, &$desc, &$config_nam
 
     $elcount = 0;
     $htmlnugget = array();
+    
     foreach ($config_names as $config_item) {
         $elcount++;
         $cbag = new serendipity_property_bag;
@@ -666,13 +678,15 @@ EOS;
                 }
                 $cname = $cbag->get('name');
                 $cdesc = $cbag->get('description');
+                $checkable = $cbag->get('checkable');
+
                 /** Unordered array of values */
                 $items = $cbag->get('values');
                 if (!is_array($items)) { $items = null; }
                 /** Array specifying order to use values in $items */
                 $order = null;
                 if ($value) {
-                    $order = explode(',', $value);
+                    $store_order = $order = explode(',', $value);
                 }
                 $uparrow_img = serendipity_getTemplateFile('admin/img/uparrow.png');
                 $downarrow_img = serendipity_getTemplateFile('admin/img/downarrow.png');
@@ -773,6 +787,11 @@ EOS;
                     print '    <li id="'.$id.'" class="sequence_item pluginmanager_item_even">' . "\n";
                     // Make a handle with ID 'g$id'
                     print '      <div id="g'.$id.'" class="pluginmanager_grablet sequence_grablet"><a href="#"></a></div>' . "\n";
+                    
+                    if ($checkable) {
+                        print '         <input type="checkbox" onclick="sort_' . $config_item . '_Sequence();" name="serendipity[' . $postKey . ']' . '[activate][' . $config_item . '][' . $id . ']" ' . (in_array($id, $store_order) ? ' checked="checked" ' : '') . ' value="true" id="activate_' . $id . '" />' . "\n";
+                    }
+
                     // Add the item contents
                     print '      <span>'.$items[$id]['display'].'</span>' . "\n";
                     if (isset($items[$id]['img'])) {
@@ -785,7 +804,7 @@ EOS;
                         print "&nbsp;\n";
                     } else {
                         print <<<EOS
-  <button type="submit" name="serendipity[$postKey][$config_item]" value="$oneup">
+  <button type="submit" name="serendipity[$postKey][override][$config_item]" value="$oneup">
     <img src="$uparrow_img" alt="Move Up">
   </button>
 
@@ -796,7 +815,7 @@ EOS;
                         print "&nbsp;\n";
                     } else {
                         print <<<EOS
-  <button type="submit" name="serendipity[$postKey][$config_item]" value="$onedown">
+  <button type="submit" name="serendipity[$postKey][override][$config_item]" value="$onedown">
     <img src="$downarrow_img" alt="Move Down">
   </button>
 
@@ -815,18 +834,35 @@ EOS;
                 // Print the Javascript to drag-n-drop the list
                 print <<<EOS
 <script type="text/javascript">
+    function sort_${config_item}_Sequence() {
+            //var seq = DragDrop.serData('${config_item}_group', null);
+            var seq = DragDrop.serData(null, '${config_item}');
+            var start = seq.indexOf("(");
+            var end = seq.indexOf(")");
+            seq = seq.slice((start + 1), end);
+            checkable_seq = seq.split(",");
+            out_seq = '';
+            for (i in checkable_seq) {
+                if (document.getElementById('activate_' + checkable_seq[i]) && !document.getElementById('activate_' + checkable_seq[i]).checked) {
+                    continue;
+                } else {
+                    if (out_seq != '') {
+                        out_seq += ',';
+                    }
+
+                    out_seq += checkable_seq[i];
+                }
+            }
+            var order = document.getElementById("${config_item}_value");
+            order.value = out_seq;
+    }
+
     function init_${config_item}_Sequence()
     {
         var lst = document.getElementById("${config_item}");
         DragDrop.makeListContainer(lst, '${config_item}_group');
-        lst.onDragOut = function() { 
-            //var seq = DragDrop.serData('${config_item}_group', null); 
-            var seq = DragDrop.serData(null, '${config_item}'); 
-            var start = seq.indexOf("(");
-            var end = seq.indexOf(")");
-            seq = seq.slice((start + 1), end);
-            var order = document.getElementById("${config_item}_value");
-            order.value = seq;
+        lst.onDragOut = function() {
+            sort_${config_item}_Sequence();
         };
     }
     addLoadEvent(init_${config_item}_Sequence);
