@@ -1,4 +1,4 @@
-<?php # $Id: functions_smarty.inc.php 2189 2008-03-19 11:34:22Z slothman $
+<?php # $Id: functions_smarty.inc.php 2399 2008-12-12 15:50:58Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -165,7 +165,7 @@ function serendipity_ifRemember($name, $value, $isDefault = false, $att = 'check
 function serendipity_smarty_fetchPrintEntries($params, &$smarty) {
     global $serendipity;
     static $entrycount = 0;
-    static $restore_var_GET_keys = array('category', 'viewAuthor', 'page');
+    static $restore_var_GET_keys = array('category', 'viewAuthor', 'page', 'hide_category');
 
     // A counter variable to not assign template files multiple times
     $entrycount++;
@@ -730,7 +730,23 @@ function &serendipity_smarty_printComments($params, &$smarty) {
             );
     }
 
-    $out = serendipity_printComments($comments, $params['mode']);
+    if (empty($params['depth'])) {
+        $params['depth'] = 0;
+    }
+    
+    if (empty($params['trace'])) {
+        $params['trace'] = null;
+    }
+
+    if (empty($params['block'])) {
+        $params['block'] = 'COMMENTS';
+    }
+    
+    if (empty($params['template'])) {
+        $params['template'] = 'comments.tpl';
+    }
+    
+    $out = serendipity_printComments($comments, $params['mode'], $params['depth'], $params['trace'], $params['block'], $params['template']);
     return $out;
 }
 
@@ -751,7 +767,23 @@ function &serendipity_smarty_printTrackbacks($params, &$smarty) {
 
     $trackbacks =& serendipity_fetchTrackbacks($params['entry']);
 
-    $out = serendipity_printComments($trackbacks, VIEWMODE_LINEAR, 0, null, 'TRACKBACKS', 'trackbacks.tpl');
+    if (empty($params['depth'])) {
+        $params['depth'] = 0;
+    }
+
+    if (empty($params['trace'])) {
+        $params['trace'] = null;
+    }
+
+    if (empty($params['block'])) {
+        $params['block'] = 'TRACKBACKS';
+    }
+
+    if (empty($params['template'])) {
+        $params['template'] = 'trackbacks.tpl';
+    }
+
+    $out = serendipity_printComments($trackbacks, VIEWMODE_LINEAR, $params['depth'], $params['trace'], $params['block'], $params['template']);
     return $out;
 }
 
@@ -943,7 +975,7 @@ function serendipity_smarty_init($vars = array()) {
                 'serendipityBaseURL'        => $serendipity['baseURL'],
                 'serendipityRewritePrefix'  => $serendipity['rewrite'] == 'none' ? $serendipity['indexFile'] . '?/' : '',
                 'serendipityIndexFile'      => $serendipity['indexFile'],
-                'serendipityVersion'        => $serendipity['version'],
+                'serendipityVersion'        => ($serendipity['expose_s9y'] ? $serendipity['version'] : ''),
 
                 'lang'                      => $serendipity['lang'],
                 'category'                  => $category,
