@@ -1,4 +1,4 @@
-<?php # $Id: functions_trackbacks.inc.php 1747 2007-07-03 08:19:07Z garvinhicking $
+<?php # $Id: functions_trackbacks.inc.php 2095 2008-01-20 14:16:06Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -34,42 +34,74 @@ function serendipity_trackback_is_success($resp) {
     return true;
 }
 
+/**
+ * Check a HTTP response if it is a valid XML pingback response
+ *
+ * @access public
+ * @param   string  HTTP Response string
+ * @return  mixed   Boolean or error message
+ */
+function serendipity_pingback_is_success($resp) {
+    // This is very rudimentary, but the fault is printed later, so what..
+    if (preg_match('@<fault>@', $resp, $matches)) {
+        return false;
+    }
+    return true;
+}
+
 /**
  * Perform a HTTP query for autodiscovering a pingback URL
  *
  * @access public
- * @param   string  (deprecated) The URL to try autodiscovery
- * @param   string  The response of the original URL
+ * @param   string  The URL to try autodiscovery
+ * @param   string  The HTML of the source URL
+ * @param   string  The URL of our blog article
  * @return
  */
-function serendipity_pingback_autodiscover($loc, $body) {
+function serendipity_pingback_autodiscover($loc, $body, $url=null) {
 global $serendipity;
+
+    // This is the old way, sending pingbacks, for downward compatibility.
+    // But this is wrong, as it does link from the main blog URL instead of the article URL
+    if (!isset($url)) {
+        $url = $serendipity['baseURL'];
+    }
+
     if (!empty($_SERVER['X-PINGBACK'])) {
         $pingback = $_SERVER['X-PINGBACK'];
     } elseif (preg_match('@<link rel="pingback" href="([^"]+)" ?/?>@i', $body, $matches)) {
         $pingback = $matches[1];
     } else {
-        return;
+        echo '<div>&#8226; ' . sprintf(PINGBACK_FAILED, PINGBACK_NOT_FOUND) . '</div>';
+        return false;
     }
 
-    // xml-rpc hack
+    // xml-rpc pingback call
     $query = "
 <?xml version=\"1.0\"?>
 <methodCall>
   <methodName>pingback.ping</methodName>
   <params>
     <param>
-      <name>sourceURI</name>
-      <value><string>{$serendipity['baseURL']}</string></value>
+      <value><string>$url</string></value>
     </param>
     <param>
-      <name>targetURI</name>
       <value><string>$loc</string></value>
     </param>
   </params>
 </methodCall>";
-        _serendipity_send($pingback, $query);
-        return;
+
+    echo '<div>&#8226; ' . sprintf(PINGBACK_SENDING, htmlspecialchars($pingback)) . '</div>';
+    flush();
+
+    $response =  _serendipity_send($pingback, $query, 'text/html');
+    $success  =   serendipity_pingback_is_success($response);
+    if ($success == true) {
+        echo '<div>&#8226; ' . PINGBACK_SENT .'</div>';
+    } else {
+        echo '<div>&#8226; ' . sprintf(PINGBACK_FAILED, $response) . '</div>';
+    }
+    return $success;
 }
 
 /**
@@ -80,7 +112,7 @@ global $serendipity;
  * @param   string  The XML data with the trackback contents
  * @return  string  Reponse
  */
-function _serendipity_send($loc, $data) {
+function _serendipity_send($loc, $data, $contenttype = null) {
     global $serendipity;
 
     $target = parse_url($loc);
@@ -99,6 +131,10 @@ function _serendipity_send($loc, $data) {
     serendipity_request_start();
 
     $req = &new HTTP_Request($uri, $options);
+    if (isset($contenttype)){
+       $req->addHeader('Content-Type', $contenttype);
+    }
+
     $req->addRawPostData($data, true);
     $res = $req->sendRequest();
 
@@ -127,14 +163,26 @@ function _serendipity_send($loc, $data) {
  * @return string   Response
  */
 function serendipity_trackback_autodiscover($res, $loc, $url, $author, $title, $text, $loc2 = '') {
+    $is_wp    = false;
+    $wp_check = false;
+
+    if (preg_match('@((' . preg_quote($loc, '@') . '|' . preg_quote($loc2, '@') . ')/?trackback/)@i', $res, $wp_loc)) {
+        // We found a WP-blog that may not advertise RDF-Tags!
+        $is_wp = true;
+    }
+
     if (!preg_match('@trackback:ping(\s*rdf:resource)?\s*=\s*["\'](https?:[^"\']+)["\']@i', $res, $matches)) {
         $matches = array();
         serendipity_plugin_api::hook_event('backend_trackback_check', $matches, $loc);
 
         // Plugins may say that a URI is valid, in situations where a blog has no valid RDF metadata
         if (empty($matches[2])) {
-            echo '<div>&#8226; ' . sprintf(TRACKBACK_FAILED, TRACKBACK_NOT_FOUND) . '</div>';
-            return false;
+            if ($is_wp) {
+                $wp_check = true;
+            } else {
+                echo '<div>&#8226; ' . sprintf(TRACKBACK_FAILED, TRACKBACK_NOT_FOUND) . '</div>';
+                return false;
+            }
         }
     }
 
@@ -142,11 +190,20 @@ function serendipity_trackback_autodiscover($res, $loc, $url, $author, $title, $
 
     if (preg_match('@dc:identifier\s*=\s*["\'](https?:[^\'"]+)["\']@i', $res, $test)) {
         if ($loc != $test[1] && $loc2 != $test[1]) {
-            echo '<div>&#8226; ' . sprintf(TRACKBACK_FAILED, TRACKBACK_URI_MISMATCH) . '</div>';
-            return false;
+            if ($is_wp) {
+                $wp_check = true;
+            } else {
+                echo '<div>&#8226; ' . sprintf(TRACKBACK_FAILED, TRACKBACK_URI_MISMATCH) . '</div>';
+                return false;
+            }
         }
     }
 
+    // If $wp_check is set it means no RDF metadata was found, and we simply try the /trackback/ url.
+    if ($wp_check) {
+        $trackURI = $wp_loc[0];
+    }
+
     $data = 'url='        . rawurlencode($url)
           . '&title='     . rawurlencode($title)
           . '&blog_name=' . rawurlencode($author)
@@ -189,9 +246,6 @@ global $serendipity;
         return; // Trackbacks to HTTPS URLs can only be performed with openssl activated
     }
 
-    echo '<div>&#8226; '. sprintf(TRACKBACK_CHECKING, $loc) .'</div>';
-    flush();
-
     if (empty($u['port'])) {
         $u['port'] = 80;
         $port      = '';
@@ -206,10 +260,13 @@ global $serendipity;
     $parsed_loc = $u['scheme'] . '://' . $u['host'] . $port . $u['path'];
 
     if (preg_match('@\.(jpe?g|aiff?|gif|png|pdf|doc|rtf|wave?|mp2|mp4|mpe?g3|mpe?g4|divx|xvid|bz2|mpe?g|avi|mp3|xl?|ppt|pps|xslt?|xsd|zip|tar|t?gz|swf|rm|ram?|exe|mov|qt|midi?|qcp|emf|wmf|snd|pmg|w?bmp|gcd|mms|ogg|ogm|rv|wmv|wma|jad|3g?|jar)$@i', $u['path'])) {
-        echo '<div>&#8226; ' . TRACKBACK_NO_DATA . '</div>';
+        // echo '<div>&#8226; ' . TRACKBACK_NO_DATA . '</div>';
         return;
     }
 
+    echo '<div>&#8226; '. sprintf(TRACKBACK_CHECKING, $loc) .'</div>';
+    flush();
+
     require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
     $options = array('allowRedirects' => true, 'maxRedirects' => 5, 'method' => 'GET');
     serendipity_plugin_api::hook_event('backend_http_request', $options, 'trackback_detect');
@@ -227,8 +284,10 @@ global $serendipity;
     serendipity_request_end();
 
     if (strlen($fContent) != 0) {
-        serendipity_trackback_autodiscover($fContent, $parsed_loc, $url, $author, $title, $text, $loc);
-        serendipity_pingback_autodiscover($loc, $fContent);
+        $trackback_result = serendipity_trackback_autodiscover($fContent, $parsed_loc, $url, $author, $title, $text, $loc);
+        if ($trackback_result == false) {
+            serendipity_pingback_autodiscover($parsed_loc, $fContent, $url);
+        }
     } else {
         echo '<div>&#8226; ' . TRACKBACK_NO_DATA . '</div>';
     }
@@ -261,6 +320,9 @@ function add_trackback ($id, $title, $url, $name, $excerpt) {
         $title = $url;
     }
 
+    // Decode HTML Entities
+    $excerpt = trackback_body_strip($excerpt);
+    
     $comment = array(
         'title'   => $title,
         'url'     => $url,
@@ -316,21 +378,185 @@ function add_trackback ($id, $title, $url, $name, $excerpt) {
  */
 function add_pingback ($id, $postdata) {
     global $serendipity;
-
-    if(preg_match('@<methodcall>\s*<methodName>\s*pingback.ping\s*</methodName>\s*<params>\s*<param>\s*<value>\s*<string>([^<]*)</string>\s*</value>\s*</param>\s*<param>\s*<value>\s*<string>([^<]*)</string>\s*</value>\s*</param>\s*</params>\s*</methodCall>@i', $postdata, $matches)) {
+    log_pingback("Reached add_pingback. ID:[$id]");
+    
+    // XML-RPC Method call without named parameter. This seems to be the default way using XML-RPC
+    if(preg_match('@<methodCall>\s*<methodName>\s*pingback.ping\s*</methodName>\s*<params>\s*<param>\s*<value>\s*<string>([^<]*)</string>\s*</value>\s*</param>\s*<param>\s*<value>\s*<string>([^<]*)</string>\s*</value>\s*</param>\s*</params>\s*</methodCall>@is', $postdata, $matches)) {
+        log_pingback("Pingback wp structure.");
         $remote             = $matches[1];
         $local              = $matches[2];
-        $comment['title']   = '';
+        log_pingback("remote=$remote, local=$local");
+        $path = parse_url($remote);
+        $comment['title']   = 'PingBack';
         $comment['url']     = $remote;
         $comment['comment'] = '';
-        $comment['name']    = '';
+        $comment['name']    = $path['host'];
+        fetchPingbackData($comment);
 
-        serendipity_saveComment($id, $comment, 'PINGBACK');
-        return 1;
+        // if no ID parameter was given, try to get one from targetURI
+        if (!isset($id) || $id==0) {
+            log_pingback("ID not found");
+            $id = evaluateIdByLocalUrl($local);
+            log_pingback("ID set to $id");
+        }
+        
+        if ($id>0) {
+            serendipity_saveComment($id, $comment, 'PINGBACK');
+            return 1;
+        } else {
+            return 0;
+        }
     }
+
+    // XML-RPC Method call with named parameter. I'm not sure, if XML-RPC supports this, but just to be sure
+    $sourceURI = getPingbackParam('sourceURI', $postdata);
+    $targetURI = getPingbackParam('targetURI', $postdata);
+    if (isset($sourceURI) && isset($targetURI)) {
+        log_pingback("Pingback spec structure.");
+        $path = parse_url($sourceURI);
+        $local              = $targetURI;
+        $comment['title']   = 'PingBack';
+        $comment['url']     = $sourceURI;
+        $comment['comment'] = '';
+        $comment['name']    = $path['host'];
+        fetchPingbackData($comment);
+
+        // if no ID parameter was given, try to get one from targetURI
+        if (!isset($id) || $id==0) {
+            log_pingback("ID not found");
+            $id = evaluateIdByLocalUrl($local);
+            log_pingback("ID set to $id");
+        }
+        if ($id>0) {
+            serendipity_saveComment($id, $comment, 'PINGBACK');
+            return 1;
+        } else {
+            return 0;
+        }
+    }
+
     return 0;
 }
 
+function evaluateIdByLocalUrl($localUrl) {
+    global $serendipity;
+    
+    // Build an ID searchpattern in configured permaling structure:
+    $permalink_article = $serendipity['permalinkStructure'];
+    log_pingback("perma: $permalink_article");
+    $permalink_article = str_replace('.','\.',$permalink_article);
+    $permalink_article = str_replace('+','\+',$permalink_article);
+    $permalink_article = str_replace('?','\?',$permalink_article);
+    $permalink_article = str_replace('%id%','(\d+)',$permalink_article);
+    $permalink_article = str_replace('%title%','[^/]*',$permalink_article);
+    $permalink_article_regex = '@' . $permalink_article . '$@'; 
+    log_pingback("regex: $permalink_article_regex");
+
+    if (preg_match($permalink_article_regex, $localUrl, $matches)) {
+        return (int)$matches[1];
+    } else {
+        return 0;
+    }
+}
+
+/**
+ * Gets a XML-RPC pingback.ping value by given parameter name
+ * @access private
+ * @param string Name of the paramameter
+ * @param string Buffer containing the pingback XML
+ */
+function getPingbackParam($paramName, $data) {
+    $pattern = "<methodCall>.*?<methodName>\s*pingback.ping\s*</methodName>.*?<params>.*?<param>\s*((<name>\s*$paramName\s*</name>\s*<value>\s*<string>([^<]*)</string>\s*</value>)|(<value>\s*<string>([^<]*)</string>\s*</value>\s*<name>\s*$paramName\s*</name>))\s*</param>.*?</params>.*?</methodCall>";
+    if (preg_match('@' . $pattern .'@is',$data, $matches)) {
+        return $matches[3];
+    } else {
+        return null;
+    }
+}
+
+/**
+ * Fetches additional comment data from the page that sent the pingback
+ * @access private
+ * @param array comment array to be filled
+ */
+function fetchPingbackData( &$comment) {
+    global $serendipity;
+    
+    // Don't fetch remote page, if not explicitly allowed in serendipity_config_local.php:
+    if (empty($serendipity['pingbackFetchPage'])) {
+        return;
+    }
+    
+    // If we don't have a comment or a commentors url, stop it.
+    if (!isset($comment) || !is_array($comment) || !isset($comment['url'])) {
+        return;
+    }
+    
+    // Max amount of characters fetched from the page doing a pingback:
+    $fetchPageMaxLength = 200;
+    if (isset($serendipity['pingbackFetchPageMaxLength'])){
+        $fetchPageMaxLength = $serendipity['pingbackFetchPageMaxLength'];
+    }
+    require_once S9Y_PEAR_PATH . 'HTTP/Request.php';
+    $url = $comment['url'];
+    
+    if (function_exists('serendipity_request_start')) serendipity_request_start();
+    
+    // Request the page
+    $req = &new HTTP_Request($url, array('allowRedirects' => true, 'maxRedirects' => 5, 'timeout' => 20, 'readTimeout' => array(5,0)));
+
+    // code 200: OK, code 30x: REDIRECTION
+    $responses = "/(200 OK)|(30[0-9] Found)/"; // |(30[0-9] Moved)
+    if ((PEAR::isError($req->sendRequest()) || preg_match($responses, $req->getResponseCode()))) {
+        // nothing to do,
+    } 
+    else {
+        $fContent = $req->getResponseBody();
+
+        // Get a title
+        if (preg_match('@<head[^>]*>.*?<title[^>]*>(.*?)</title>.*?</head>@is',$fContent,$matches)) {
+            $comment['title'] = html_entity_decode(strip_tags($matches[1]), ENT_COMPAT, LANG_CHARSET);
+        }
+        
+        // Try to get content from first <p> tag on:
+        if (preg_match('@<p[^>]*>(.*?)</body>@is',$fContent,$matches)) {
+            $body = $matches[1];
+        }
+        if (empty($body) && preg_match('@<body[^>]*>(.*?)</body>@is',$fContent,$matches)){
+            $body = $matches[1];
+        }
+        // Get a part of the article
+        if (!empty($body)) {
+            $body = trackback_body_strip($body);
+
+            // truncate the text to 200 chars
+            $arr = str_split($body, $fetchPageMaxLength);
+            $body = $arr[0];
+
+            $comment['comment'] = $body . '[..]';
+        }
+    }
+    
+    if (function_exists('serendipity_request_end')) serendipity_request_end();
+    
+}
+
+/**
+ * Strips any unneeded code from trackback / pingback bodies returning pure (UTF8) text.
+ */
+function trackback_body_strip( $body ){
+    // replace non brakeable space with normal space:            
+    $body = str_replace('&nbsp;', ' ', $body);
+
+    // strip html entities and tags.
+    $body = html_entity_decode(strip_tags($body), ENT_COMPAT, LANG_CHARSET);
+
+    // replace whitespace with single space            
+    $body = preg_replace('@\s+@s', ' ', $body);
+    
+    return $body;
+}
+
 /**
  * Create an excerpt for a trackback to send
  *
@@ -423,12 +649,13 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
     global $serendipity;
     static $old_references = array();
     static $saved_references = array();
+    static $saved_urls = array();
     static $debug = false;
 
     if ($dry_run) {
         // Store the current list of references. We might need to restore them for later user.
         $old_references = serendipity_db_query("SELECT * FROM {$serendipity['dbPrefix']}references WHERE (type = '' OR type IS NULL) AND entry_id = " . (int)$id, false, 'assoc');
-        
+
         if ($debug && is_string($old_references)) {
             echo $old_references . "<br />\n";
         }
@@ -438,6 +665,7 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
             foreach($old_references AS $idx => $old_reference) {
                 // We need the current reference ID to restore it later.
                 $saved_references[$old_reference['link'] . $old_reference['name']] = $current_references[$old_reference['link'] . $old_reference['name']] = $old_reference;
+                $saved_urls[$old_reference['link']] = true;
             }
         }
         if ($debug) echo "Got references in dry run: <pre>" . print_r($current_references, true) . "</pre><br />\n";
@@ -512,6 +740,12 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
         if ($debug && is_string($row)) {
             echo $row . "<br />\n";
         }
+        
+        $names[$i] = strip_tags($names[$i]);
+        if (empty($names[$i])) {
+            if ($debug) echo "Found reference $locations[$i] w/o name. Adding location as name.";
+            $names[$i] = $locations[$i];
+        }
 
         if ($row[0] > 0 && isset($saved_references[$locations[$i] . $names[$i]])) {
             if ($debug) echo "Found references for $id, skipping rest<br />\n";
@@ -520,10 +754,13 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
 
         if (!isset($serendipity['noautodiscovery']) || !$serendipity['noautodiscovery']) {
             if (!$dry_run) {
-                if ($debug) echo "Enabling autodiscovery.<br />\n";
-                serendipity_reference_autodiscover($locations[$i], $url, $author, $title, serendipity_trackback_excerpt($text));
+                if (!isset($saved_urls[$locations[$i]])){
+                    if ($debug) echo "Enabling autodiscovery.<br />\n";
+                    serendipity_reference_autodiscover($locations[$i], $url, $author, $title, serendipity_trackback_excerpt($text));
+                }
+                elseif ($debug) echo "This reference was already used before in $id and therefore will not be trackbacked again.<br/>\n";
             } elseif ($debug) {
-                echo "Skipping autodiscovery<br />\n";
+                echo "Dry run: Skipping autodiscovery<br />\n";
             }
             $checked_locations[$locations[$i]] = true; // Store trackbacked link so that no further trackbacks will be sent to the same link
         } elseif ($debug) {
@@ -545,7 +782,7 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
     for ($i = 0; $i < $j; ++$i) {
         $i_link     = serendipity_db_escape_string(strip_tags($names[$i]));
         $i_location = serendipity_db_escape_string($locations[$i]);
-        
+
         // No link with same description AND same text should be inserted.
         if (isset($duplicate_check[$i_location . $i_link])) {
             continue;
@@ -575,13 +812,13 @@ function serendipity_handle_references($id, $author, $title, $text, $dry_run = f
             );
             $duplicate_check[$i_location . $i_link] = true;
         }
-        
+
         if ($debug) {
             echo "Current lookup for {$locations[$i]}{$names[$i]} is <pre>" . print_r($current_references[$locations[$i] . $names[$i]], true) . "</pre><br />\n";
             echo $query . "<br />\n";
         }
     }
-    
+
     if ($debug) {
         echo "Old/Saved locations: <pre>" . print_r($old_references, true) . "</pre><br />\n";
     }
@@ -619,4 +856,5 @@ function is_utf8($string) {
          . '|[\xF1-\xF3][\x80-\xBF]{3}'          # planes 4-15
          . '|\xF4[\x80-\x8F][\x80-\xBF]{2}'      # plane 16
          . ')*$%xs', $string);
-}
\ No newline at end of file
+}
+
