@@ -1,4 +1,4 @@
-<?php # $Id: genpage.inc.php 1520 2006-11-30 21:34:29Z garvinhicking $
+<?php # $Id: genpage.inc.php 2358 2008-10-19 10:48:12Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -45,9 +45,16 @@ if ($serendipity['smarty_raw_mode']) {
         case 'read':
             if (isset($serendipity['GET']['id'])) {
                 $entry = array(serendipity_fetchEntry('id', $serendipity['GET']['id']));
-                if (!is_array($entry) || count($entry) < 1) {
+                if (!is_array($entry) || count($entry) < 1 || !is_array($entry[0])) {
                     unset($serendipity['GET']['id']);
                     $entry = array(array());
+                    $serendipity['head_title'] = htmlspecialchars($serendipity['blogTitle']); 
+                    $serendipity['head_subtitle'] = ''; 
+                    $serendipity['smarty']->assign('head_title', $serendipity['head_title']); 
+                    $serendipity['smarty']->assign('head_subtitle', $serendipity['head_subtitle']); 
+                    $serendipity['view'] = '404';
+                    serendipity_header('HTTP/1.0 404 Not found');                    
+                    serendipity_header('Status: 404 Not found');                    
                 }
 
                 serendipity_printEntries($entry, 1);
@@ -109,6 +116,16 @@ if ($serendipity['smarty_raw_mode']) {
             serendipity_printArchives();
             break;
 
+
+        case 'custom':
+            if ($serendipity['smarty_custom_vars']) {
+                $serendipity['smarty']->assign($serendipity['smarty_custom_vars']);
+            }
+            break;
+
+        case 'empty':
+            break;
+
         // Welcome screen or whatever
         default:
             serendipity_printEntries(serendipity_fetchEntries(null, true, $serendipity['fetchLimit']));
