@@ -1,4 +1,4 @@
-<?php # $Id: plugin_api.inc.php 2132 2008-02-21 09:42:50Z garvinhicking $
+<?php # $Id: plugin_api.inc.php 2316 2008-08-22 09:20:13Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -830,6 +830,11 @@ class serendipity_plugin_api
         if (count($plugins) == 0) {
             $serendipity['prevent_sidebar_plugins_' . $side] = true;
         }
+        
+        $loggedin = false;
+        if (serendipity_userLoggedIn() && serendipity_checkPermission('adminPlugins')) {
+            $loggedin = true;
+        }
 
         foreach ($plugins AS $plugin_data) {
             $plugin =& serendipity_plugin_api::load_plugin($plugin_data['name'], $plugin_data['authorid'], $plugin_data['path']);
@@ -842,6 +847,10 @@ class serendipity_plugin_api
                 $show_plugin = $plugin->generate_content($title);
                 $content = ob_get_contents();
                 ob_end_clean();
+                
+                if ($loggedin) {
+                    $content .= '<div class="serendipity_edit_nugget"><a href="' . $serendipity['serendipityHTTPPath'] . 'serendipity_admin.php?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=' . htmlentities($plugin->instance) . '">' . EDIT . '</a></div>';
+                }
 
                 if ($show_plugin !== false) {
                     $pluginData[] = array('side'    => $side,
