@@ -1,4 +1,4 @@
-<?php # $Id: plugin_internal.inc.php 2191 2008-03-20 09:17:25Z garvinhicking $
+<?php # $Id: plugin_internal.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -470,6 +470,14 @@ class serendipity_archives_plugin extends serendipity_plugin {
         $show_count = serendipity_db_bool($this->get_config('show_count', false));
         $hide_zero_count = serendipity_db_bool($this->get_config('hide_zero_count', false));
         $freq = $this->get_config('frequency', 'months');
+
+        echo '<ul>' . "\n";
+        
+        if ($serendipity['dbType'] == 'sqlite' || $serendipity['dbType'] == 'sqlite3') {
+            $dist_sql = 'count(e.id) AS orderkey';
+        } else {
+            $dist_sql = 'count(DISTINCT e.id) AS orderkey';
+        }
         
         for($x = 0; $x < $max_x; $x++) {
             $current_ts = $ts;
@@ -546,11 +554,11 @@ class serendipity_archives_plugin extends serendipity_plugin {
                     '',
                     false,
                     false,
-                    'timestamp DESC',
+                    null,
                     '',
                     false,
                     true,
-                    'count(e.id) AS orderkey',
+                    $dist_sql,
                     '',
                     'single',
                     false, $category_set // the joins used
@@ -566,12 +574,13 @@ class serendipity_archives_plugin extends serendipity_plugin {
             }
 
             if (!$hidden_by_zero_count) {
-                echo '<a href="' . $link . '" title="' . $ts_title . '">' . $ts_title . $html_count . '</a><br />' . "\n";
+                echo '<li><a href="' . $link . '" title="' . $ts_title . '">' . $ts_title . $html_count . '</a></li>' . "\n";
             }
         }
 
-        echo '<a href="'. $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] . '?frontpage">' . RECENT . '</a><br />' . "\n";
-        echo '<a href="'. serendipity_rewriteURL(PATH_ARCHIVE . $add_query) .'">' . OLDER . '</a>'. "\n";
+        echo '<li><a href="'. $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'] . '?frontpage">' . RECENT . '</a></li>' . "\n";
+        echo '<li><a href="'. serendipity_rewriteURL(PATH_ARCHIVE . $add_query) .'">' . OLDER . '</a></li>'. "\n";
+        echo '</ul>' . "\n";
     }
 }
 
@@ -744,6 +753,9 @@ class serendipity_syndication_plugin extends serendipity_plugin {
                                         'fb_title',
                                         'fb_alt',
                                         'fb_img',
+                                        'big_img',
+                                        'feed_name',
+                                        'comment_name',
                                        )
         );
         $propbag->add('groups',        array('FRONTEND_VIEWS'));
@@ -957,6 +969,26 @@ class serendipity_syndication_plugin extends serendipity_plugin {
                 $propbag->add('default',     '');
                 break;
 
+            case 'big_img':
+                $propbag->add('type',        'string');
+                $propbag->add('name',        SYNDICATION_PLUGIN_BIGIMG);
+                $propbag->add('description', SYNDICATION_PLUGIN_BIGIMG_DESC);
+                $propbag->add('default',     '');
+                break;
+
+            case 'feed_name':
+                $propbag->add('type',        'string');
+                $propbag->add('name',        SYNDICATION_PLUGIN_FEEDNAME);
+                $propbag->add('description', SYNDICATION_PLUGIN_FEEDNAME_DESC);
+                $propbag->add('default',     '');
+                break;
+
+             case 'comment_name':
+                $propbag->add('type',        'string');
+                $propbag->add('name',        SYNDICATION_PLUGIN_COMMENTNAME);
+                $propbag->add('description', SYNDICATION_PLUGIN_COMMENTNAME_DESC);
+                $propbag->add('default',     '');
+                break;
 
             default:
                 return false;
@@ -971,74 +1003,100 @@ class serendipity_syndication_plugin extends serendipity_plugin {
         $title = $this->get_config('title');
         $icon  = serendipity_getTemplateFile($this->get_config('iconURL', 'img/xml.gif'));
 
-        if (serendipity_db_bool($this->get_config('show_0.91', true))) {
+        $custom_feed = trim($this->get_config('feed_name'));
+        $custom_comm = trim($this->get_config('comment_name'));
+        $custom_img  = trim($this->get_config('big_img'));
+
+        if (empty($custom_feed) || $custom_feed == 'default' || $custom_feed == 'none' || $custom_feed == 'empty') {
+            $FEED = 'feed';
+        } else {
+            $FEED = $custom_feed;
+        }
+
+        if (empty($custom_comm) || $custom_comm == 'default' || $custom_comm == 'none' || $custom_comm == 'empty') {
+            $COMMENTS = COMMENTS;
+        } else {
+            $COMMENTS = $custom_comm;
+        }
+
+        if (!empty($custom_img) && $custom_img != 'default' && $custom_img != 'none' && $custom_img != 'empty') {
 ?>
         <div style="padding-bottom: 2px;">
-            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>">RSS 0.91 feed</a>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo $custom_img; ?>" alt="XML" style="border: 0px" /></a>
         </div>
 <?php
         }
 
+?><ul><?php
+
+        if (serendipity_db_bool($this->get_config('show_0.91', true))) {
+?>
+        <li>
+            <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss', 'serendipityHTTPPath') ?>">RSS 0.91 <?php echo $FEED; ?></a>
+        </li>
+<?php
+        }
+
         if (serendipity_db_bool($this->get_config('show_1.0', true))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>">RSS 1.0 feed</a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss1', 'serendipityHTTPPath') ?>">RSS 1.0 <?php echo $FEED; ?></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_2.0', true))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>">RSS 2.0 feed</a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath') ?>">RSS 2.0 <?php echo $FEED; ?></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_atom0.3', true))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="ATOM/XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>">ATOM 0.3 feed</a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom03.xml', 'serendipityHTTPPath') ?>">ATOM 0.3 <?php echo $FEED; ?></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_atom1.0', true))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="ATOM/XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>">ATOM 1.0 feed</a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/atom10.xml', 'serendipityHTTPPath') ?>">ATOM 1.0 <?php echo $FEED; ?></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_2.0c', true))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><span style="white-space: nowrap">RSS 2.0 <?php echo COMMENTS; ?></span></a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/comments.rss2', 'serendipityHTTPPath') ?>"><span style="white-space: nowrap">RSS 2.0 <?php echo $COMMENTS; ?></span></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_opml1.0', false))) {
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
             <a class="serendipity_xml_icon" href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>"><img src="<?php echo $icon; ?>" alt="XML" style="border: 0px" /></a>
-            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>">OPML 1.0 feed</a>
-        </div>
+            <a href="<?php echo serendipity_rewriteURL(PATH_FEEDS .'/opml.xml', 'serendipityHTTPPath') ?>">OPML 1.0 <?php echo $FEED; ?></a>
+        </li>
 <?php
         }
 
         if (serendipity_db_bool($this->get_config('show_googlereader', false))) {
 ?>
-        <div style="padding-bottom: 2px;" class="serendipity_googlereader">
+        <li class="serendipity_googlereader">
             <a href="http://fusion.google.com/add?source=atgs&amp;feedurl=<?php echo urlencode(rtrim($serendipity['baseURL'], '/') . serendipity_rewriteURL(PATH_FEEDS .'/index.rss2', 'serendipityHTTPPath')); ?>"><img src="http://buttons.googlesyndication.com/fusion/add.gif" border="0" alt="Add to Google"></a>
-        </div>
+        </li>
 <?php
         }
 
@@ -1050,16 +1108,17 @@ class serendipity_syndication_plugin extends serendipity_plugin {
 				$img = 'http://feeds.feedburner.com/~fc/'.$this->get_config('fb_id').'?bg=99CCFF&amp;fg=444444&amp;anim=0';
 			}
 ?>
-        <div style="padding-bottom: 2px;">
+        <li>
 			<a href="<?php echo $url; ?>"<?php if (strlen($alt) > 0) echo " title=\"$alt\""; ?>><img src="<?php echo $img; ?>" alt="" style="border:0"/></a>
             <?php
 			$mytitle = $this->get_config('fb_title');
 			if (strlen($mytitle) > 0) { ?>
 			<a href="<?php echo $url; ?>"><?php echo $mytitle; ?></a>
             <?php } ?>
-		</div>
+	</li>
 <?php
-		}
+        }
+        echo '</ul>';
     }
 
     function generate_rss_fields(&$title, &$description, &$entries) {
@@ -1348,6 +1407,7 @@ class serendipity_html_nugget_plugin extends serendipity_plugin {
             echo $this->get_config('content');
         }
 
+/* THIS FUNCTIONALITY IS NOW IN THE CORE, YET A BIT REDUCED [performance]
         if (serendipity_userLoggedIn()) {
             $is_plugin_owner    = ($this->serendipity_owner == $serendipity['authorid'] || serendipity_checkPermission('adminPluginsMaintainOthers'));
 
@@ -1355,6 +1415,7 @@ class serendipity_html_nugget_plugin extends serendipity_plugin {
                 echo '<div class="serendipity_edit_nugget"><a href="' . $serendipity['baseURL'] . '/serendipity_admin.php?serendipity[adminModule]=plugins&amp;serendipity[plugin_to_conf]=' . htmlentities($this->instance) . '">' . EDIT . '</a></div>';
             }
         }
+*/
     }
 }
 
@@ -1368,7 +1429,7 @@ class serendipity_categories_plugin extends serendipity_plugin {
         $propbag->add('description', CATEGORY_PLUGIN_DESC);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Serendipity Team');
-        $propbag->add('version',       '2.02');
+        $propbag->add('version',       '2.03');
         $propbag->add('configuration', array('title', 'authorid', 'parent_base', 'hide_parent', 'image', 'sort_order', 'sort_method', 'allow_select', 'hide_parallel', 'show_count', 'smarty'));
         $propbag->add('groups',        array('FRONTEND_VIEWS'));
     }
@@ -1583,6 +1644,7 @@ class serendipity_categories_plugin extends serendipity_plugin {
                 // Hide parents outside of our tree
                 if ($hide_parallel && $serendipity['GET']['category']) {
                     if ($hidedepth == 0 && $cat['parentid'] != $serendipity['GET']['category'] && $cat['categoryid'] != $serendipity['GET']['category']) {
+                        unset($categories[$cid]);
                         continue;
                     } else {
                         if ($cat['depth'] < $hidedepth) {
@@ -1605,6 +1667,7 @@ class serendipity_categories_plugin extends serendipity_plugin {
                 if (!empty($cat_count[$cat['categoryid']])) {
                     $categories[$cid]['true_category_name'] = $cat['category_name'];
                     $categories[$cid]['category_name'] .= ' (' . $cat_count[$cat['categoryid']] . ')';
+                    $categories[$cid]['article_count'] = $cat_count[$cat['categoryid']];
                 }
 
                 if (!$smarty) {
@@ -1738,12 +1801,14 @@ class serendipity_authors_plugin extends serendipity_plugin {
         $html       = '';
 
         if ($is_form) {
-            $html .= '<form action="' . $serendipity['baseURL'] . $serendipity['indexFile'] . '?frontpage" method="post"><div>';
+            $html .= '<form action="' . $serendipity['baseURL'] . $serendipity['indexFile'] . '?frontpage" method="post">';
         }
 
         $image = $this->get_config('image', serendipity_getTemplateFile('img/xml.gif'));
         $image = (($image == "'none'" || $image == 'none') ? '' : $image);
 
+        $html .= '<ul>' . "\n";
+
         if (is_array($authors) && count($authors)) {
             foreach ($authors as $auth) {
 
@@ -1756,7 +1821,7 @@ class serendipity_authors_plugin extends serendipity_plugin {
                     $entrycount = "";
                 }
 
-                $html .= '<div style="padding-bottom: 2px;">';
+                $html .= '<li>';
 
                 if ($is_form) {
                     $html .= '<input style="width: 15px" type="checkbox" name="serendipity[multiAuth][]" value="' . $auth['authorid'] . '" />';
@@ -1766,16 +1831,18 @@ class serendipity_authors_plugin extends serendipity_plugin {
                     $html .= '<a class="serendipity_xml_icon" href="'. serendipity_feedAuthorURL($auth, 'serendipityHTTPPath') .'"><img src="'. $image .'" alt="XML" style="border: 0px" /></a> ';
                 }
                 $html .= '<a href="'. serendipity_authorURL($auth, 'serendipityHTTPPath') .'" title="'. htmlspecialchars($auth['realname']) .'">'. htmlspecialchars($auth['realname']) . $entrycount . '</a>';
-                $html .= '</div>' . "\n";
+                $html .= '</li>' . "\n";
             }
         }
 
+        $html .= '</ul>' . "\n";
+
         if ($is_form) {
-            $html .= '<br /><input type="submit" name="serendipity[isMultiAuth]" value="' . GO . '" /><br />';
+            $html .= '<div><input type="submit" name="serendipity[isMultiAuth]" value="' . GO . '" /></div>';
         }
 
         $html .= sprintf(
-            '<br /><a href="%s" title="%s">%s</a>',
+            '<div><a href="%s" title="%s">%s</a></div>',
 
             $serendipity['serendipityHTTPPath'] . $serendipity['indexFile'],
             ALL_AUTHORS,
@@ -1783,7 +1850,7 @@ class serendipity_authors_plugin extends serendipity_plugin {
         );
 
         if ($is_form) {
-            $html .= '</div></form>';
+            $html .= '</form>';
         }
         print $html;
     }
