@@ -1,4 +1,4 @@
-<?php # $Id: config_local.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: config_local.inc.php 2371 2008-11-12 13:32:24Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -35,7 +35,7 @@
                                     array('var'         => 'dbPass',
                                           'title'       => INSTALL_DBPASS,
                                           'description' => INSTALL_DBPASS_DESC,
-                                          'type'        => 'protected',
+                                          'type'        => 'fullprotected',
                                           'default'     => '',
                                           'permission'  => 'siteConfiguration',
                                           'flags'       => array('nosave', 'hideValue', 'simpleInstall')),
@@ -319,13 +319,6 @@
                                           'permission'  => 'siteConfiguration',
                                           'flags'       => array('installOnly', 'local')),
 
-                                    array('var'         => 'allowSubscriptions',
-                                          'title'       => INSTALL_SUBSCRIBE,
-                                          'description' => INSTALL_SUBSCRIBE_DESC,
-                                          'type'        => 'bool',
-                                          'permission'  => 'siteConfiguration',
-                                          'default'     => true),
-
                                     array('var'         => 'blogTitle',
                                           'title'       => INSTALL_BLOGNAME,
                                           'description' => INSTALL_BLOGNAME_DESC,
@@ -349,6 +342,27 @@
                                           'permission'  => 'blogConfiguration',
                                           'default'     => ''),
 
+                                    array('var'         => 'allowSubscriptions',
+                                          'title'       => INSTALL_SUBSCRIBE,
+                                          'description' => INSTALL_SUBSCRIBE_DESC,
+                                          'type'        => 'list',
+                                          'default'     => array('true' => YES, 'false' => NO, 'fulltext' => FULL_COMMENT_TEXT),
+                                          'permission'  => 'siteConfiguration'),
+
+                                    array('var'         => 'allowSubscriptionsOptIn',
+                                          'title'       => INSTALL_SUBSCRIBE_OPTIN,
+                                          'description' => INSTALL_SUBSCRIBE_OPTIN_DESC,
+                                          'type'        => 'bool',
+                                          'default'     => true,
+                                          'permission'  => 'siteConfiguration'),
+
+                                    array('var'         => 'useCommentTokens',
+                                          'title'       => COMMENT_TOKENS,
+                                          'description' => COMMENT_TOKENS_DESC,
+                                          'type'        => 'bool',
+                                          'default'     => false,
+                                          'permission'  => 'blogConfiguration'), 
+
                                     array('var'         => 'lang',
                                           'title'       => INSTALL_LANG,
                                           'description' => INSTALL_LANG_DESC,
@@ -522,6 +536,16 @@
                                           'permission'  => 'siteConfiguration',
                                           'default'     => 110),
 
+                                    array('var'         => 'thumbConstraint',
+                                          'title'       => INSTALL_THUMBDIM,
+                                          'description' => INSTALL_THUMBDIM_DESC,
+                                          'type'        => 'list',
+                                          'permission'  => 'siteConfiguration',
+                                          'default'     => array(
+                                              'largest' => INSTALL_THUMBDIM_LARGEST,
+                                              'width'   => INSTALL_THUMBDIM_WIDTH,
+                                              'height'  => INSTALL_THUMBDIM_HEIGHT)),
+
                                     array('var'         => 'maxFileSize',
                                           'title'       => MEDIA_UPLOAD_SIZE,
                                           'description' => MEDIA_UPLOAD_SIZE_DESC,
