@@ -1,4 +1,4 @@
-<?php # $Id: index.php 2098 2008-01-29 19:11:04Z garvinhicking $
+<?php # $Id: index.php 2362 2008-10-23 13:50:54Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -18,6 +18,7 @@ if ($global_debug) {
 // We need to set this to return a 200 since we use .htaccess ErrorDocument
 // rules to handle archives.
 header('HTTP/1.0 200');
+header('Status: 200 OK');
 
 // Session are needed to also remember an autologin user on the frontend
 ob_start();
@@ -56,6 +57,8 @@ if (preg_match(PAT_UNSUBSCRIBE, $uri, $res)) {
     define('DATA_UNSUBSCRIBED', false);
 }
 
+serendipity_checkCommentTokenModeration($uri);
+
 if (preg_match(PAT_DELETE, $uri, $res) && $serendipity['serendipityAuthedUser'] === true) {
     if ($res[1] == 'comment' && serendipity_deleteComment($res[2], $res[3], 'comments')) {
         define('DATA_COMMENT_DELETED', sprintf(COMMENT_DELETED, $res[2]));
@@ -275,6 +278,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
             if (serendipity_saveComment($serendipity['POST']['entry_id'], $comment, 'NORMAL')) {
                 $sc_url = ($_SERVER['HTTPS'] == 'on' ? 'https://' : 'http://') . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI'] . (strstr($_SERVER['REQUEST_URI'], '?') ? '&' : '?') . 'serendipity[csuccess]=' . (isset($serendipity['csuccess']) ? $serendipity['csuccess'] : 'true');
                 if (serendipity_isResponseClean($sc_url)) {
+                    header('Status: 302 Found');
                     header('Location: ' . $sc_url);
                 }
                 exit;
@@ -304,6 +308,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     } else {
         $serendipity['view'] = '404';
         header('HTTP/1.0 404 Not found');
+        header('Status: 404 Not found');
     }
 
     ob_start();
@@ -362,6 +367,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     if (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] == 'on') {
         $base = str_replace('http://', 'https://', $base);
     }
+    header('Status: 302 Found');
     header("Location: {$base}serendipity_admin.php");
     exit;
 } else if (preg_match(PAT_ARCHIVE, $uri)) {
@@ -439,12 +445,12 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
         $matches[1] = serendipity_searchPermalink($serendipity['permalinkCategoryStructure'], implode('/', $_args), $matches[1], 'category');
         $serendipity['GET']['category'] = $matches[1];
     }
-
     $cInfo = serendipity_fetchCategoryInfo($serendipity['GET']['category']);
 
     if (!is_array($cInfo)) {
         $serendipity['view'] = '404';
         header('HTTP/1.0 404 Not found');
+        header('Status: 404 Not found');
     } else {
         $serendipity['head_title']    = $cInfo['category_name'];
         $serendipity['head_subtitle'] = $serendipity['blogTitle'];
@@ -490,6 +496,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
     if (!is_array($uInfo)) {
         $serendipity['view'] = '404';
         header('HTTP/1.0 404 Not found');
+        header('Status: 404 Not found');
     } else {
         $serendipity['head_title']    = sprintf(ENTRIES_BY, $uInfo[0]['realname']);
         $serendipity['head_subtitle'] = $serendipity['blogTitle'];
@@ -602,6 +609,7 @@ if (preg_match(PAT_ARCHIVES, $uri, $matches) || isset($serendipity['GET']['range
 } else {
     $serendipity['view'] = '404';
     header('HTTP/1.0 404 Not found');
+    header('Status: 404 Not found');
     include(S9Y_INCLUDE_PATH . 'include/genpage.inc.php');
     // printf('<div class="serendipity_msg_important">' . DOCUMENT_NOT_FOUND . '</div>', $uri);
 }
