@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_cn.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_cn.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by
@@ -90,7 +90,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', '发生错误, 文件没有上传，可能因为你的文件超过限制的大小， 请询问你的主机商或修改你的 php.ini 文件属性。');
 @define('GO', '继续');
 @define('NEWSIZE', '大小: ');
-@define('RESIZE_BLAHBLAH', '<b>重设大小 %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>重设大小 %s</b>');
 @define('ORIGINAL_SIZE', '原有的大小: <i>%sx%s</i> 像素');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>在这里你可以修改图片大小！如果你要修改成相同的图片比例, 你只需要输入一个数值然后按 TAB -- 系统会自动帮你计算比例以免出错。</p>');
 @define('QUICKJUMP_CALENDAR', '日历快速跳跃');
@@ -204,6 +204,10 @@
 @define('RESIZING', '重设大小');
 @define('RESIZE_DONE', '完成 (重设 %s 个图片)');
 @define('SYNCING', '进行数据库和图片文件夹数据同步');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', '完成 (同步了 %s 个图片)');
 @define('FILE_NOT_FOUND', '找不到文件 <b>%s</b>, 可能已被删除');
 @define('ABORT_NOW', '放弃');
@@ -330,6 +334,10 @@
 @define('TOP_LEVEL', '最高层');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', '权限');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', '新设定已经被保存到 %s');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', '缩图会以下面的格式重新命名: original.[后置字符].ext');
 @define('INSTALL_THUMBWIDTH', '缩图大小');
 @define('INSTALL_THUMBWIDTH_DESC', '自动建立缩图的最大宽度');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', '个人资料设定');
@@ -681,7 +697,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', '作者的静态连接');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', '这里可以让你设定以基本位置来计算文章的相对连接。你可以用以下参数：%id%, %realname%, %username%, %email% 或其它字符。');
 @define('INSTALL_PERMALINK_CATEGORY', '类别的静态连接');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', '这里可以让你设定以基本位置来计算文章的相对连接。你可以用以下参数：%id%, %name%, %description% 或其它字符。');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', '这里可以让你设定以基本位置来计算文章的相对连接。你可以用以下参数：%id%, %name%, %parentname%, %description% 或其它字符。');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-Feed 类别的静态连接');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '这里可以让你设定以基本位置来计算 RSS-Feed 类别文章的相对连接。你可以用以下参数：%id%, %name%, %description% 或其它字符。');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', '保存文件路径');
@@ -901,3 +917,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
