@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_cz.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_cz.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Josef Klimosz <ok2wo@centrum.cz>
@@ -98,7 +98,7 @@ $i18n_filename_to = array (
 @define('ERROR_FILE_EXISTS_ALREADY', 'Chyba: Soubor už ve vašem počítači existuje!');
 @define('GO', 'Provést!');
 @define('NEWSIZE', 'Nový rozměr: ');
-@define('RESIZE_BLAHBLAH', '<b>Změnit rozměr %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Změnit rozměr %s</b>');
 @define('ORIGINAL_SIZE', 'Původní rozměr: <i>%sx%s</i> pixelů');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Zde můžete zadat nový rozměr obrázku. Pokud chcete zachovat proporce, zadejte jen jednu hodnotu a stiskněte klávesu TAB, nový rozměr bude dopočítán automaticky:');
 @define('QUICKJUMP_CALENDAR', 'Vyhledávací kalendář');
@@ -200,6 +200,10 @@ $i18n_filename_to = array (
 @define('RESIZING', 'Změna rozměrů');
 @define('RESIZE_DONE', 'Hotovo (upraven rozměr %s obrázků).');
 @define('SYNCING', 'Synchronizace databáze s adresářem obrázků');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Hotovo (synchronizováno %s obrázků).');
 @define('DELETE_IMAGE_FAIL' , 'Nelze vymazat obrázek <b>%s</b>');
 @define('DELETE_THUMBNAIL', 'Vymazán náhled obrázku s názvem <b>%s</b>');
@@ -321,6 +325,10 @@ $i18n_filename_to = array (
 @define('SKIPPING_FILE_UNREADABLE', 'Vynechán soubor: %s nelze načíst.');
 @define('FOUND_FILE', 'Založit nový/změnit soubor: %s.');
 @define('PERMISSIONS', 'Oprávnění');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 
 /* DATABASE SETTINGS */
 @define('INSTALL_CAT_DB', 'Databáze');
@@ -403,6 +411,14 @@ $i18n_filename_to = array (
 @define('INSTALL_THUMBSUFFIX_DESC', 'Náhledy budou pojmenovány original.sufix.ext');
 @define('INSTALL_THUMBWIDTH', 'Rozměry náhledů');
 @define('INSTALL_THUMBWIDTH_DESC', 'Pevná šířka automaticky generovaných náhledů');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Osobní nastavení');
@@ -690,7 +706,7 @@ $i18n_filename_to = array (
 @define('INSTALL_PERMALINK_AUTHOR', 'Struktura URL autorů');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné příspěvky určitých autorů.  Můžete použít proměnné %id%, %realname%, %username%, %email% a jakékoli jiné znaky.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Struktura URL kategorií');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné určité kategorie. Můžete použít proměnné  %id%, %name%, %description% a jakékoli jiné znaky.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné určité kategorie. Můžete použít proměnné  %id%, %name%, %parentname%, %description% a jakékoli jiné znaky.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Struktura URL trvalých odkazů kategorií RSS');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Zde můžete definovat relativní strukturu URL, kde začátek je vaše base URL, z níž mohou být dostupné  RSS kanály z určitých kategorií. Můžete použít proměnné %id%, %name%, %description% a jakékoli jiné znaky.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Cesta k archivům');
@@ -909,3 +925,29 @@ $i18n_filename_to = array (
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
