@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_de.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_de.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Jannis Hermanns, Garvin Hicking and others
@@ -23,16 +23,12 @@
 @define('CONFIGURE_PLUGINS', 'Plugins verwalten');
 @define('CONFIGURATION', 'Konfiguration');
 @define('BACK_TO_BLOG', 'Zurück zum Blog');
+@define('LOGIN', 'Login');
 @define('LOGOUT', 'Abmelden');
 @define('LOGGEDOUT', 'Abgemeldet.');
 @define('CREATE', 'Erstellen');
 @define('SAVE', 'Speichern');
 @define('NAME', 'Name');
-@define('NEW_TRACKBACK_TO', 'Neues Trackback für');
-@define('NEW_COMMENT_TO', 'Neuer Kommentar für');
-@define('RECENT', 'Das Neueste ...');
-@define('OLDER', 'Älteres ...');
-@define('ANONYMOUS', 'Anonym');
 @define('CREATE_NEW_CAT', 'Neue Kategorie');
 @define('I_WANT_THUMB', 'Ich möchte die Vorschau im Eintrag haben.');
 @define('I_WANT_BIG_IMAGE', 'Ich möchte das große Bild im Eintrag haben.');
@@ -40,6 +36,11 @@
 @define('I_WANT_IT_TO_LINK', 'Das Bild soll hierhin linken:');
 @define('BACK', 'Zurück');
 @define('FORWARD', 'Vorwärts');
+@define('ANONYMOUS', 'Anonym');
+@define('NEW_TRACKBACK_TO', 'Neues Trackback für');
+@define('NEW_COMMENT_TO', 'Neuer Kommentar für');
+@define('RECENT', 'Das Neueste ...');
+@define('OLDER', 'Älteres ...');
 @define('DONE', 'Fertig');
 @define('WELCOME_BACK', 'Willkommen zurück,');
 @define('TITLE', 'Titel');
@@ -85,7 +86,7 @@
 @define('ERROR_FILE_EXISTS_ALREADY', 'Fehler: Diese Datei existiert schon auf dem Server!');
 @define('GO', 'Los!');
 @define('NEWSIZE', 'Neue Größe ');
-@define('RESIZE_BLAHBLAH', '<b>Größe von %s ändern</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Größe von %s ändern</b>');
 @define('ORIGINAL_SIZE', 'Originalgröße: <i>%sx%s</i> Pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hier können Sie die Bildgröße ändern. Um die Proportionen beizubehalten, einfach einen der beiden Werte eingeben, und anschließend die TAB-Taste drücken, und Sie erhalten eine Vorschau mit korrekten Proportionen.');
 @define('DATE_FORMAT_1', 'd.m.Y');
@@ -253,6 +254,10 @@
 @define('SIDEBAR_PLUGINS', 'Seitenleisten-Plugins');
 @define('EVENT_PLUGINS', 'Ereignis-Plugins');
 @define('SYNCING', 'Synchronisiere Datenbank mit Bilder-Ordner');
+@define('SYNC_OPTION_LEGEND', 'Optionen für die Erzeugung der Vorschaubilder');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Behalte alle vorhandenen Vorschaubilder');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Behalte vorhandene Vorschaubilder nur, wenn diese die richtige Größe haben');
+@define('SYNC_OPTION_DELETETHUMBS', 'Erneuere alle Vorschaubilder');
 @define('SYNC_DONE', 'Fertig (%s Bilder synchronisiert).');
 @define('SORT_ORDER', 'Sortierung');
 @define('SORT_ORDER_NAME', 'Dateiname');
@@ -315,6 +320,10 @@
 @define('TOP_LEVEL', 'Ursprung');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s Feed');
 @define('PERMISSIONS', 'Rechte');
+@define('INTEGRITY', 'Installation prüfen');
+@define('CHECKSUMS_NOT_FOUND', 'Fehler beim Vergleich der Prüfsummen! (Keine Prüfsummendatei checksums.inc.php im Hauptverzeichnis gefunden)');
+@define('CHECKSUMS_PASS', 'Alle erforderlichen Dateien wurden überprüft.');
+@define('CHECKSUM_FAILED', '%s beschädigt oder verändert: Überprüfung fehlgeschlagen');
 @define('XML_IMAGE_TO_DISPLAY', 'XML-Button');
 @define('XML_IMAGE_TO_DISPLAY_DESC','Bilddatei, um ein Icon für XML-Feeds darzustellen. Für das Standardbild leer lassen, oder \'none\' zum Deaktivieren.');
 @define('SETTINGS_SAVED_AT', 'Die neuen Einstellungen wurden um %s gespeichert.');
@@ -398,10 +407,18 @@
 @define('INSTALL_IMAGEMAGICK_DESC', 'Ist ImageMagick installiert? Verwendet ansonsten die GDLib.');
 @define('INSTALL_IMAGEMAGICKPATH', 'Pfad zur convert ImageMagick-Datei');
 @define('INSTALL_IMAGEMAGICKPATH_DESC', 'Voller Pfad und Name zur Image-Magick Datei');
-@define('INSTALL_THUMBSUFFIX', 'Thumbnail-Endung');
-@define('INSTALL_THUMBSUFFIX_DESC', 'Thumbnails werden nach dem Schema originalname.Suffix.erweiterung benannt.');
-@define('INSTALL_THUMBWIDTH', 'Thumbnailgröße');
-@define('INSTALL_THUMBWIDTH_DESC', 'Maximale Breite/Höhe der automatisch erzeugten Thumbnails');
+@define('INSTALL_THUMBSUFFIX', 'Vorschaubild-Endung');
+@define('INSTALL_THUMBSUFFIX_DESC', 'Vorschaubilder werden nach dem Schema originalname.Suffix.erweiterung benannt.');
+@define('INSTALL_THUMBWIDTH', 'Vorschaubildgröße');
+@define('INSTALL_THUMBWIDTH_DESC', 'Maximale Breite/Höhe der automatisch erzeugten Vorschaubildes');
+@define('INSTALL_THUMBDIM', 'Bestimmung der maximalen Vorschaubildgröße');
+@define('INSTALL_THUMBDIM_LARGEST', 'Längste Seite');
+@define('INSTALL_THUMBDIM_WIDTH', 'Breite');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Höhe');
+@define('INSTALL_THUMBDIM_DESC', 'Legt fest, wie die Größe der Thumbnails angepasst werden soll. Der Standard 
+    "' . INSTALL_THUMBDIM_LARGEST .  '" nutzt die größte Seite als Beschränkung, so dass weder Breite noch Höhe die festgelegte Zahl überschreiten dürfen.
+    "' . INSTALL_THUMBDIM_WIDTH . '" und "' .  INSTALL_THUMBDIM_HEIGHT . '" 
+    legen lediglich die Höhe bzw. Breite als größte Seite fest, so dass die jeweils andere Angabe auch größer als die festgelegte Zahl sein darf.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Persönliche Einstellungen');
@@ -490,7 +507,6 @@
 @define('DELETE_FILE', 'Datei namens <b>%s</b> gelöscht');
 @define('ABOUT_TO_DELETE_FILE', 'Sie beabsichtigen, die Datei <b>%s</b> zu löschen.<br />Wenn Sie die Datei in einem Ihrer Einträge verwenden, wird das Löschen Lücken erzeugen.<br />Soll trotzdem fortgefahren werden?<br /><br />');
 @define('A_NEW_TRACKBACK_BLAHBLAH', 'Ein neues Trackback für den Blog-Eintrag namens "%s" wurde empfangen.');
-@define('LOGIN', 'Login');
 @define('TRACKBACK_SENDING', 'Sende Trackback zu URI %s ...');
 @define('TRACKBACK_SENT', 'Trackback erfolgreich!');
 @define('TRACKBACK_FAILED', 'Trackback gescheitert: %s');
@@ -679,7 +695,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Permalink-Struktur für Autoren-URLs');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der Artikel von gewählten Autoren dargestellt werden. Die Variablen %id%, %realname%, %username%, %email% und alle anderen normalen Zeichen sind möglich.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Permalink-Struktur für Kategorie-URLs');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewählte Kategorien dargestellt werden. Die Variablen %id%, %name%, %description% und alle anderen normalen Zeichen sind möglich.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewählte Kategorien dargestellt werden. Die Variablen %id%, %name%, %parentname%, %description% und alle anderen normalen Zeichen sind möglich.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink-Struktur für RSS-Kategorien-Feed URLs');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewählte RSS-Feeds von Kategorien dargestellt werden. Die Variablen %id%, %name%, %description% und alle anderen normalen Zeichen sind möglich.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Pfad zu den Einträgen');
@@ -757,7 +773,7 @@
 @define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Mediendaten löschen');
 @define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Mediendaten anderer Benutzer verwalten');
 @define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Mediendaten ansehen');
-@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Thumbnails synchronisieren');
+@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Vorschaubilder synchronisieren');
 @define('PERMISSION_ADMINCOMMENTS', 'adminComments: Kommentare verwalten');
 @define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Templates verwalten');
 @define('INSTALL_BLOG_EMAIL', 'E-Mail-Adresse des Blogs');
@@ -887,13 +903,39 @@
 @define('USERCONF_CREATE_DESC', 'Wenn diese Option aktiviert ist, wird dieser Benutzer keine Möglichkeit mehr haben Einträge anzulegen oder sonstige Aktionen auszuführen. Wenn er in die Administrations-Oberfläche kommt, wird er nichts anderes tun können als seine Persönlichen Einstellungen zu ändern und sich auszuloggen.');
 @define('CATEGORY_HIDE_SUB', 'Artikel von Unterkategorien verstecken?');
 @define('CATEGORY_HIDE_SUB_DESC', 'Standardmäßig werden bei der Ansicht einer Kategorie im Frontend alle Artikel der gewählten Kategorie und aller Unterkategorien angezeigt. Wenn diese Option aktiviert wird, werden Artikel von Unterkategorien nicht angezeigt.');
-@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
-@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
-
-@define('SET_TO_MODERATED', 'Moderieren');
-@define('COMMENT_MODERATED', 'Kommentar #%s wurde erfolgreich moderiert.');
 @define('PINGBACK_SENDING', 'Sende pingback an URI %s...');
 @define('PINGBACK_SENT', 'Pingback erfolgreich');
 @define('PINGBACK_FAILED', 'Pingback fehlgeschlagen: %s');
 @define('PINGBACK_NOT_FOUND', 'Keine pingback-URI gefunden.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Versteckt den Archiv-Link, wenn es keine Einträge für einen Zeitraum gab (benötigt das Zählen der Einträge)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS Import, benötigt PHP5 und kann viel RAM/Speicher benötigen.');
+
+@define('SET_TO_MODERATED', 'Moderieren');
+@define('COMMENT_MODERATED', 'Kommentar #%s wurde erfolgreich moderiert.');
 @define('CENTER', 'mitte');
+@define('FULL_COMMENT_TEXT', 'Ja, mit vollständigen Kommentar-Texten.');
+
+@define('COMMENT_TOKENS', 'Schnelle Kommentar-Moderation verwenden?');
+@define('COMMENT_TOKENS_DESC', 'Diese Methode setzt Tokens ein, damit Kommentare direkt aus der Hinweis-E-Mail heraus gelöscht oder akzeptiert werden können. Diese Funktion ist für höheren Komfort gedacht, geht aber zu Lasten der Sicherheit: Wenn jemand die E-Mail abfängt, kann diese Person entsprechende Kommentare ohne weitere Authentifikation löschen oder freischalten.');
+@define('COMMENT_NOTOKENMATCH', 'Der Kommentar-Link ist nicht mehr gültig, oder Kommentar #%s wurde bereits akzeptiert oder gelöscht.');
+@define('TRACKBACK_NOTOKENMATCH', 'Der Kommentar-Link ist nicht mehr gültig, oder Trackback #%s wurde bereits akzeptiert oder gelöscht.');
+@define('BADTOKEN', 'Ungültiger Kommentar-Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hallo %s,\n\nSie haben einen neuen Kommentar zu \"%s\" erstellt. Ihr Kommentar war:\n\n%s\n\nDer Betreiber dieses Blogs hat die Bestätigung per E-Mail gewünscht, daher müssen Sie folgenden Link anklicken:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hallo %s,\n\nSie haben einen neuen Kommentar zu \"%s\" erstellt. Ihr Kommentar war:\n\n%s\n\nDer Betreiber dieses Blogs hat die Bestätigung per E-Mail gewünscht, daher müssen Sie folgenden Link anklicken:\n<%s>\n\nNachdem Sie dies getan haben, können Sie auf dem Blog jederzeit mit ihrem Namen und E-Mail-Adresse ohne weitere Freischaltung kommentieren.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Benutze Double-Opt In für Abonnements von Kommentarbenachrichtigungen?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'Falls aktiviert, wird einem Kommentator, der E-Mail-Benachrichtigung zu neuen Kommentaren abonnieren möchte, eine E-Mail geschickt. Diese enthält einen Bestätigungslink nach dem z.B. für Deutsche Gesetze erforderlichen Opt-In-Schema.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hallo %s,\n\nSie haben bei ihrem Blog-Kommentar zu dem Eintrag \"%s\" auf <%s> das Abonnement neuer Kommentare gewünscht. Um dies zu bestätigen (\"Double Opt In\") klicken Sie bitte diesen Link:\n<%s>\n");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Die Bestätigung des Abonnements der Kommentarbenachrichtigung wurde erfolgreich verarbeitet.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Die Bestätigung ihres Kommentars wurde erfolgreich verarbeitet.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Ihre Bestätigung des Abonnements einer Kommentarbenachrichtigung konnte nicht verarbeitet werden. Bitte prüfen Sie den Link, den Sie geklickt haben, auf Vollständigkeit. Falls dieser Link vor mehr als 3 Wochen gesendet wurde, müssen Sie eine neue E-Mail anfordern.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Ihre Bestätigung des Kommentars konnte nicht verarbeitet werden. Bitte prüfen Sie den Link, den Sie geklickt haben, auf Vollständigkeit. Falls dieser Link vor mehr als 3 Wochen gesendet wurde, müssen Sie ihr Kommentar erneut senden.');
+@define('PLUGIN_DOCUMENTATION', 'Dokumentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Lokale Dokumentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Versionsgeschichte');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
