@@ -60,7 +60,7 @@
 @define('NAME', 'Név');
 @define('EMAIL', 'email');
 @define('HOMEPAGE', 'Honlap');
-@define('COMMENT', 'Hozzászólás');
+@define('COMMENT', 'Megjegyzés');
 @define('REMEMBER_INFO', 'Megjegyezzem a megadott adatokat? ');
 @define('SUBMIT_COMMENT', 'Hozzászólás beküldése');
 @define('NO_ENTRIES_TO_PRINT', 'Nincs mit megjeleníteni');
@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Ismeretlen hiba történt, a fájl nincs feltöltve. Talán a fájl mérete nagyobb mint a szerveren beállított megengedett maximum érték. Ezt a beállítást a szerver üzemeltetője tudja megváltoztatni.');
 @define('GO', 'OK');
 @define('NEWSIZE', 'Új méret: ');
-@define('RESIZE_BLAHBLAH', '<b>Átméretezés %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Átméretezés %s</b>');
 @define('ORIGINAL_SIZE', 'Eredeti méret: <i>%sx%s</i> képpont');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Itt módosíthatja a kép méretét. Ha arányosan szeretné a képet átméretezni, elég az egyik dobozban módosítani a számot,majd megnyomni a TAB billentyűt -- az új méret automatikusan kerül meghatározásra, így a kép nem lesz aránytalan</p>');
 @define('QUICKJUMP_CALENDAR', 'Gyors naptárra ugrás');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'Átméretezés');
 @define('RESIZE_DONE', 'Kész (%s kép átméretezve).');
 @define('SYNCING', 'Szinkronizálom az adatbázist a képek könyvtárával.');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Kész (%s képet szinkronizáltam).');
 @define('FILE_NOT_FOUND', 'Nem találom a <b>%s</b> fájlt, lehet, hogy már törölve lett?');
 @define('ABORT_NOW', 'Azonnali megszakítás');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'Legfelső szint');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s hírcsatorna');
 @define('PERMISSIONS', 'Jogosultságok');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Az új beállításokat elmentettük ekkor: %s');
 
 /* DATABASE SETTINGS */
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'A képekből generált előnézeti képek ilyen nevűek lesznek: eredetinév.[előtag].kiterj');
 @define('INSTALL_THUMBWIDTH', 'Előnézeti kép méretek');
 @define('INSTALL_THUMBWIDTH_DESC', 'Az automatikusan generált előnézeti képek szélességének maximuma');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Személyes adatok');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Szerzőre vonatkozó permanens hivatkozás URL struktúrája');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Itt adhatod meg a relatív URL struktúrát az alap URL-hez képest, ahonnan a szerzőre mutató hivatkozások elérhetőek lesznek. Használhatod a következő változókat: %id%, %realname%, %username%, %email% és egyéb karaktereket is.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Kategóriára vonatkozó permanens hivatkozás URL struktúrája');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Itt adhatod meg a relatív URL struktúrát az alap URL-hez képest, ahonnan a kategóriára mutató hivatkozások elérhetőek lesznek. Használhatod a következő változókat: %id%, %name%, %description% és egyéb karaktereket is.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Itt adhatod meg a relatív URL struktúrát az alap URL-hez képest, ahonnan a kategóriára mutató hivatkozások elérhetőek lesznek. Használhatod a következő változókat: %id%, %name%, %parentname%, %description% és egyéb karaktereket is.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS hírcsatornára vonatkozó permanens hivatkozás URL struktúrája');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Itt adhatod meg a relatív URL struktúrát az alap URL-hez képest, ahonnan az RSS hírcsatornára mutató hivatkozások elérhetőek lesznek. Használhatod a következő változókat: %id%, %name%, %description% és egyéb karaktereket is.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Archívumok útvonala');
@@ -897,3 +913,29 @@
 @define('PINGBACK_NOT_FOUND', 'Nem található hivatkozás az URL létezés ellenőrzéséhez.');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Az archívum hivatkozás elrejtése, ha nincs abban az időszakban bejegyzés (a bejegyzések számolása szükséges)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS importálása, PHP5 szükséges, és lehet hogy sok memóriát igényel');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
