@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_is.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_is.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation by Örn Arnarson <orn@arnarson.net>
@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Óþekkt villa hefur komið upp, skrá ekki vistuð. Kannski var stærð skráarinnar meiri heldur en hámarksstærðin sem netjónninn skilgreinir. Hafðu samband við þjónustuaðilann þinn eða breytti php.ini skránni til að leyfa stærri skráarflutninga.');
 @define('GO', 'Go!');
 @define('NEWSIZE', 'Ný stærð: ');
-@define('RESIZE_BLAHBLAH', '<b>Breyta stærð %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Breyta stærð %s</b>');
 @define('ORIGINAL_SIZE', 'Upprunaleg stærð: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hér getur þú breytt stærð myndarinnar. Ef þú vilt breyta stærð hennar í réttum hlutföllum, sláðu þá inn eitthvað gildi í annan tveggja reitanna og ýttu á TAB takkann. -- Stærð þeirra verður reiknuð sjálfvirkt svo hlutföllin haldist rétt.</p>');
 @define('QUICKJUMP_CALENDAR', 'QuickJump dagatal');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'Breyti stærð');
 @define('RESIZE_DONE', 'Búin (breytti stærð %s mynda).');
 @define('SYNCING', 'Samhæfi gagnagrunn við myndamöppu');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Búin (Samhæfði %s myndir).');
 @define('FILE_NOT_FOUND', 'Fann ekki skrána <b>%s</b>, kannski er þegar búið að eyða henni?');
 @define('ABORT_NOW', 'Hætta við núna');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'Toppstigi');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s straumur');
 @define('PERMISSIONS', 'Réttindi');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Nýju stillingarnar voru vistaðar klukkan %s');
 
 /* DATABASE SETTINGS */
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Sýnishorn verða nefnd eftir eftirfarandi forsniði: upprunalegt.[viðskeyti].end');
 @define('INSTALL_THUMBWIDTH', 'Stærð sýnishorna');
 @define('INSTALL_THUMBWIDTH_DESC', 'Staðlað hágildi breiddar framkallaðra sýnishorna');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Persónulegu upplýsingar þínar');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Uppbygging varanlegra hlekkja slóða höfundar');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hér geturðu skilgreint slóðauppbygginguna, allt frá upphafsslóð til þess hvar færslur frá ákveðnum höfundum kynnu að vera til staðar. Þú getur notað breyturnar %id%, %realname%, %username%, %email% Og alla aðra stafi.');
 @define('INSTALL_PERMALINK_CATEGORY', 'URL uppbygging varanlegra hlekkja flokka');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hér geturðu skilgreint slóðauppbygginguna, allt frá upphafsslóð til þess hvar færslur úr ákveðnum flokkum kynnu að vera til staðar. Þú getur notað breyturnar %id%, %name%, %description% og alla aðra stafi.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hér geturðu skilgreint slóðauppbygginguna, allt frá upphafsslóð til þess hvar færslur úr ákveðnum flokkum kynnu að vera til staðar. Þú getur notað breyturnar %id%, %name%, %parentname%, %description% og alla aðra stafi.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'URL uppbygging varanlegra RSS-strauma flokka');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hér geturðu skilgreint slóðauppbygginguna, allt frá upphafsslóð til þess hvar RSS-straumar úr ákveðnum flokkum kynnu að vera til staðar. Þú getur notað breyturnar %id%, %name%, %description% og alla aðra stafi.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Slóð til skjalasafna');
@@ -900,3 +916,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
