@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_nl.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_nl.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Christiaan Heerze <webmaster@heimp.nl>
@@ -90,7 +90,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Er is een onbekende fout opgetreden, het bestand is niet verzonden. Misschien is het bestand groter dan uw server toestaat. Controleer dit bij uw provider of bewerk uw php.ini zodat deze grotere bestanden toelaat.');
 @define('GO', 'Uitvoeren!');
 @define('NEWSIZE', 'Nieuwe grootte: ');
-@define('RESIZE_BLAHBLAH', '<b>Vergroten/Verkleinen %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Vergroten/Verkleinen %s</b>');
 @define('ORIGINAL_SIZE', 'Originele grootte: <i>%sx%s</i> pixels');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hier kunt u de grootte van de afbeelding aanpassen. Als u de afbeeldingsverhoudingen wilt behouden, voer dan in één van de velden een waarde in en druk op de TAB-toets -- Het programma zal dan zelf de andere grootte berekenen zodat de verhoudingen hetzelfde blijven</p>');
 @define('QUICKJUMP_CALENDAR', 'Quickjump Kalender');
@@ -204,6 +204,10 @@
 @define('RESIZING', 'Grootte aanpassen');
 @define('RESIZE_DONE', 'Gereed (%s afbeeldingen aangepast).');
 @define('SYNCING', 'Bezig met het synchroniseren van de databank met de map waar de afbeeldingen in staan');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Gereed (%s afbeeldingen gesynchroniseerd).');
 @define('FILE_NOT_FOUND', 'Kan bestand <b>%s</b> niet vinden, mogelijk is deze reeds verwijderd.');
 @define('ABORT_NOW', 'Annuleren');
@@ -330,6 +334,10 @@
 @define('TOP_LEVEL', 'Bovenste niveau');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s-toevoer');
 @define('PERMISSIONS', 'Toegangsrechten');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'De instellingen zijn opgeslagen in %s');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Miniaturen krijgen een naam volgens het formaat: origineel.[achtervoegsel].ext');
 @define('INSTALL_THUMBWIDTH', 'Formaat miniaturen');
 @define('INSTALL_THUMBWIDTH_DESC', 'Maximale breedte van automatisch aangemaakte miniaturen');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Uw persoonlijke gegevens');
@@ -678,7 +694,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Permanente hyperlink Auteur URL-structuur');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot artikelen van bepaalde auteurs beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %realname%, %username%, %email% en andere karakters.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Permanente hyperlink Categorie URL-structuur');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot de artikelen van bepaalde categorieën beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %name%, %description% en andere karakters.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot de artikelen van bepaalde categorieën beschikbaar worden. U kunt gebruikmaken van de variabelen %id%, %name%, %parentname%, %description% en andere karakters.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permanente hyperlink Verzamelpublicatie Categorie URL-structuur');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hier kunt u de relatieve URL-structuur bepalen, startend van je basis-URL tot waar de verzamelpublicaties van bepaalde categorieën vrijkomen. U kunt gebruikmaken van de variabelen %id%, %name%, %description% en andere karakters.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Pad naar archieven');
@@ -901,3 +917,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
