@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 2083 2008-01-03 15:02:22Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 2384 2008-11-26 12:33:29Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -90,7 +90,7 @@ $i18n_unknown = 'tw';
 @define('ERROR_UNKNOWN_NOUPLOAD', '未知的錯誤發生, 檔案還沒上傳. 也許你的檔案大於限制的大小. 請詢問您的 ISP 或修改您的 php.ini 檔.');
 @define('GO', '繼續!');
 @define('NEWSIZE', '新大小: ');
-@define('RESIZE_BLAHBLAH', '<b>重設大小 %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>重設大小 %s</b>');
 @define('ORIGINAL_SIZE', '原有的大小: <i>%sx%s</i> 像素');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>在這裡您可以修改圖片大小. 如果您要修改成相同的圖片比例, 您只需要輸入一個數值然後按 TAB -- 系統會自動幫您計算比例以免出錯</p>');
 @define('QUICKJUMP_CALENDAR', '日曆快速跳躍');
@@ -204,6 +204,10 @@ $i18n_unknown = 'tw';
 @define('RESIZING', '重設大小');
 @define('RESIZE_DONE', '完成 (重設 %s 個圖片).');
 @define('SYNCING', '進行資料庫和圖片檔案夾同步化');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', '完成 (同步了 %s 個圖片).');
 @define('FILE_NOT_FOUND', '找不到檔案名稱 <b>%s</b>, 也許已經被刪除了?');
 @define('ABORT_NOW', '放棄');
@@ -330,6 +334,10 @@ $i18n_unknown = 'tw';
 @define('TOP_LEVEL', '最高層');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', '權限');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', '新設定已經儲存於 %s');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@ $i18n_unknown = 'tw';
 @define('INSTALL_THUMBSUFFIX_DESC', '縮圖會以下面的格式重新命名: 原檔名.[後置字元].ext');
 @define('INSTALL_THUMBWIDTH', '縮圖尺度');
 @define('INSTALL_THUMBWIDTH_DESC', '自動建立縮圖的最大寬度');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', '個人資料設定');
@@ -680,7 +696,7 @@ $i18n_unknown = 'tw';
 @define('INSTALL_PERMALINK_AUTHOR', '作者的靜態連接');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', '這裡可以讓您設定以基底位址來計算作者文章的相對連結。您可以用以下變數：%id%, %realname%, %username%, %email% 或其他字串。');
 @define('INSTALL_PERMALINK_CATEGORY', '類別的靜態連接');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', '這裡可以讓您設定以基底位址來計算類別文章的相對連結。您可以用以下變數：%id%, %name%, %description% 或其他字串。');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', '這裡可以讓您設定以基底位址來計算類別文章的相對連結。您可以用以下變數：%id%, %name%, %parentname%, %description% 或其他字串。');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-Feed 類別的靜態連接');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '這裡可以讓您設定以基底位址來計算 RSS-Feed 類別文章的相對連結。您可以用以下變數：%id%, %name%, %description% 或其他字串。');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', '保存文庫路徑');
@@ -904,3 +920,29 @@ $i18n_unknown = 'tw';
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
