@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_bg.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_bg.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) 2004 Bogomil Shopov <bogomil@spisanie.com>
@@ -89,7 +89,7 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('ERROR_FILE_EXISTS_ALREADY', ':    !');
 @define('GO', '');
 @define('NEWSIZE', ' : ');
-@define('RESIZE_BLAHBLAH', '<b>    %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>    %s</b>');
 @define('ORIGINAL_SIZE', ' : <i>%s&#215;%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>       .      ,          TAB.      ,      .');
 @define('QUICKSEARCH', ' ');
@@ -141,7 +141,7 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('COMMENTS_ENABLE', '     ');
 @define('COMMENTS_CLOSED', '      ');
 @define('EMPTY_COMMENT', '    , , %s %s   ');
-@define('ENTRIES_FOR', '  %s');
+@define('ENTRIES_FOR', ',   %s');
 @define('DOCUMENT_NOT_FOUND', ' %s   .');
 @define('USERNAME', '');
 @define('PASSWORD', '');
@@ -188,6 +188,10 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('RESIZING', '  ');
 @define('RESIZE_DONE', ' (    %s ).');
 @define('SYNCING', '       ');
+@define('SYNC_OPTION_LEGEND', '    ');
+@define('SYNC_OPTION_KEEPTHUMBS', '    ');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', '   ,     ');
+@define('SYNC_OPTION_DELETETHUMBS', '   ');
 @define('SYNC_DONE', ' (  %s ).');
 @define('DELETE_FILE_FAIL' , '      <b>%s</b>');
 @define('DELETE_THUMBNAIL', '  ,  <b>%s</b>');
@@ -363,6 +367,10 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('TOP_LEVEL', '');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', ' %s');
 @define('PERMISSIONS', '');
+@define('INTEGRITY', '   ');
+@define('CHECKSUMS_NOT_FOUND', '     ! (  checksums.inc.php   )');
+@define('CHECKSUMS_PASS', '    .');
+@define('CHECKSUM_FAILED', '%s   :  ');
 @define('SETTINGS_SAVED_AT', '     %s');
 @define('INSTALL_CAT_DB', '   ');
 @define('INSTALL_CAT_DB_DESC', '        . Serendipity    ,     ');
@@ -436,6 +444,14 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('INSTALL_THUMBSUFFIX_DESC', '      : .[].');
 @define('INSTALL_THUMBWIDTH', '  ');
 @define('INSTALL_THUMBWIDTH_DESC', '      ');
+@define('INSTALL_THUMBDIM', '   ');
+@define('INSTALL_THUMBDIM_LARGEST', '-');
+@define('INSTALL_THUMBDIM_WIDTH', '');
+@define('INSTALL_THUMBDIM_HEIGHT', '');
+@define('INSTALL_THUMBDIM_DESC', ',      .   "' . 
+    INSTALL_THUMBDIM_LARGEST .  '"    ,          -   ; "' . 
+    INSTALL_THUMBDIM_WIDTH . '"  "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '"    ,      -   .');
 @define('USERCONF_CAT_PERSONAL', ' ');
 @define('USERCONF_CAT_PERSONAL_DESC', '    ');
 @define('USERCONF_USERNAME', ' ');
@@ -668,7 +684,7 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('INSTALL_PERMALINK_AUTHOR', '     ');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', '       URL   URL,       .     %id%, %realname%, %username%, %email%    .');
 @define('INSTALL_PERMALINK_CATEGORY', '     ');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', '       URL   URL,       .     %id%, %name%, %description%    .');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', '       URL   URL,       .     %id%, %name%, %parentname%, %description%    .');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', '       RSS');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '       URL   URL,       .     %id%, %name%, %description%    .');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', '  ');
@@ -890,3 +906,29 @@ $i18n_filename_to   = array('-', 'a', 'A', 'b', 'B', 'v', 'V', 'g', 'G', 'd', 'D
 @define('SET_TO_MODERATED', '');
 @define('COMMENT_MODERATED', ' #%s     ');
 @define('CENTER', '');
+@define('FULL_COMMENT_TEXT', ',     ');
+
+@define('COMMENT_TOKENS', '  Tokens    ?');
+@define('COMMENT_TOKENS_DESC', '   tokens,             e-mail,          . ,    ,   email  ,          .');
+@define('COMMENT_NOTOKENMATCH', '       #%s      ');
+@define('TRACKBACK_NOTOKENMATCH', '       #%s      ');
+@define('BADTOKEN', '   '); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', " %s,\n\n  ()     \"%s\".   :\n\n%s\n\n     e-mail ,        ,     :\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', " %s,\n\n  ()     \"%s\".   :\n\n%s\n\n      e-mail ,        ,     :\n<%s>\n\n   ,             e-mail       .");
+@define('INSTALL_SUBSCRIBE_OPTIN', '       ?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', '  ,           ,    ,        .         ( ).');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', " %s,\n\n          \"%s\" (<%s>).     (\"Double Opt In\")    :\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', '          .');
+@define('NOTIFICATION_CONFIRM_MAIL', '      .');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', '        .   ,   .          ,      email  .');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', '      .    ,   .          ,       .');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
