@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_de.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_de.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) Jannis Hermanns, Garvin Hicking and others
@@ -23,16 +23,12 @@
 @define('CONFIGURE_PLUGINS', 'Plugins verwalten');
 @define('CONFIGURATION', 'Konfiguration');
 @define('BACK_TO_BLOG', 'Zurck zum Blog');
+@define('LOGIN', 'Login');
 @define('LOGOUT', 'Abmelden');
 @define('LOGGEDOUT', 'Abgemeldet.');
 @define('CREATE', 'Erstellen');
 @define('SAVE', 'Speichern');
 @define('NAME', 'Name');
-@define('NEW_TRACKBACK_TO', 'Neues Trackback fr');
-@define('NEW_COMMENT_TO', 'Neuer Kommentar fr');
-@define('RECENT', 'Das Neueste ...');
-@define('OLDER', 'lteres ...');
-@define('ANONYMOUS', 'Anonym');
 @define('CREATE_NEW_CAT', 'Neue Kategorie');
 @define('I_WANT_THUMB', 'Ich mchte die Vorschau im Eintrag haben.');
 @define('I_WANT_BIG_IMAGE', 'Ich mchte das groe Bild im Eintrag haben.');
@@ -40,6 +36,11 @@
 @define('I_WANT_IT_TO_LINK', 'Das Bild soll hierhin linken:');
 @define('BACK', 'Zurck');
 @define('FORWARD', 'Vorwrts');
+@define('ANONYMOUS', 'Anonym');
+@define('NEW_TRACKBACK_TO', 'Neues Trackback fr');
+@define('NEW_COMMENT_TO', 'Neuer Kommentar fr');
+@define('RECENT', 'Das Neueste ...');
+@define('OLDER', 'lteres ...');
 @define('DONE', 'Fertig');
 @define('WELCOME_BACK', 'Willkommen zurck,');
 @define('TITLE', 'Titel');
@@ -85,7 +86,7 @@
 @define('ERROR_FILE_EXISTS_ALREADY', 'Fehler: Diese Datei existiert schon auf dem Server!');
 @define('GO', 'Los!');
 @define('NEWSIZE', 'Neue Gre ');
-@define('RESIZE_BLAHBLAH', '<b>Gre von %s ndern</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Gre von %s ndern</b>');
 @define('ORIGINAL_SIZE', 'Originalgre: <i>%sx%s</i> Pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hier knnen Sie die Bildgre ndern. Um die Proportionen beizubehalten, einfach einen der beiden Werte eingeben, und anschlieend die TAB-Taste drcken, und Sie erhalten eine Vorschau mit korrekten Proportionen.');
 @define('DATE_FORMAT_1', 'd.m.Y');
@@ -253,6 +254,10 @@
 @define('SIDEBAR_PLUGINS', 'Seitenleisten-Plugins');
 @define('EVENT_PLUGINS', 'Ereignis-Plugins');
 @define('SYNCING', 'Synchronisiere Datenbank mit Bilder-Ordner');
+@define('SYNC_OPTION_LEGEND', 'Optionen fr die Erzeugung der Vorschaubilder');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Behalte alle vorhandenen Vorschaubilder');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Behalte vorhandene Vorschaubilder nur, wenn diese die richtige Gre haben');
+@define('SYNC_OPTION_DELETETHUMBS', 'Erneuere alle Vorschaubilder');
 @define('SYNC_DONE', 'Fertig (%s Bilder synchronisiert).');
 @define('SORT_ORDER', 'Sortierung');
 @define('SORT_ORDER_NAME', 'Dateiname');
@@ -315,6 +320,10 @@
 @define('TOP_LEVEL', 'Ursprung');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s Feed');
 @define('PERMISSIONS', 'Rechte');
+@define('INTEGRITY', 'Installation prfen');
+@define('CHECKSUMS_NOT_FOUND', 'Fehler beim Vergleich der Prfsummen! (Keine Prfsummendatei checksums.inc.php im Hauptverzeichnis gefunden)');
+@define('CHECKSUMS_PASS', 'Alle erforderlichen Dateien wurden berprft.');
+@define('CHECKSUM_FAILED', '%s beschdigt oder verndert: berprfung fehlgeschlagen');
 @define('XML_IMAGE_TO_DISPLAY', 'XML-Button');
 @define('XML_IMAGE_TO_DISPLAY_DESC','Bilddatei, um ein Icon fr XML-Feeds darzustellen. Fr das Standardbild leer lassen, oder \'none\' zum Deaktivieren.');
 @define('SETTINGS_SAVED_AT', 'Die neuen Einstellungen wurden um %s gespeichert.');
@@ -398,10 +407,18 @@
 @define('INSTALL_IMAGEMAGICK_DESC', 'Ist ImageMagick installiert? Verwendet ansonsten die GDLib.');
 @define('INSTALL_IMAGEMAGICKPATH', 'Pfad zur convert ImageMagick-Datei');
 @define('INSTALL_IMAGEMAGICKPATH_DESC', 'Voller Pfad und Name zur Image-Magick Datei');
-@define('INSTALL_THUMBSUFFIX', 'Thumbnail-Endung');
-@define('INSTALL_THUMBSUFFIX_DESC', 'Thumbnails werden nach dem Schema originalname.Suffix.erweiterung benannt.');
-@define('INSTALL_THUMBWIDTH', 'Thumbnailgre');
-@define('INSTALL_THUMBWIDTH_DESC', 'Maximale Breite/Hhe der automatisch erzeugten Thumbnails');
+@define('INSTALL_THUMBSUFFIX', 'Vorschaubild-Endung');
+@define('INSTALL_THUMBSUFFIX_DESC', 'Vorschaubilder werden nach dem Schema originalname.Suffix.erweiterung benannt.');
+@define('INSTALL_THUMBWIDTH', 'Vorschaubildgre');
+@define('INSTALL_THUMBWIDTH_DESC', 'Maximale Breite/Hhe der automatisch erzeugten Vorschaubildes');
+@define('INSTALL_THUMBDIM', 'Bestimmung der maximalen Vorschaubildgre');
+@define('INSTALL_THUMBDIM_LARGEST', 'Lngste Seite');
+@define('INSTALL_THUMBDIM_WIDTH', 'Breite');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Hhe');
+@define('INSTALL_THUMBDIM_DESC', 'Legt fest, wie die Gre der Thumbnails angepasst werden soll. Der Standard 
+    "' . INSTALL_THUMBDIM_LARGEST .  '" nutzt die grte Seite als Beschrnkung, so dass weder Breite noch Hhe die festgelegte Zahl berschreiten drfen.
+    "' . INSTALL_THUMBDIM_WIDTH . '" und "' .  INSTALL_THUMBDIM_HEIGHT . '" 
+    legen lediglich die Hhe bzw. Breite als grte Seite fest, so dass die jeweils andere Angabe auch grer als die festgelegte Zahl sein darf.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Persnliche Einstellungen');
@@ -490,7 +507,6 @@
 @define('DELETE_FILE', 'Datei namens <b>%s</b> gelscht');
 @define('ABOUT_TO_DELETE_FILE', 'Sie beabsichtigen, die Datei <b>%s</b> zu lschen.<br />Wenn Sie die Datei in einem Ihrer Eintrge verwenden, wird das Lschen Lcken erzeugen.<br />Soll trotzdem fortgefahren werden?<br /><br />');
 @define('A_NEW_TRACKBACK_BLAHBLAH', 'Ein neues Trackback fr den Blog-Eintrag namens "%s" wurde empfangen.');
-@define('LOGIN', 'Login');
 @define('TRACKBACK_SENDING', 'Sende Trackback zu URI %s ...');
 @define('TRACKBACK_SENT', 'Trackback erfolgreich!');
 @define('TRACKBACK_FAILED', 'Trackback gescheitert: %s');
@@ -679,7 +695,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Permalink-Struktur fr Autoren-URLs');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der Artikel von gewhlten Autoren dargestellt werden. Die Variablen %id%, %realname%, %username%, %email% und alle anderen normalen Zeichen sind mglich.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Permalink-Struktur fr Kategorie-URLs');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewhlte Kategorien dargestellt werden. Die Variablen %id%, %name%, %description% und alle anderen normalen Zeichen sind mglich.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewhlte Kategorien dargestellt werden. Die Variablen %id%, %name%, %parentname%, %description% und alle anderen normalen Zeichen sind mglich.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink-Struktur fr RSS-Kategorien-Feed URLs');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Legt die relative URL-Struktur fest (beginnend mit der Stamm-URL), mit der gewhlte RSS-Feeds von Kategorien dargestellt werden. Die Variablen %id%, %name%, %description% und alle anderen normalen Zeichen sind mglich.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Pfad zu den Eintrgen');
@@ -757,7 +773,7 @@
 @define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Mediendaten lschen');
 @define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Mediendaten anderer Benutzer verwalten');
 @define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Mediendaten ansehen');
-@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Thumbnails synchronisieren');
+@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Vorschaubilder synchronisieren');
 @define('PERMISSION_ADMINCOMMENTS', 'adminComments: Kommentare verwalten');
 @define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Templates verwalten');
 @define('INSTALL_BLOG_EMAIL', 'E-Mail-Adresse des Blogs');
@@ -891,9 +907,35 @@
 @define('PINGBACK_SENT', 'Pingback erfolgreich');
 @define('PINGBACK_FAILED', 'Pingback fehlgeschlagen: %s');
 @define('PINGBACK_NOT_FOUND', 'Keine pingback-URI gefunden.');
-@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
-@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Versteckt den Archiv-Link, wenn es keine Eintrge fr einen Zeitraum gab (bentigt das Zhlen der Eintrge)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS Import, bentigt PHP5 und kann viel RAM/Speicher bentigen.');
 
 @define('SET_TO_MODERATED', 'Moderieren');
 @define('COMMENT_MODERATED', 'Kommentar #%s wurde erfolgreich moderiert.');
 @define('CENTER', 'mitte');
+@define('FULL_COMMENT_TEXT', 'Ja, mit vollstndigen Kommentar-Texten.');
+
+@define('COMMENT_TOKENS', 'Schnelle Kommentar-Moderation verwenden?');
+@define('COMMENT_TOKENS_DESC', 'Diese Methode setzt Tokens ein, damit Kommentare direkt aus der Hinweis-E-Mail heraus gelscht oder akzeptiert werden knnen. Diese Funktion ist fr hheren Komfort gedacht, geht aber zu Lasten der Sicherheit: Wenn jemand die E-Mail abfngt, kann diese Person entsprechende Kommentare ohne weitere Authentifikation lschen oder freischalten.');
+@define('COMMENT_NOTOKENMATCH', 'Der Kommentar-Link ist nicht mehr gltig, oder Kommentar #%s wurde bereits akzeptiert oder gelscht.');
+@define('TRACKBACK_NOTOKENMATCH', 'Der Kommentar-Link ist nicht mehr gltig, oder Trackback #%s wurde bereits akzeptiert oder gelscht.');
+@define('BADTOKEN', 'Ungltiger Kommentar-Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hallo %s,\n\nSie haben einen neuen Kommentar zu \"%s\" erstellt. Ihr Kommentar war:\n\n%s\n\nDer Betreiber dieses Blogs hat die Besttigung per E-Mail gewnscht, daher mssen Sie folgenden Link anklicken:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hallo %s,\n\nSie haben einen neuen Kommentar zu \"%s\" erstellt. Ihr Kommentar war:\n\n%s\n\nDer Betreiber dieses Blogs hat die Besttigung per E-Mail gewnscht, daher mssen Sie folgenden Link anklicken:\n<%s>\n\nNachdem Sie dies getan haben, knnen Sie auf dem Blog jederzeit mit ihrem Namen und E-Mail-Adresse ohne weitere Freischaltung kommentieren.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Benutze Double-Opt In fr Abonnements von Kommentarbenachrichtigungen?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'Falls aktiviert, wird einem Kommentator, der E-Mail-Benachrichtigung zu neuen Kommentaren abonnieren mchte, eine E-Mail geschickt. Diese enthlt einen Besttigungslink nach dem z.B. fr Deutsche Gesetze erforderlichen Opt-In-Schema.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hallo %s,\n\nSie haben bei ihrem Blog-Kommentar zu dem Eintrag \"%s\" auf <%s> das Abonnement neuer Kommentare gewnscht. Um dies zu besttigen (\"Double Opt In\") klicken Sie bitte diesen Link:\n<%s>\n");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Die Besttigung des Abonnements der Kommentarbenachrichtigung wurde erfolgreich verarbeitet.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Die Besttigung ihres Kommentars wurde erfolgreich verarbeitet.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Ihre Besttigung des Abonnements einer Kommentarbenachrichtigung konnte nicht verarbeitet werden. Bitte prfen Sie den Link, den Sie geklickt haben, auf Vollstndigkeit. Falls dieser Link vor mehr als 3 Wochen gesendet wurde, mssen Sie eine neue E-Mail anfordern.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Ihre Besttigung des Kommentars konnte nicht verarbeitet werden. Bitte prfen Sie den Link, den Sie geklickt haben, auf Vollstndigkeit. Falls dieser Link vor mehr als 3 Wochen gesendet wurde, mssen Sie ihr Kommentar erneut senden.');
+@define('PLUGIN_DOCUMENTATION', 'Dokumentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Lokale Dokumentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Versionsgeschichte');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
