@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_es.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_es.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Luis Cervantes <LuisCervantes@ono.com>,
@@ -93,7 +93,7 @@
 @define('ERROR_FILE_EXISTS_ALREADY', 'Error: El fichero ya existe en el sistema!');
 @define('GO', 'Ir!');
 @define('NEWSIZE', 'Nuevo tamao: ');
-@define('RESIZE_BLAHBLAH', '<b>Cambiar tamao %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Cambiar tamao %s</b>');
 @define('ORIGINAL_SIZE', 'Tamao original: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aqu puedes ajustar el nuevo tamao de la imagen. Si quieres mantener las proporciones slo introduce uno de los valores y presiona la tecla tabulador (TAB), de esta forma se ajustar automticamente:');
 @define('DATE_FORMAT_1', 'd.m.Y');
@@ -253,6 +253,10 @@
 @define('SIDEBAR_PLUGINS', 'Extensiones de barra lateral');
 @define('EVENT_PLUGINS', 'Extensiones de eventos');
 @define('SYNCING', 'Sincronizando la base de datos con el directorio de imgenes.');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Hecho (Sincronizadas %s imgenes).');
 @define('SORT_ORDER', 'Ordenar por');
 @define('SORT_ORDER_NAME', 'Nombre de fichero');
@@ -315,6 +319,10 @@
 @define('TOP_LEVEL', 'Nivel superior');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', 'Permisos');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 
 /* DATABASE SETTINGS */
 @define('INSTALL_CAT_DB', 'Opciones de la base de datos');
@@ -399,6 +407,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Las miniaturas se crearn con el siguiente formato: original.[sufijo].ext');
 @define('INSTALL_THUMBWIDTH', 'Dimensiones de las miniaturas');
 @define('INSTALL_THUMBWIDTH_DESC', 'Anchura mxima esttica de las miniaturas auto-generadas');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Datos personales');
@@ -693,7 +709,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Estructura URL de los enlaces permanentes al autor');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierto autor sean accesibles. Puedes utilizar las variables %id%, %realname%, %username%, %email% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Estructura URL de los enlaces permanentes a categoras');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categora sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las entradas pertenecientes a cierta categora sean accesibles. Puedes utilizar las variables %id%, %name%, %parentname%, %description% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Estructura URL de los enlaces permanentes a la sindicacin RSS de las categoras');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqu puedes definir la estructura URL relativa desde la URL base hasta donde las sindicaciones RSS de ciertas categoras sean accesibles. Puedes utilizar las variables %id%, %name%, %description% y cualquier otro caracter.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Ruta a los archivos');
@@ -897,7 +913,7 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('PERM_SET_CHILD', 'Define los mismos permisos en todos los directorios hijos');
 @define('PERMISSION_FORBIDDEN_PLUGINS', 'Extensiones prohibidas');
 @define('PERMISSION_FORBIDDEN_HOOKS', 'Eventos prohibidos');
-@define('PERMISSION_FORBIDDEN_ENABLE', 'Activar la extesin ACL para grupos de usuarios?');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Activar la extensin ACL para grupos de usuarios?');
 @define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Si la opcin "Extensin ACL para grupos de usuarios" es activada en la configuracin, puedes especificar que grupos de usuarios son capaces de ejecutar ciertas extensiones/eventos.');
 @define('DELETE_SELECTED_ENTRIES', 'Eliminar las entradas seleccionadas');
 @define('PLUGIN_AUTHORS_MINCOUNT', 'Slo mostrar aquellos autores con al menos X artculos');
@@ -907,13 +923,39 @@ Melvin TODO [20060128]: What spanish word do we use for "referrers" ??
 @define('USERCONF_CREATE', 'Deshabilitar usuario / prohibir actividad?');
 @define('USERCONF_CREATE_DESC', 'Si activas esta opcin el usuario ya no podr crear o editar entradas en el blog. Cuando l vuelva a ingresar al sistema no podr hacer nada ms que desconectarse y ver su configuracin personal.');
 @define('CATEGORY_HIDE_SUB', 'Ocultar las entradas realizadas en sub-categoras?');
-@define('CATEGORY_HIDE_SUB_DESC', 'Por defecto, cuando se navega una categora tambin se muestran las entradas hechas en cualquiera de sus sub-categoras. Si activas esta opcin, se mostrn unicamente aquellas entradas que pertenezcan a la categora seleccionada.');
-@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
-@define('PINGBACK_SENT', 'Pingback successful');
-@define('PINGBACK_FAILED', 'Pingback failed: %s');
-@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
-@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
-@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
-@define('SET_TO_MODERATED', 'Moderate');
-@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
-@define('CENTER', 'center');
+@define('CATEGORY_HIDE_SUB_DESC', 'Por defecto, cuando se navega una categora tambin se muestran las entradas hechas en cualquiera de sus sub-categoras. Si activas esta opcin, se mostraran nicamente aquellas entradas que pertenezcan a la categora seleccionada.');
+@define('PINGBACK_SENDING', 'Enviando pingback a URI %s...');
+@define('PINGBACK_SENT', 'Pingback enviado exitosamente');
+@define('PINGBACK_FAILED', 'Fall envo de Pingback: %s');
+@define('PINGBACK_NOT_FOUND', 'No se encontr pingback-URI.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Oculta el enlace a los archivos de una fecha dada cuando, durante ese lapso de tiempo, no se hayan registrado entradas (requiere conteo de entradas)');
+@define('RSS_IMPORT_WPXRSS', 'Importar el RSS eXtendido de WordPress (WPXRSS), necesita PHP5 y es posible que consuma bastante memoria');
+@define('SET_TO_MODERATED', 'Moderar');
+@define('COMMENT_MODERATED', 'El comentario #%s ha sido marcado como moderado exitosamente');
+@define('CENTER', 'Centro');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
