@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_fi.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_fi.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation by Mauri Sahlberg <mos@iki.fi>
@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Pieleen meni, tiedostoa ei tuotu. Kenties tiedoston koko oli liian suuri. Kysy palveluntarjoajaltasi apua tai muokkaa php.ini tiedostoasi salliaksesi isompien tiedostojen tuonnin..');
 @define('GO', 'Tee!');
 @define('NEWSIZE', 'Uusi koko: ');
-@define('RESIZE_BLAHBLAH', '<b>Muokkaa kokoa %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Muokkaa kokoa %s</b>');
 @define('ORIGINAL_SIZE', 'Alkuperäinen koko: <i>%sx%s</i> pikseliä');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Kuvan koon muokkaus. Voit muokata kuvan kokoa säilyttäen suhteet, lisää toiseen laatikkoon arvo ja paina tab-näppäintä, niin lasken sinulle suhteen mukaisen toisen arvon automaattisesti.</p>');
 @define('QUICKJUMP_CALENDAR', 'Pikasiirtymä kalenteriin');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'Muokataan');
 @define('RESIZE_DONE', 'Valmis (muokattu %s kuvaa).');
 @define('SYNCING', 'Päivitetään tietokantaa vastaamaan kuvakansiota');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Valmis (Päivitetty %s kuvaa).');
 @define('FILE_NOT_FOUND', 'Tiedostoa <b>%s</b> ei löydy, ehkäpä se on jo poistettu?');
 @define('ABORT_NOW', 'Peruuta');
@@ -327,6 +331,10 @@
 @define('TOP_LEVEL', 'Ylin taso');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s');
 @define('PERMISSIONS', 'Oikeudet');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Uudet asetukset on tallettetu %s');
 
 /* DATABASE SETTINGS */
@@ -412,6 +420,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Pienoiskuvakkeet nimetään seuraavasti: originaali.[suffiksi].pääte');
 @define('INSTALL_THUMBWIDTH', 'Pienoiskuvakkeen mitat');
 @define('INSTALL_THUMBWIDTH_DESC', 'Pienoiskuvakkeen maksimileveys');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Henkilötietosi');
@@ -676,7 +692,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Kirjoittajien merkintöjen permalink-lauseke');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Lauseke kirjoittajien merkintöjä varten alkaen blogin osoitteesta. Voit käyttää muuttujia %id%, %realname%, %username%, %email% sekä muita merkkejä.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Kategorioiden merkintöjen permalink-lauseke');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Lauseke kategorioiden merkintöjä varten alkaen blogin osoitteesta. Voit käyttää muuttujia %id%, %name%, %description% sekä muita merkkejä.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Lauseke kategorioiden merkintöjä varten alkaen blogin osoitteesta. Voit käyttää muuttujia %id%, %name%, %parentname%, %description% sekä muita merkkejä.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-kanavien (kategoriat) merkintöjen permalink-lauseke');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Lauseke RSS-kanavien merkintöjä varten (kategoriat) alkaen blogin osoitteesta. Voit käyttää muuttujia %id%, %name%, %description% sekä muita merkkejä.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Arkistojenpolku');
@@ -899,3 +915,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
