@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_fr.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_fr.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation by Sebastian Mordziol <argh@php-tools.net>
@@ -90,7 +90,7 @@
 @define('ERROR_FILE_EXISTS_ALREADY', 'Erreur : le fichier existe dj sur votre machine.');
 @define('GO', 'Go!');
 @define('NEWSIZE', 'Nouvelle taille : ');
-@define('RESIZE_BLAHBLAH', '<b>Redimensionner %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Redimensionner %s</b>');
 @define('ORIGINAL_SIZE', 'Taille d\'origine : <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Ici vous pouvez ajuster la taille de l\'image slectionne. Si vous voulez respecter les proportions de l\'image, entrez juste la hauteur ou la largeur, et pressez la touche TAB - la valeur correspondante sera insre automatiquement :');
 @define('QUICKJUMP_CALENDAR', 'Saut rapide vers le Calendrier');
@@ -190,6 +190,10 @@
 @define('RESIZING', 'Redimensionnement');
 @define('RESIZE_DONE', 'Termin (%s images redimensionnes).');
 @define('SYNCING', 'Synchronisation de la base de donnes avec votre collection d\'images');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Termin (%s images synchronises).');
 @define('DELETE_IMAGE_FAIL' , 'Impossible de supprimer l\'image intitule <b>%s</b>');
 @define('DELETE_THUMBNAIL', 'Suppression de la miniature de l\'image intitule <b>%s</b>');
@@ -398,6 +402,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Les miniatures d\'images seront enregistres de la manire suivante : original.[suffixe].ext');
 @define('INSTALL_THUMBWIDTH', 'Dimensions des miniatures');
 @define('INSTALL_THUMBWIDTH_DESC', 'Largeur maximum (statique) des miniatures cres automatiquement');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Dtails personnels');
@@ -414,6 +426,10 @@
 @define('USERCONF_SENDTRACKBACKS_DESC', 'Voulez-vous recevoir un email lorsque quelqu\'un cre un rtrolien  l\'un de vos billets ?');
 
 @define('PERMISSIONS', 'Permissions');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('USERCONF_ALLOWPUBLISH', 'Publication de billets ?');
 @define('USERCONF_ALLOWPUBLISH_DESC', 'Cet utilisateur est-il autoris  poster des billets ?');
 @define('ENTRY_SAVED', 'Votre billet a t enregistr');
@@ -682,7 +698,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Structure des rtroliens par auteur');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\adresse de votre blog par lequel on pourra accder aux billets classs par auteur. Vous pouvez utiliser les variables %id% (identifiant), %realname% (nom rel), %username% (pseudo), %email% et n\'importe quels autres caractres.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Structure des rtroliens par catgorie');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\'adresse de votre blog par lequel on pourra accder aux billets classs par catgorie. Vous pouvez utiliser les variables %id% (identifiant), %name% (nom), %description% et n\'importe quels autres caractres.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\'adresse de votre blog par lequel on pourra accder aux billets classs par catgorie. Vous pouvez utiliser les variables %id% (identifiant), %name% (nom), %parentname%, %description% et n\'importe quels autres caractres.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Structure des fils RSS par catgorie');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Ici vous pouvez dfinir le chemin relatif  l\'adresse de votre blog par lequel on pourra accder aux fils RSS des catgories. Vous pouvez utiliser les variables %id% (identifiant), %name% (nom), %description% et n\'importe quels autres caractres.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Chemin d\'accs aux archives');
@@ -906,3 +922,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
