@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Ismeretlen hiba trtnt, a fjl nincs feltltve. Taln a fjl mrete nagyobb mint a szerveren belltott megengedett maximum rtk. Ezt a belltst a szerver zemeltetje tudja megvltoztatni.');
 @define('GO', 'OK');
 @define('NEWSIZE', 'j mret: ');
-@define('RESIZE_BLAHBLAH', '<b>tmretezs %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>tmretezs %s</b>');
 @define('ORIGINAL_SIZE', 'Eredeti mret: <i>%sx%s</i> kppont');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Itt mdosthatja a kp mrett. Ha arnyosan szeretn a kpet tmretezni, elg az egyik dobozban mdostani a szmot,majd megnyomni a TAB billentyt -- az j mret automatikusan kerl meghatrozsra, gy a kp nem lesz arnytalan</p>');
 @define('QUICKJUMP_CALENDAR', 'Gyors naptrra ugrs');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'tmretezs');
 @define('RESIZE_DONE', 'Ksz (%s kp tmretezve).');
 @define('SYNCING', 'Szinkronizlom az adatbzist a kpek knyvtrval.');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Ksz (%s kpet szinkronizltam).');
 @define('FILE_NOT_FOUND', 'Nem tallom a <b>%s</b> fjlt, lehet, hogy mr trlve lett?');
 @define('ABORT_NOW', 'Azonnali megszakts');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'Legfels szint');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s hrcsatorna');
 @define('PERMISSIONS', 'Jogosultsgok');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Az j belltsokat elmentettk ekkor: %s');
 
 /* DATABASE SETTINGS */
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'A kpekbl generlt elnzeti kpek ilyen nevek lesznek: eredetinv.[eltag].kiterj');
 @define('INSTALL_THUMBWIDTH', 'Elnzeti kp mretek');
 @define('INSTALL_THUMBWIDTH_DESC', 'Az automatikusan generlt elnzeti kpek szlessgnek maximuma');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Szemlyes adatok');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Szerzre vonatkoz permanens hivatkozs URL struktrja');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a szerzre mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %realname%, %username%, %email% s egyb karaktereket is.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Kategrira vonatkoz permanens hivatkozs URL struktrja');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a kategrira mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %name%, %description% s egyb karaktereket is.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan a kategrira mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %name%, %parentname%, %description% s egyb karaktereket is.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS hrcsatornra vonatkoz permanens hivatkozs URL struktrja');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Itt adhatod meg a relatv URL struktrt az alap URL-hez kpest, ahonnan az RSS hrcsatornra mutat hivatkozsok elrhetek lesznek. Hasznlhatod a kvetkez vltozkat: %id%, %name%, %description% s egyb karaktereket is.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Archvumok tvonala');
@@ -897,3 +913,29 @@
 @define('PINGBACK_NOT_FOUND', 'Nem tallhat hivatkozs az URL ltezs ellenrzshez.');
 @define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Az archvum hivatkozs elrejtse, ha nincs abban az idszakban bejegyzs (a bejegyzsek szmolsa szksges)');
 @define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS importlsa, PHP5 szksges, s lehet hogy sok memrit ignyel');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
