@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_is.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_is.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation by rn Arnarson <orn@arnarson.net>
@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'ekkt villa hefur komi upp, skr ekki vistu. Kannski var str skrarinnar meiri heldur en hmarksstrin sem netjnninn skilgreinir. Hafu samband vi jnustuailann inn ea breytti php.ini skrnni til a leyfa strri skrarflutninga.');
 @define('GO', 'Go!');
 @define('NEWSIZE', 'N str: ');
-@define('RESIZE_BLAHBLAH', '<b>Breyta str %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Breyta str %s</b>');
 @define('ORIGINAL_SIZE', 'Upprunaleg str: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hr getur  breytt str myndarinnar. Ef  vilt breyta str hennar  rttum hlutfllum, slu  inn eitthva gildi  annan tveggja reitanna og ttu  TAB takkann. -- Str eirra verur reiknu sjlfvirkt svo hlutfllin haldist rtt.</p>');
 @define('QUICKJUMP_CALENDAR', 'QuickJump dagatal');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'Breyti str');
 @define('RESIZE_DONE', 'Bin (breytti str %s mynda).');
 @define('SYNCING', 'Samhfi gagnagrunn vi myndamppu');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Bin (Samhfi %s myndir).');
 @define('FILE_NOT_FOUND', 'Fann ekki skrna <b>%s</b>, kannski er egar bi a eya henni?');
 @define('ABORT_NOW', 'Htta vi nna');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'Toppstigi');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s straumur');
 @define('PERMISSIONS', 'Rttindi');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 'Nju stillingarnar voru vistaar klukkan %s');
 
 /* DATABASE SETTINGS */
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Snishorn vera nefnd eftir eftirfarandi forsnii: upprunalegt.[viskeyti].end');
 @define('INSTALL_THUMBWIDTH', 'Str snishorna');
 @define('INSTALL_THUMBWIDTH_DESC', 'Stala hgildi breiddar framkallara snishorna');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Persnulegu upplsingar nar');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Uppbygging varanlegra hlekkja sla hfundar');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur fr kvenum hfundum kynnu a vera til staar.  getur nota breyturnar %id%, %realname%, %username%, %email% Og alla ara stafi.');
 @define('INSTALL_PERMALINK_CATEGORY', 'URL uppbygging varanlegra hlekkja flokka');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur r kvenum flokkum kynnu a vera til staar.  getur nota breyturnar %id%, %name%, %description% og alla ara stafi.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar frslur r kvenum flokkum kynnu a vera til staar.  getur nota breyturnar %id%, %name%, %parentname%, %description% og alla ara stafi.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'URL uppbygging varanlegra RSS-strauma flokka');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hr geturu skilgreint slauppbygginguna, allt fr upphafssl til ess hvar RSS-straumar r kvenum flokkum kynnu a vera til staar.  getur nota breyturnar %id%, %name%, %description% og alla ara stafi.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Sl til skjalasafna');
@@ -900,3 +916,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
