@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_ko.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_ko.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by: Wesley Hwang-Chung <wesley96@gmail.com>
@@ -90,7 +90,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', '알 수 없는 오류가 발생하여 파일이 업로드되지 않았습니다. 서버가 허용하는 파일 크기를 초과했을 수 있습니다. 호스팅 업체에 확인을 하거나 php.ini 파일을 수정하여 더 큰 파일을 업로드할 수 있도록 하십시오.');
 @define('GO', '시작!');
 @define('NEWSIZE', '새로운 크기: ');
-@define('RESIZE_BLAHBLAH', '<b>크기 조절: %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>크기 조절: %s</b>');
 @define('ORIGINAL_SIZE', '원래 크기: <i>%sx%s</i> 픽셀');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>여기서 그림 크기를 조절할 수 있습니다. 비율을 유지하면서 크기를 조절하려면 입력상자 한 쪽에 값을 넣고 Tab 키를 누르면 됩니다. 비율이 유지되는 값이 자동으로 계산됩니다.</p>');
 @define('QUICKJUMP_CALENDAR', '빨리 찾아보는 달력');
@@ -204,6 +204,10 @@
 @define('RESIZING', '크기 조절중');
 @define('RESIZE_DONE', '완료 (%s개의 그림의 크기를 조절함).');
 @define('SYNCING', '데이터베이스를 그림 폴더와 동기화합니다');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', '완료 (%s개의 그림을 동기화함).');
 @define('FILE_NOT_FOUND', '<b>%s</b>라는 이름의 파일을 찾지 못했습니다. 이미 삭제되었을 수 있습니다.');
 @define('ABORT_NOW', '지금 중지');
@@ -330,6 +334,10 @@
 @define('TOP_LEVEL', '최상위 (본문)');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s 피드');
 @define('PERMISSIONS', '권한 설정');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', '새로운 설정이 %s에 저장되었습니다');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', '작은 그림은 원래이름.[접두사].확장자 식의 이름으로 생성됩니다');
 @define('INSTALL_THUMBWIDTH', '작은 그림 크기');
 @define('INSTALL_THUMBWIDTH_DESC', '자동 생성되는 작은 그림의 최대 크기');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', '사용자의 개인 정보');
@@ -679,7 +695,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', '고정 링크 - 작성자에 따른 주소 구조');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', '특정 작성자가 쓴 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %realname%, %username%, %email% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
 @define('INSTALL_PERMALINK_CATEGORY', '고정 링크 - 범주에 따른 주소 구조');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', '특정 범주에 속하는 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %name%, %description% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', '특정 범주에 속하는 글이 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %name%, %parentname%, %description% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', '고정 링크 - RSS 피드 - 범주에 따른 주소 구조');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', '특정 범주에 속하는 RSS 피드가 기본 블로그 주소에 대해 상대적으로 가지게 되는 주소 구조를 정할 수 있습니다. %id%, %name%, %description% 변수와 함께 다른 일반 글자를 활용할 수 있습니다.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', '글 목록으로 가는 경로');
@@ -902,3 +918,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
