@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_pt.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_pt.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translation (c) by Agner Olson <agner@agner.net>
@@ -84,7 +84,7 @@
 @define('ERROR_FILE_EXISTS_ALREADY', 'Erro: Arquivo j existe em sua mquina!');
 @define('GO', 'Vai!');
 @define('NEWSIZE', 'Novo tamanho: ');
-@define('RESIZE_BLAHBLAH', '<b>Redimensionar %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>Redimensionar %s</b>');
 @define('ORIGINAL_SIZE', 'Tamanho original: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Aqui voc pode ajustar o novo tamanho das imagens. Se pretende manter as propores, preencha apenas um valor e pressione a tecla TAB que automaticamente ser calculado o novo tamanho de modo que as propores no fiquem bagunadas:');
 @define('QUICKJUMP_CALENDAR', 'Calendrio de acesso rpido');
@@ -184,6 +184,10 @@
 @define('RESIZING', 'Redimensionando');
 @define('RESIZE_DONE', 'Pronto (%s imagens redimensionadas).');
 @define('SYNCING', 'Sincronizando o banco de dados com o diretrio de imagens');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Pronto (%s imagens sincronizadas).');
 @define('DELETE_IMAGE_FAIL' , 'No foi possvel excluir a imagem <b>%s</b>');
 @define('DELETE_THUMBNAIL', 'Excluir a miniatura da imagem intitulada <b>%s</b>');
@@ -313,6 +317,10 @@
 @define('TOP_LEVEL', 'Nvel mximo');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', 'Permisses');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 
 /* DATABASE SETTINGS */
 @define('INSTALL_CAT_DB', 'Configuraes de banco de dados');
@@ -395,6 +403,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'As miniaturas sero nomeadas com o seguinte formato: original.[sufixo].ext');
 @define('INSTALL_THUMBWIDTH', 'Dimenso das miniaturas ');
 @define('INSTALL_THUMBWIDTH_DESC', 'Largura mxima esttica das miniaturas geradas automaticamente');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Detalhes pessoais');
@@ -681,7 +697,7 @@
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Aqui voc pode definir as URLs relativas das estruturas que iniciam pela sua URL base onde algumas entradas de outros autores tornan-se disponveis. Voc pode usar as variveis %id%, %realname%, %username%, %email% ou quaisquer outros.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Estrutura da URL da categoria de permalink');
 
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqui voc pode definir as estruturas URL relativas, iniciando pela sua URL base, de onde outras categorias se tornaro disponveis. Voc pode usar as variveis %id%, %name%, %description%, ou quaisquer outros.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Aqui voc pode definir as estruturas URL relativas, iniciando pela sua URL base, de onde outras categorias se tornaro disponveis. Voc pode usar as variveis %id%, %name%, %parentname%, %description%, ou quaisquer outros.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Categoria das estruturas URL de Permalink e RSS-Feed');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Aqui voc pode definir as estruturas URL relativas, iniciando pela sua URL base at onde o RSS-feed se torna disponvel. Voc pode usar as variveis %id%, %name%, %description%, ou quaisquer outros.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Caminho para arquivos');
@@ -904,3 +920,29 @@
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
