@@ -88,7 +88,7 @@
 @define('ERROR_UNKNOWN_NOUPLOAD', 'Ett oknt fel intrffade och filen laddades inte upp. Filstorleken r kanske strre n vad som tillts av din serverinstallation. Kolla med din tjnsteleverantr eller ndra i filen php.ini fr att tillta uppladdning av strre filer.');
 @define('GO', 'Kr!');
 @define('NEWSIZE', 'Ny storlek: ');
-@define('RESIZE_BLAHBLAH', '<b>ndra storlek p %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>ndra storlek p %s</b>');
 @define('ORIGINAL_SIZE', 'Ursprunglig storlek: <i>%sx%s</i> pixel');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Hr kan du anpassa bildstorleken. Om du vill ndra storlek proportionellt, ndra bara ett vrde i ngot av de tv flten och tryck p TAB - D ndras  automatiskt storleken automatiskt s att bildens proportioner bibehlls</p>');
 @define('QUICKJUMP_CALENDAR', 'Snabbkalender');
@@ -202,6 +202,10 @@
 @define('RESIZING', 'ndrar storlek');
 @define('RESIZE_DONE', 'Klar (bt storlek p %s bilder).');
 @define('SYNCING', 'Synkroniserar databasen med bildkatalogen');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', 'Klar (synkroniserade %s bilder).');
 @define('FILE_NOT_FOUND', 'Kunde inte hitta filen <b>%s</b>, kanske r den redan borttagen?');
 @define('ABORT_NOW', 'Avbryt nu');
@@ -257,7 +261,7 @@
 @define('ALL_CATEGORIES', 'Alla kategorier');
 @define('DO_MARKUP', 'Utfr Markup Transformations');
 @define('GENERAL_PLUGIN_DATEFORMAT', 'Datumformatering');
-@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet p artikelns verkliga datum, med hjlp PHPs strftime() variabler. (Default: "%s")');
+@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet p artikelns verkliga datum, med hjlp PHPs strftime() variabler. (Ursprungsvrde: "%s")');
 @define('ERROR_TEMPLATE_FILE', 'Kunde inte ppna mallfil. Uppdatera Serendipity!');
 @define('ADVANCED_OPTIONS', 'Utkade instllningar');
 @define('EDIT_ENTRY', 'Redigera artikel');
@@ -328,6 +332,10 @@
 @define('TOP_LEVEL', 'versta nivn');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s matning');
 @define('PERMISSIONS', 'Rttigheter');
+@define('INTEGRITY', 'Verifiera installationens integritet');
+@define('CHECKSUMS_NOT_FOUND', 'Kunde inte jmfra kontrollsummor! (Ingen checksums.inc.php i huvudmappen)');
+@define('CHECKSUMS_PASS', 'Alla ndvndiga filer verifierade..');
+@define('CHECKSUM_FAILED', '%s korrupt eller ndrad: verifiering misslyckades');
 @define('SETTINGS_SAVED_AT', 'De nya instllningarna har sparats p %s');
 
 /* DATABASE SETTINGS */
@@ -348,7 +356,7 @@
 
 /* PATHS */
 @define('INSTALL_CAT_PATHS', 'Skvgar');
-@define('INSTALL_CAT_PATHS_DESC', 'Olka skvgar till ndvndiga mappar och filer. Glm inte efterfljande snedstreck fr kataloger!');
+@define('INSTALL_CAT_PATHS_DESC', 'Olika skvgar till ndvndiga mappar och filer. Glm inte efterfljande snedstreck fr kataloger!');
 @define('INSTALL_FULLPATH', 'Fullstndig skvg');
 @define('INSTALL_FULLPATH_DESC', 'Den absoluta (fullstndiga) skvgen till din Serendipity-installation');
 @define('INSTALL_UPLOADPATH', 'Skvg fr uppladdning');
@@ -413,6 +421,14 @@
 @define('INSTALL_THUMBSUFFIX_DESC', 'Miniatyrer kommer att dpas enligt fljande format: original.[suffix].ext');
 @define('INSTALL_THUMBWIDTH', 'Miniatyrbildsdimensioner');
 @define('INSTALL_THUMBWIDTH_DESC', 'Statisk max-bredd fr auto-genererade miniatyrbilder');
+@define('INSTALL_THUMBDIM', 'Begrnsad miniatyrbildsdimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Strst');
+@define('INSTALL_THUMBDIM_WIDTH', 'Bredd');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Hjd');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension att begrnsa till miniatyrbildens maxstorlek. Ursprungsvrdet "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" begrnsar bda dimensionerna, s att ingen av dem kan vara strre n maxstorleken; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" och "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" begrnsa endast den valda dimensionen, s att den andra kan vara strre n maxstorleken.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'Din personliga information');
@@ -584,8 +600,8 @@
 @define('ACTUAL', 'Verklig');
 @define('PHPINI_CONFIGURATION', 'php.ini-konfiguration');
 @define('PHP_INSTALLATION', 'PHP-installation');
-@define('THEY_DO', 'they do');
-@define('THEY_DONT', 'they do not');
+@define('THEY_DO', 'det gr de');
+@define('THEY_DONT', 'det gr de inte');
 @define('SIMPLE_INSTALLATION', 'Enkel installation');
 @define('EXPERT_INSTALLATION', 'Expertinstallation');
 @define('COMPLETE_INSTALLATION', 'Komplett installation');
@@ -677,7 +693,7 @@
 @define('INSTALL_PERMALINK_AUTHOR', 'Frfattares artiklars pemalink-URL-struktur');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n artiklar skrivna av vissa frfattare. Du kan anvnda variablerna %id%, %realname%, %username%, %email% samt alla andra tecken.');
 @define('INSTALL_PERMALINK_CATEGORY', 'Kategoriers permalink-URL-struktur');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n artiklar i vissa kategorier. Du kan anvnda variablerna %id%, %name%, %description% samt alla andra tecken.');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n artiklar i vissa kategorier. Du kan anvnda variablerna %id%, %name%, %parentname%, %description% samt alla andra tecken.');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'Kategoriers RSS-matningars permalink-URL-struktur');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Hr kan du definiera URL-strukturen relativt till din bas-URL fr att n RSS-matningar frn vissa kategorier. Du kan anvnda variablerna %id%, %name%, %description% samt alla andra tecken.');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Skvg till arkiv');
@@ -801,101 +817,127 @@
 @define('CATEGORIES_HIDE_PARENT', 'Vill du gmma vald verordnad kategori?');
 @define('CATEGORIES_HIDE_PARENT_DESC', 'Om du begrnsar listningen av kategorier till en specifik kategori s kommer du att endast se den verordnade kategorin nr de listas. Om du avaktiverar detta val s kommer inte den verordnade kategorin att visas.');
 @define('WARNING_NO_GROUPS_SELECTED', 'OBS! Du valde inte ngot gruppmedlemskap. Det medfr att du kommer att loggas ut frn hanteringen av anvndargrupper. Ditt medlemskap har drfr inte ndrats.');
-@define('INSTALL_RSSFETCHLIMIT', 'Entries to display in Feeds');
-@define('INSTALL_RSSFETCHLIMIT_DESC', 'Number of entries to display for each page on the RSS Feed.');
-@define('INSTAL_DB_UTF8', 'Enable DB-charset conversion');
-@define('INSTAL_DB_UTF8_DESC', 'Issues a MySQL "SET NAMES" query to indicate the required charset for the database. Turn this on or off, if you see weird characters in your blog.');
-@define('ONTHEFLYSYNCH', 'Enable on-the-fly media synchronization');
-@define('ONTHEFLYSYNCH_DESC', 'If enabled, Serendipity will compare the media database with the files stored on your server and synchronize the database and directory contents.');
-@define('USERCONF_CHECK_USERNAME_ERROR', 'The username cannot be left blank.');
-@define('FURTHER_LINKS', 'Further Links');
-@define('FURTHER_LINKS_S9Y', 'Serendipity Homepage');
-@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity Documentation');
-@define('FURTHER_LINKS_S9Y_BLOG', 'Official Blog');
-@define('FURTHER_LINKS_S9Y_FORUMS', 'Forums');
+@define('INSTALL_RSSFETCHLIMIT', 'Artiklar som visas i flden');
+@define('INSTALL_RSSFETCHLIMIT_DESC', 'Antal artiklar att visa p varje sida i RSS-fldet.');
+@define('INSTAL_DB_UTF8', 'Aktivera Enable DB-teckenuppsttningskonvertering');
+@define('INSTAL_DB_UTF8_DESC', 'Utfrdare MySQL-frfrgan "SET NAMES" fr att indikera den fr databasen ndvndiga teckenuppsttningen. ndra denna instllning om du ser mrkliga tecken i din blogg.');
+@define('ONTHEFLYSYNCH', 'Aktivera mediasynkronisering');
+@define('ONTHEFLYSYNCH_DESC', 'Om aktiv kommer Serendipity att jmfra mediadatabasen med filerna som lagras p din server och synkronisera databasen med mappinnehllet.');
+@define('USERCONF_CHECK_USERNAME_ERROR', 'Anvndarnamnet kan inte utelmnas.');
+@define('FURTHER_LINKS', 'Fler lnkar');
+@define('FURTHER_LINKS_S9Y', 'Serendipitys hemsida');
+@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipitys dokumentation');
+@define('FURTHER_LINKS_S9Y_BLOG', 'Officiell blogg');
+@define('FURTHER_LINKS_S9Y_FORUMS', 'Forum');
 @define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
-@define('COMMENT_IS_DELETED', '(Comment removed)');
+@define('COMMENT_IS_DELETED', '(Kommentar borttagen)');
 
-@define('CURRENT_AUTHOR', 'Current author');
+@define('CURRENT_AUTHOR', 'Innevarande frfattare');
 
-@define('WORD_NEW', 'New');
-@define('SHOW_MEDIA_TOOLBAR', 'Show toolbar within media selector popup?');
-@define('MEDIA_KEYWORDS', 'Media keywords');
-@define('MEDIA_KEYWORDS_DESC', 'Enter a list of ";" separated words that you want to use as pre-defined keywords for media items.');
-@define('MEDIA_EXIF', 'Import EXIF/JPEG image data');
-@define('MEDIA_EXIF_DESC', 'If enabled, existing EXIF/JPEG metadata of images will be parsed and stored in the database for display in the media gallery.');
-@define('MEDIA_PROP', 'Media properties');
+@define('WORD_NEW', 'Ny');
+@define('SHOW_MEDIA_TOOLBAR', 'Visa verktygsrad i mediavljarens popup-fnster?');
+@define('MEDIA_KEYWORDS', 'Medianyckelord');
+@define('MEDIA_KEYWORDS_DESC', 'Fyll i en lista med ord separerade av ";" som du vill anvnda som frdefinierade nyckelord fr mediastycken.');
+@define('MEDIA_EXIF', 'Importera EXIF/JPEG-bilddata');
+@define('MEDIA_EXIF_DESC', 'Om aktiv kommer existerande EXIF/JPEG-metadata i bilder att lsas och lagras i databasen fr visning i mediagalleriet.');
+@define('MEDIA_PROP', 'Mediaegenskaper');
 
 
-@define('GO_ADD_PROPERTIES', 'Go & enter properties');
+@define('GO_ADD_PROPERTIES', 'Mata in egenskaper');
 @define('MEDIA_PROPERTY_DPI', 'DPI');
-@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
-@define('MEDIA_PROPERTY_COMMENT1', 'Short Comment');
-@define('MEDIA_PROPERTY_COMMENT2', 'Long Comment');
-@define('MEDIA_PROPERTY_TITLE', 'Title');
-@define('MEDIA_PROP_DESC', 'Enter a list of ";" separated property fields you want to define for each media file');
-@define('MEDIA_PROP_MULTIDESC', '(You can append ":MULTI" after any item to indicate that this item will contain long text instead of just some characters)');
+@define('MEDIA_PROPERTY_COPYRIGHT', 'Upphovsskydd');
+@define('MEDIA_PROPERTY_COMMENT1', 'Kort kommentar');
+@define('MEDIA_PROPERTY_COMMENT2', 'Lng kommentar');
+@define('MEDIA_PROPERTY_TITLE', 'Titel');
+@define('MEDIA_PROP_DESC', 'Fyll i en lista med egenskapsflt separerade av  ";" som du vill definiera fr varje mediafil');
+@define('MEDIA_PROP_MULTIDESC', '(Du kan lgga till ":MULTI" efter valfritt egenskapsflt fr att indikera att detta kommer att innehlla en lngre text snarare n enstaka tecken)');
 
-@define('STYLE_OPTIONS_NONE', 'This theme/style has no specific options. To see how your template can specify options, read the Technical Documentation on www.s9y.org about "Configuration of Theme options".');
-@define('STYLE_OPTIONS', 'Theme/Style options');
+@define('STYLE_OPTIONS_NONE', 'Denna stil har inga specifika instllningar. Fr att se hur din mall kan specifiera instllningar, ls "Technical Documentation" p www.s9y.org om "Configuration of Theme options".');
+@define('STYLE_OPTIONS', 'Tema/stil-instllningar');
 
-@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');
+@define('PLUGIN_AVAILABLE_COUNT', 'Totalt: %d insticksmoduler.');
 
-@define('SYNDICATION_RFC2616', 'Activate strict RFC2616 RSS-Feed compliance');
-@define('SYNDICATION_RFC2616_DESC', 'NOT Enforcing RFC2616 means that all Conditional GETs to Serendipity will return entries last modified since the time of the last request. With that setting to "false", your visitors will get all articles since their last request, which is considered a good thing. However, some Agents like Planet act weird, if that happens, at it also violates RFC2616. So if you set this option to "TRUE" you will comply with that RFC, but readers of your RSS feed might miss items in their holidays. So either way, either it hearts Aggregators like Planet, or it hurts actual readers of your blog. If you are facing complaints from either side, you can toggle this option. Reference: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
-@define('MEDIA_PROPERTY_DATE', 'Associated Date');
-@define('MEDIA_PROPERTY_RUN_LENGTH', 'Run-Length');
-@define('FILENAME_REASSIGNED', 'Automagically assigned new file name: %s');
-@define('MEDIA_UPLOAD_SIZE', 'Max. file upload size');
-@define('MEDIA_UPLOAD_SIZE_DESC', 'Enter the maximum filesize for uploaded files in bytes. This setting can be overruled by server-side settings in PHP.ini: upload_max_filesize, post_max_size, max_input_time all take precedence over this option. An empty string means to only use the server-side limits.');
-@define('MEDIA_UPLOAD_SIZEERROR', 'Error: You cannot upload files larger than %s bytes!');
-@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. width of image files for upload');
-@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Enter the maximum image width in pixels for uploaded images.');
-@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. height of image files for upload');
-@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Enter the maximum image height in pixels for uploaded images.');
-@define('MEDIA_UPLOAD_DIMERROR', 'Error: You cannot upload image files larger than %s x %s pixels!');
+@define('SYNDICATION_RFC2616', 'Aktivera strikt RFC2616 RSS-fldesefterlevnad');
+@define('SYNDICATION_RFC2616_DESC', 'Att INTE verkstlla RFC2616 innebr att alla villkorliga GETs till Serendipity kommer att returnera artiklar som ndrats sedan den senaste frfrgan. Med den instllingen som "falsk" kommer dina beskare att f alla artiklar sedan deras senaste besk, vilket betraktas som en god sak. Dock kan vissa agenter ssom Planet att upptrda mrkligt eftersom det strider mot RFC2616. S om du stter denna instllning som "true" kommer du att hlla dig till denna RFC, men lsare av dina RSS-flden kan missa artiklar vid lngre uppehll. Antingen orsakar du problem fr sammanstllare som Planet eller fr dina direkta lsare. Om du fr klagoml frn ngon av dessa kan du ndra denna instllning. Se ven: <a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>');
+@define('MEDIA_PROPERTY_DATE', 'Tillhrande datum');
+@define('MEDIA_PROPERTY_RUN_LENGTH', 'Speltid');
+@define('FILENAME_REASSIGNED', 'Automatiskt tilldelat nytt filnamn: %s');
+@define('MEDIA_UPLOAD_SIZE', 'Maximal uppladdningsstorlek fr fil');
+@define('MEDIA_UPLOAD_SIZE_DESC', 'Mata in den maximala filstorleken fr uppladdade filer i bytes. Denna instllning kan sidosttas av serverinstllningar i PHP.ini: upload_max_filesize, post_max_size, max_input_time kommer alla att ha fretrde framfr denna instllning. En tom strng innebr att endast serverinstllningarnas begrnsning anvnds.');
+@define('MEDIA_UPLOAD_SIZEERROR', 'Fel: Du kan inte ladda upp filer strre n %s byte!');
+@define('MEDIA_UPLOAD_MAXWIDTH', 'Maximal bredd p bilder som laddas upp');
+@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Mata in den maximala bildbredden i pixlar fr uppladdade bilder.');
+@define('MEDIA_UPLOAD_MAXHEIGHT', 'Maximal hjd p bilder som laddas upp');
+@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Mata in den maximala bildhjden i pixlar fr uppladdade bilder.');
+@define('MEDIA_UPLOAD_DIMERROR', 'Fel: Du kan inte ladda upp bildfiler strre n %s x %s pixlar!');
 
-@define('MEDIA_TARGET', 'Target for this link');
-@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, adaptive size)');
-@define('MEDIA_ENTRY', 'Isolated Entry');
-@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');
+@define('MEDIA_TARGET', 'Ml fr denna lnk');
+@define('MEDIA_TARGET_JS', 'Popup-fnster (via JavaScript, adaptiv storlek)');
+@define('MEDIA_ENTRY', 'Isolerad artikel');
+@define('MEDIA_TARGET_BLANK', 'Popup-fnster (via target=_blank)');
 
-@define('MEDIA_DYN_RESIZE', 'Allow dynamic image resizing?');
-@define('MEDIA_DYN_RESIZE_DESC', 'If enabled, the media selector can return images in any requested size via a GET variable. The results are cached, and thus can create a large filebase if you make intensive use of it.');
+@define('MEDIA_DYN_RESIZE', 'Tillt dynamisk bildskalning?');
+@define('MEDIA_DYN_RESIZE_DESC', 'Om aktiv kan mediavljaren returnera bilder i valfri efterfrgad storlek via en GET-variabel. Resultaten cache-lagras och kan drfr skapa en stor filsamling om du anvnder detta intensivt.');
 
-@define('MEDIA_DIRECTORY_MOVED', 'Directory and files were successfully moved to %s');
-@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Directory and files could not be moved to %s!');
-@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'On Non-MySQL databases, iterating through every article to replace the old directory URLs with new directory URLs is not possible. You will need to manually edit your entries to fix new URLs. You can still move your old directory back to where it was, if that is too cumbersome for you.');
-@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Moved the URL of the moved directory in %s entries.');
-@define('PLUGIN_ACTIVE', 'Active');
-@define('PLUGIN_INACTIVE', 'Inactive');
-@define('PREFERENCE_USE_JS', 'Enable advanced JS usage?');
-@define('PREFERENCE_USE_JS_DESC', 'If enabled, advanced JavaScript sections will be enabled for better usability, like in the Plugin Configuration section you can use drag and drop for re-ordering plugins.');
+@define('MEDIA_DIRECTORY_MOVED', 'Mapp och filer flyttades utan problem till %s');
+@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Mapp och filer kunde inte flyttas till %s!');
+@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'I andra databaser n MySQL r det inte mjligt att iterera genom varje artikel fr att erstta gammal mapps URL. Du kommer att behva att redigera dina artiklar manuellt fr att fixa ny URLer. Du kan fortfarande flytta din gamla mapp tillbaka till dess gamla plats om detta r fr anstrngande.');
+@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Flyttade URLen fr den flyttade mappen fr %s artiklar.');
+@define('PLUGIN_ACTIVE', 'Aktiv');
+@define('PLUGIN_INACTIVE', 'Inaktiv');
+@define('PREFERENCE_USE_JS', 'Aktivera avancerad JS-anvndning?');
+@define('PREFERENCE_USE_JS_DESC', 'Om aktiv kommer avancerade JavaScript-sektioner att anvndas fr strre anvndbarhet, ssom att i sektionen fr konfigurering av insticksmoduler kunna dra och slppa insticksmoduler fr att ndra deras ordning.');
 
-@define('PREFERENCE_USE_JS_WARNING', '(This page uses advanced JavaScripting. If you are having functionality issues, please disable the use of advanced JS usage in your personal preferences or disable your browser\'s JavaScript)');
+@define('PREFERENCE_USE_JS_WARNING', '(Denna sida anvnder avancerad JavaScript. Om du upplever funktionsproblem stng av anvndningen av avancerad JS-anvndning i dina personliga instllningar eller stng av din webblsares JavaScript)');
 
 
-@define('INSTALL_PERMALINK_COMMENTSPATH', 'Path to comments');
-@define('PERM_SET_CHILD', 'Set the same permissions on all child directories');
-@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
-@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
-@define('PERMISSION_FORBIDDEN_ENABLE', 'Enable Plugin ACL for usergroups?');
-@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'If the option "Plugin ACL for usergroups" is enabled in the configuration, you can specify which usergroups are allowed to execute certain plugins/events.');
-@define('DELETE_SELECTED_ENTRIES', 'Delete selected entries');
-@define('PLUGIN_AUTHORS_MINCOUNT', 'Show only authors with at least X articles');
+@define('INSTALL_PERMALINK_COMMENTSPATH', 'Skvg till kommentarer');
+@define('PERM_SET_CHILD', 'Ange samma behrigheter p alla undermappar');
+@define('PERMISSION_FORBIDDEN_PLUGINS', 'Frbjudna insticksmoduler');
+@define('PERMISSION_FORBIDDEN_HOOKS', 'Frbjudna hndelser');
+@define('PERMISSION_FORBIDDEN_ENABLE', 'Aktivera ACL fr insticksmoduler och anvndargrupper?');
+@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Om aktiv s kan du specifiera vilka anvndargrupper som fr tillgng till olika insticksmoduler/hndelser.');
+@define('DELETE_SELECTED_ENTRIES', 'Ta bort valda artiklar');
+@define('PLUGIN_AUTHORS_MINCOUNT', 'Visa enbart frfattare med minst X skrivna artiklar');
 @define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
-@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
-@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
-@define('USERCONF_CREATE', 'Disable user / forbid activity?');
-@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
-@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
-@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
-@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
-@define('PINGBACK_SENT', 'Pingback successful');
-@define('PINGBACK_FAILED', 'Pingback failed: %s');
-@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
-@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
-@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
-@define('SET_TO_MODERATED', 'Moderate');
-@define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
-@define('CENTER', 'center');
+@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Lgg till denna lnk som bokmrke och anvnd den sen p valfri sida som du vill blogga om fr att snabbt komma t din Serendipity-blogg.');
+@define('IMPORT_WP_PAGES', 'Hmta ven bilagor och statiska sidor som normala artiklar?');
+@define('USERCONF_CREATE', 'Stng av anvndare / frbjud aktivitet?');
+@define('USERCONF_CREATE_DESC', 'Om vald har anvndaren inte ngra mjligheter att redigera eller skapa p bloggen lngre. Vid inloggning i anvndargrnssnittet kan anvndaren enbart se sina personliga instllningar samt logga ut.');
+@define('CATEGORY_HIDE_SUB', 'Dlj inlgg gjorda i underkategorier?');
+@define('CATEGORY_HIDE_SUB_DESC', 'Normalt sett nr du blddrar i en kategori kommer ven artiklar frn underkategorier att visas. Om denna instllning aktiveras kommer enbart artiklar i den valda kategorin att visas.');
+@define('PINGBACK_SENDING', 'Skickar pingback till URI %s...');
+@define('PINGBACK_SENT', 'Pingback lyckades');
+@define('PINGBACK_FAILED', 'Pingback misslyckades: %s');
+@define('PINGBACK_NOT_FOUND', 'Ingen pingback-URI hittades.');
+@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Dlj arkivlnken om inga artiklar skrevs i denna tidsrymd (krver att artiklar rknas)');
+@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, krver PHP5 och kan anvnda mycket minne');
+@define('SET_TO_MODERATED', 'Moderera');
+@define('COMMENT_MODERATED', 'Kommentar #%s har angetts som modererad');
+@define('CENTER', 'centrera');
+@define('FULL_COMMENT_TEXT', 'Ja, med komplett kommentarstext');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
