@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_lang_tw.inc.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_lang_tw.inc.php 2405 2008-12-18 10:55:57Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 # Translated by CapriSkye <admin@capriskye.com>
@@ -90,7 +90,7 @@ $i18n_unknown = 'tw';
 @define('ERROR_UNKNOWN_NOUPLOAD', '~o, ɮ٨SW. ]\Aɮפj󭭨jp. и߰ݱz ISP έקz php.ini .');
 @define('GO', '~!');
 @define('NEWSIZE', 'sjp: ');
-@define('RESIZE_BLAHBLAH', '<b>]jp %s</b><p>');
+@define('RESIZE_BLAHBLAH', '<b>]jp %s</b>');
 @define('ORIGINAL_SIZE', '즳jp: <i>%sx%s</i> ');
 @define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>bo̱ziHקϤjp. pGznק令ۦPϤ, zuݭnJ@ӼƭȵM TAB -- tη|۰zpҥHKX</p>');
 @define('QUICKJUMP_CALENDAR', 'ֳtD');
@@ -204,6 +204,10 @@ $i18n_unknown = 'tw';
 @define('RESIZING', ']jp');
 @define('RESIZE_DONE', ' (] %s ӹϤ).');
 @define('SYNCING', 'iƮwMϤɮקPB');
+@define('SYNC_OPTION_LEGEND', 'Thumbnail Synchronization Options');
+@define('SYNC_OPTION_KEEPTHUMBS', 'Keep all existing thumbnails');
+@define('SYNC_OPTION_SIZECHECKTHUMBS', 'Keep existing thumbnails only if they are the correct size');
+@define('SYNC_OPTION_DELETETHUMBS', 'Regenerate all thumbnails');
 @define('SYNC_DONE', ' (PBF %s ӹϤ).');
 @define('FILE_NOT_FOUND', '䤣ɮצW <b>%s</b>, ]\wgQRF?');
 @define('ABORT_NOW', '');
@@ -330,6 +334,10 @@ $i18n_unknown = 'tw';
 @define('TOP_LEVEL', '̰h');
 @define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
 @define('PERMISSIONS', 'v');
+@define('INTEGRITY', 'Verify Installation Integrity');
+@define('CHECKSUMS_NOT_FOUND', 'Unable to compare checksums! (No checksums.inc.php in main directory)');
+@define('CHECKSUMS_PASS', 'All required files verified.');
+@define('CHECKSUM_FAILED', '%s corrupt or modified: failed verification');
 @define('SETTINGS_SAVED_AT', 's]wwgxs %s');
 
 /* DATABASE SETTINGS */
@@ -415,6 +423,14 @@ $i18n_unknown = 'tw';
 @define('INSTALL_THUMBSUFFIX_DESC', 'YϷ|HU榡sRW: ɦW.[mr].ext');
 @define('INSTALL_THUMBWIDTH', 'YϤث');
 @define('INSTALL_THUMBWIDTH_DESC', '۰ʫإYϪ̤je');
+@define('INSTALL_THUMBDIM', 'Thumbnail constrained dimension');
+@define('INSTALL_THUMBDIM_LARGEST', 'Largest');
+@define('INSTALL_THUMBDIM_WIDTH', 'Width');
+@define('INSTALL_THUMBDIM_HEIGHT', 'Height');
+@define('INSTALL_THUMBDIM_DESC', 'Dimension to be constrained to the thumbnail max size. The default "' . 
+    INSTALL_THUMBDIM_LARGEST .  '" limits both dimensions, so neither can be greater than the max size; "' . 
+    INSTALL_THUMBDIM_WIDTH . '" and "' .  INSTALL_THUMBDIM_HEIGHT . 
+    '" only limit the chosen dimension, so the other could be larger than the max size.');
 
 /* Personal details */
 @define('USERCONF_CAT_PERSONAL', 'ӤHƳ]w');
@@ -680,7 +696,7 @@ $i18n_unknown = 'tw';
 @define('INSTALL_PERMALINK_AUTHOR', '@̪RAs');
 @define('INSTALL_PERMALINK_AUTHOR_DESC', 'o̥iHz]wH򩳦}ӭp@̤峹۹sCziHΥHUܼơG%id%, %realname%, %username%, %email% ΨLrC');
 @define('INSTALL_PERMALINK_CATEGORY', 'ORAs');
-@define('INSTALL_PERMALINK_CATEGORY_DESC', 'o̥iHz]wH򩳦}ӭpO峹۹sCziHΥHUܼơG%id%, %name%, %description% ΨLrC');
+@define('INSTALL_PERMALINK_CATEGORY_DESC', 'o̥iHz]wH򩳦}ӭpO峹۹sCziHΥHUܼơG%id%, %name%, %parentname%, %description% ΨLrC');
 @define('INSTALL_PERMALINK_FEEDCATEGORY', 'RSS-Feed ORAs');
 @define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'o̥iHz]wH򩳦}ӭp RSS-Feed O峹۹sCziHΥHUܼơG%id%, %name%, %description% ΨLrC');
 @define('INSTALL_PERMALINK_ARCHIVESPATH', 'Osw|');
@@ -904,3 +920,29 @@ $i18n_unknown = 'tw';
 @define('SET_TO_MODERATED', 'Moderate');
 @define('COMMENT_MODERATED', 'Comment #%s has successfully been set as moderated');
 @define('CENTER', 'center');
+@define('FULL_COMMENT_TEXT', 'Yes, with full comment text');
+
+@define('COMMENT_TOKENS', 'Use Tokens for Comment Moderation?');
+@define('COMMENT_TOKENS_DESC', 'If tokens are used, comments can be approved and deleted by clicking the email links without requiring login access to the blog. Note that this is a convenience feature, and if your mails get hijacked, those people can approve/delete the referenced comment without further authentication.');
+@define('COMMENT_NOTOKENMATCH', 'Moderation link has expired or comment #%s has already been approved or deleted');
+@define('TRACKBACK_NOTOKENMATCH', 'Moderation link has expired or trackback #%s has already been approved or deleted');
+@define('BADTOKEN', 'Invalid Moderation Link'); 
+
+@define('CONFIRMATION_MAIL_ALWAYS', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n");
+@define('CONFIRMATION_MAIL_ONCE', "Hello %s,\n\nYou have sent a new comment to \"%s\". Your comment was:\n\n%s\n\nThe owner of the blog has enabled one-time mail verification, so you need to click on the following link to authenticate your comment:\n<%s>\n\nAfter you have done that, you can always post comments on that blog with your username and e-mail address without receiving such notifications.");
+@define('INSTALL_SUBSCRIBE_OPTIN', 'Use Double-Opt In for comment subscriptions?');
+@define('INSTALL_SUBSCRIBE_OPTIN_DESC', 'If enabled, when a comment is made where the person wants to be notified via e-mail about new comments to the same entry, he must confirm his subscription to the entry. This Double-Opt In is required by german law, for example.');
+@define('CONFIRMATION_MAIL_SUBSCRIPTION', "Hello %s,\n\nYou have requested to be notified for comments to \"%s\" (<%s>). To approve this subscription (\"Double Opt In\") please click this link:\n<%s>\n.");
+@define('NOTIFICATION_CONFIRM_SUBMAIL', 'Your confirmation of your comment subscription has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_MAIL', 'Your confirmation of the comment has been successfully entered.');
+@define('NOTIFICATION_CONFIRM_SUBMAIL_FAIL', 'Your comment subscription could not be confirmed. Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must request a new confirmation mail.');
+@define('NOTIFICATION_CONFIRM_MAIL_FAIL', 'Your comment confirmation could not be confirmed.  Please check the link you clicked on for completion. If the link was sent more than 3 weeks ago, you must send your comment again.');
+@define('PLUGIN_DOCUMENTATION', 'Documentation');
+@define('PLUGIN_DOCUMENTATION_LOCAL', 'Local Documentation');
+@define('PLUGIN_DOCUMENTATION_CHANGELOG', 'Version history');
+@define('SYNDICATION_PLUGIN_BIGIMG', 'Big Image');
+@define('SYNDICATION_PLUGIN_BIGIMG_DESC', 'Display a (big) image at the top of the feeds in sidebar, enter full or absolute URL to image file.');
+@define('SYNDICATION_PLUGIN_FEEDNAME', 'Displayed name for "feed"');
+@define('SYNDICATION_PLUGIN_FEEDNAME_DESC', 'Enter an optional custom name for the feeds (defaults to "feed" when empty)');
+@define('SYNDICATION_PLUGIN_COMMENTNAME', 'Displayed name for "comment" feed');
+@define('SYNDICATION_PLUGIN_COMMENTNAME_DESC', 'Enter an optional custom name for the comment feed');
