@@ -1,13 +1,11 @@
-<?php # $Id: lang_bg.inc.php 920 2006-02-09 10:58:08Z garvinhicking $
+<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
 
 /**
- *  @version $Revision: 920 $
- *  @author Ivan Cenov JWalker@abv.bg
- *  EN-Revision: 690
+ *  @version $Revision: 1419 $
+ *  @author Ivan Cenov jwalker@hotmail.bg
  */
  
         @define('PLUGIN_EVENT_BBCODE_NAME',     ' : BBCode');
         @define('PLUGIN_EVENT_BBCODE_DESC',     '   (, , HTML )  BBcode');
         @define('PLUGIN_EVENT_BBCODE_TRANSFORM', '  <a href="http://www.phpbb.com/phpBB/faq.php?mode=bbcode">BBCode</a>  ');
-
-?>
+        @define('PLUGIN_EVENT_BBCODE_TARGET',   '  target="blank"   ?');
