@@ -1,11 +1,11 @@
-<?php # $Id: lang_bg.inc.php 1419 2006-08-29 10:25:22Z jwalker $
+<?php # $Id: lang_bg.inc.php 2317 2008-08-22 13:13:01Z jwalker $
 
 /**
- *  @version $Revision: 1419 $
+ *  @version $Revision: 2317 $
  *  @author Ivan Cenov jwalker@hotmail.bg
  */
 
-
+ 
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_TITLE', '   ');
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_DESC', '(,   , sticky )');
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_STICKYPOSTS', '     sticky');
@@ -37,3 +37,8 @@
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_CUSTOMFIELDS_DESC3', '          <a href="%s" target="_blank" title="' . PLUGIN_EVENT_ENTRYPROPERTIES_TITLE . '"></a>   serendipity_event_entryproperties.');
 
     @define('PLUGIN_EVENT_ENTRYPROPERTIES_DISABLE_MARKUP', '     :');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_EXTJOINS', '      ');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_EXTJOINS_DESC', '  ,     SQL    ,     ,       .    ,       .');
+
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_SEQUENCE', '    ');
+    @define('PLUGIN_EVENT_ENTRYPROPERTIES_SEQUENCE_DESC', '      ()             .');
\ No newline at end of file
