@@ -1,4 +1,4 @@
-<?php # $Id: lang_de.inc.php 2175 2008-03-17 13:30:40Z garvinhicking $
+<?php # $Id: lang_de.inc.php 2351 2008-10-13 11:02:12Z garvinhicking $
 
         @define('PLUGIN_EVENT_SPAMBLOCK_TITLE', 'Spamschutz');
         @define('PLUGIN_EVENT_SPAMBLOCK_DESC', 'Mehrere Mglichkeiten, um Kommentarspam einzudmmen');
@@ -116,4 +116,8 @@
 @define('PLUGIN_EVENT_SPAMBLOCK_TRACKBACKIPVALIDATION_DESC', 'Soll die IP des Senders bei Trackbacks/Pingbacks mit der IP des Hosts bereinstimmen, auf den der Kommentar gesetzt werden soll? (EMPFOHLEN!)');
 @define('PLUGIN_EVENT_SPAMBLOCK_REASON_IPVALIDATION', 'IP Validierung : %s [%s] != Sender IP [%s]');
 
-?>
+@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_DESC', 'Falls deaktiviert wird keine E-Mail-Prfung ausgefhrt. Falls auf "Ja" gesetzt wird eine E-Mail-Adresse auf syntaktische Korrektheit geprft. "Immer besttigen" bedeutet, dass ein Kommentator seine Kommentare jedesmal per E-Mail besttigen muss. "Einmal besttigen" heit, dass er beim ersten Kommentare seine Identitt besttigt, und danach immer ohne weitere Moderation kommentieren darf.');
+@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_ONCE', 'Einmal besttigen');
+@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_ALWAYS', 'Immer besttigen');
+@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_MAIL', 'Sie erhalten nun eine E-Mail-Benachrichtigung, mit der Sie ihren Kommentar freischalten knnen.');
+@define('PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_INFO', 'Um einen Kommentar hinterlassen zu knnen, erhalten Sie nach dem Kommentieren eine E-Mail mit Aktivierungslink an ihre angegebene Adresse.');
