@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_event_spamblock.php 1852 2007-08-14 18:43:00Z brockhaus $
+<?php # $Id: serendipity_event_spamblock.php 2424 2009-01-13 18:00:13Z garvinhicking $
 
 
 if (IN_serendipity !== true) {
@@ -39,7 +39,7 @@ var $filter_defaults;
             'smarty'      => '2.6.7',
             'php'         => '4.1.0'
         ));
-        $propbag->add('version',       '1.70');
+        $propbag->add('version',       '1.71');
         $propbag->add('event_hooks',    array(
             'frontend_saveComment' => true,
             'external_plugin'      => true,
@@ -157,10 +157,15 @@ var $filter_defaults;
                 break;
 
             case 'checkmail':
-                $propbag->add('type', 'boolean');
+                $propbag->add('type', 'radio');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL);
-                $propbag->add('description', '');
-                $propbag->add('default', false);
+                $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_DESC);
+                $propbag->add('default', 'false');
+                $propbag->add('radio', array(
+                    'value' => array('false', 'true', 'verify_once', 'verify_always'),
+                    'desc'  => array(NO, YES, PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_ONCE, PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_ALWAYS)
+                ));
+                $propbag->add('radio_per_row', '1');
                 break;
 
             case 'required_fields':
@@ -305,7 +310,7 @@ var $filter_defaults;
                 $propbag->add('type', 'radio');
                 $propbag->add('name', PLUGIN_EVENT_SPAMBLOCK_LOGTYPE);
                 $propbag->add('description', PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DESC);
-                $propbag->add('default', 'db');
+                $propbag->add('default', 'none');
                 $propbag->add('radio',         array(
                     'value' => array('file', 'db', 'none'),
                     'desc'  => array(PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_FILE, PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_DB, PLUGIN_EVENT_SPAMBLOCK_LOGTYPE_NONE)
@@ -409,7 +414,7 @@ var $filter_defaults;
         }
 
         $hta = $serendipity['serendipityPath'] . '.htaccess';
-        if (file_exists($hta) && is_writable($hta)) {
+        if (count($deny) > 0 && file_exists($hta) && is_writable($hta)) {
             $htaccess = file_get_contents($hta);
             $fp = @fopen($hta, 'w');
             if (!$fp) {
@@ -508,11 +513,11 @@ var $filter_defaults;
                 if (preg_match('@true@i', $reqdata)) {
                     $ret['is_spam'] = true;
                     $ret['message'] = $reqdata;
-                    $this->log($this->logfile, $eventData['id'], 'AKISMET_PASS', 'Passed Akismet verification', $addData);
+                    $this->log($this->logfile, $eventData['id'], 'AKISMET_SPAM', 'Akismet API returned spam', $addData);
                 } elseif (preg_match('@false@i', $reqdata)) {
                     $ret['is_spam'] = false;
                     $ret['message'] = $reqdata;
-                    $this->log($this->logfile, $eventData['id'], 'AKISMET_SPAM', 'Akismet API returned spam', $addData);
+                    $this->log($this->logfile, $eventData['id'], 'AKISMET_PASS', 'Passed Akismet verification', $addData);
                 } else {
                     $ret['is_spam'] = false;
                     $ret['message'] = 'Akismet API failure';
@@ -729,12 +734,19 @@ var $filter_defaults;
                     break;
 
                 case 'frontend_saveComment':
+                /*
+                    $fp = fopen('/tmp/spamblock2.log', 'a');
+                    fwrite($fp, date('Y-m-d H:i') . "\n" . print_r($eventData, true) . "\n" . print_r($addData, true) . "\n");
+                    fclose($fp);
+                */    
+                    
                     if (!is_array($eventData) || serendipity_db_bool($eventData['allow_comments'])) {
                         $this->checkScheme();
 
                         $serendipity['csuccess'] = 'true';
                         $logfile = $this->logfile = $this->get_config('logfile', $serendipity['serendipityPath'] . 'spamblock.log');
                         $required_fields = $this->get_config('required_fields', '');
+                        $checkmail = $this->get_config('checkmail');
 
                         // Check CSRF [comments only, cannot be applied to trackbacks]
                         if ($addData['type'] == 'NORMAL' && serendipity_db_bool($this->get_config('csrf', true))) {
@@ -758,7 +770,7 @@ var $filter_defaults;
                                 }
                             }
                         }
-
+                        
                         /*
                         if ($addData['type'] != 'NORMAL' && empty($addData['name'])) {
                             $eventData = array('allow_coments' => false);
@@ -772,6 +784,26 @@ var $filter_defaults;
                             return true;
                         }
 
+                        // Check if the user has verified himself via email already.
+                        if ($addData['type'] == 'NORMAL' && (string)$checkmail === 'verify_once') {
+                            $auth = serendipity_db_query("SELECT *
+                                                            FROM {$serendipity['dbPrefix']}options
+                                                           WHERE okey  = 'mail_confirm'
+                                                             AND name  = '" . serendipity_db_escape_string($addData['email']) . "'
+                                                             AND value = '" . serendipity_db_escape_string($addData['name']) . "'", true);
+                            if (!is_array($auth)) {
+                                $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_MAIL, $addData);
+                                $eventData['moderate_comments'] = true;
+                                $eventData['status']            = 'confirm1';
+                                $serendipity['csuccess']        = 'moderate';
+                                $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_MAIL;
+                                return false;
+                            } else {
+                                // User is allowed to post message, bypassing other checks as if he were logged in.
+                                return true;
+                            }
+                        }
+
                         // Check if entry title is the same as comment body
                         if (serendipity_db_bool($this->get_config('entrytitle')) && trim($eventData['title']) == trim($addData['comment'])) {
                             $this->log($logfile, $eventData['id'], 'REJECTED', PLUGIN_EVENT_SPAMBLOCK_REASON_TITLE, $addData);
@@ -1079,8 +1111,8 @@ var $filter_defaults;
                         }
 
                         // Check for identical comments. We allow to bypass trackbacks from our server to our own blog.
-                        if ( $this->get_config('bodyclone', true) === true && $_SERVER['REMOTE_ADDR'] != $_SERVER['SERVER_ADDR']) {
-                            $query = "SELECT count(id) AS counter FROM {$serendipity['dbPrefix']}comments WHERE body = '" . serendipity_db_escape_string($addData['comment']) . "'";
+                        if ( $this->get_config('bodyclone', true) === true && $_SERVER['REMOTE_ADDR'] != $_SERVER['SERVER_ADDR'] && $addData['type'] != 'PINGBACK') {
+                            $query = "SELECT count(id) AS counter FROM {$serendipity['dbPrefix']}comments WHERE type = '" . $addData['type'] . "' AND body = '" . serendipity_db_escape_string($addData['comment']) . "'";
                             $row   = serendipity_db_query($query, true);
                             if (is_array($row) && $row['counter'] > 0) {
                                 $this->IsHardcoreSpammer();
@@ -1103,6 +1135,15 @@ var $filter_defaults;
                             }
                         }
 
+                        if ($addData['type'] == 'NORMAL' && (string)$checkmail === 'verify_always') {
+                            $this->log($logfile, $eventData['id'], 'MODERATE', PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_MAIL, $addData);
+                            $eventData['moderate_comments'] = true;
+                            $eventData['status']            = 'confirm';
+                            $serendipity['csuccess']        = 'moderate';
+                            $serendipity['moderate_reason'] = PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_MAIL;
+                            return false;
+                        }
+
                         // Check invalid email
                         if ($addData['type'] == 'NORMAL' && serendipity_db_bool($this->get_config('checkmail', false))) {
                             if (!empty($addData['email']) && strstr($addData['email'], '@') === false) {
@@ -1125,6 +1166,10 @@ var $filter_defaults;
                     if (serendipity_db_bool($this->get_config('hide_email', false))) {
                         echo '<div class="serendipity_commentDirection serendipity_comment_spamblock">' . PLUGIN_EVENT_SPAMBLOCK_HIDE_EMAIL_NOTICE . '</div>';
                     }
+                    
+                    if ((string)$this->get_config('checkmail') === 'verify_always' || (string)$this->get_config('checkmail') === 'verify_once') {
+                        echo '<div class="serendipity_commentDirection serendipity_comment_spamblock">' . PLUGIN_EVENT_SPAMBLOCK_CHECKMAIL_VERIFICATION_INFO . '</div>';
+                    }
 
                     if (serendipity_db_bool($this->get_config('csrf', true))) {
                         echo serendipity_setFormToken('form');
