@@ -1,8 +1,9 @@
-<?php # $Id: lang_bg.inc.php 1795 2007-07-24 12:57:48Z garvinhicking $
+<?php # $Id: lang_bg.inc.php 2162 2008-03-07 06:36:23Z jwalker $
 
 /**
- *  @version $Revision: 1795 $
+ *  @version $Revision: 2162 $
  *  @author Ivan Cenov jwalker@hotmail.bg
+ *  EN-Revision: 2144
  */
 
     @define('PLUGIN_EVENT_STATISTICS_NAME', '');
@@ -87,6 +88,8 @@
     @define('PLUGIN_EVENT_STATISTICS_SHOW_ENTRYCOUNT', '    ');
     @define('PLUGIN_EVENT_STATISTICS_SHOW_COMMENTCOUNT', '    ');
     @define('PLUGIN_EVENT_STATISTICS_SHOW_MONTHVISITORS', '    ');
+    @define('PLUGIN_EVENT_STATISTICS_SHOW_DAYVISITORS', '   ');
+    @define('PLUGIN_EVENT_STATISTICS_SHOW_WEEKVISITORS', '    ');
     @define('PLUGIN_EVENT_STATISTICS_SHOW_CACHETIMEOUT', '  ');
     @define('PLUGIN_EVENT_STATISTICS_SHOW_CACHETIMEOUT_DESC', '         . -        ,        ,    .');
     @define('PLUGIN_EVENT_STATISTICS_TEXT', ' ');
@@ -95,6 +98,8 @@
     @define('PLUGIN_EVENT_STATISTICS_TEXT_ENTRYCOUNT', '  %s ');
     @define('PLUGIN_EVENT_STATISTICS_TEXT_COMMENTCOUNT', '  %s ');
     @define('PLUGIN_EVENT_STATISTICS_TEXT_MONTHVISITORS', '%s   ');
+    @define('PLUGIN_EVENT_STATISTICS_TEXT_DAYVISITORS', '%s () ');
+    @define('PLUGIN_EVENT_STATISTICS_TEXT_WEEKVISITORS', '%s ()  ');
 
     @define('PLUGIN_EVENT_STATISTICS_SHOW_CURRENTVISITORS', '      (    15 )');
     @define('PLUGIN_EVENT_STATISTICS_TEXT_CURRENTVISITORS', '%s  ');
