@@ -1,13 +1,13 @@
-<?php # $Id: lang_pl.inc.php 1609 2007-02-06 08:35:09Z garvinhicking $
+<?php # $Id: lang_pl.inc.php 2093 2008-01-18 12:50:00Z garvinhicking $
 
 /**
- *  @version $Revision: 1609 $
+ *  @version $Revision: 2093 $
  *  @author Kostas CoSTa Brzezinski <costa@kofeina.net>
  *  EN-Revision: Revision of lang_en.inc.php
  */
 
 @define('PLUGIN_EVENT_TEXTILE_NAME', 'Znacznik: Textile');
 @define('PLUGIN_EVENT_TEXTILE_DESC', 'Parsuj całą treść przez moduł konwertera Textile');
-@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', '<a href="http://www.textism.com/tools/textile/">Textile</a>-format dozwolony');
+@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', '<a href="%s">Textile</a>-format dozwolony');
 
 ?>
