@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_comments.php 2172 2008-03-17 08:58:32Z garvinhicking $
+<?php # $Id: serendipity_plugin_comments.php 2377 2008-11-19 19:45:25Z slothman $
 
 // Probe for a language include with constants. Still include defines later on, if some constants were missing
 $probelang = dirname(__FILE__) . '/' . $serendipity['charset'] . 'lang_' . $serendipity['lang'] . '.inc.php';
@@ -22,7 +22,7 @@ class serendipity_plugin_comments extends serendipity_plugin
         $propbag->add('description',   PLUGIN_COMMENTS_BLAHBLAH);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Garvin Hicking, Tadashi Jokagi, Judebert, G. Brockhaus');
-        $propbag->add('version',       '1.12');
+        $propbag->add('version',       '1.13');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -181,6 +181,10 @@ class serendipity_plugin_comments extends serendipity_plugin
                 $isTrackBack = $row['comment_type'] == 'TRACKBACK' || $row['comment_type'] == 'PINGBACK';
                 
                 if ($row['comment_url'] != '' && ( ($isTrackBack && ($showurls =='trackbacks' || $showurls =='all') || !$isTrackBack && ($showurls =='comments' || $showurls =='all')))) {
+                    if (substr($row['comment_url'], 0, 7) != 'http://' && 
+                        substr($row['comment_url'], 0, 8) != 'https://') {
+                        $row['comment_url'] = 'http://' . $row['comment_url']; 
+                    }    
                     $user = '<a class="highlight" href="' . htmlspecialchars(strip_tags($row['comment_url'])) . '" title="' . htmlspecialchars(strip_tags($row['comment_title'])) . '">' . htmlspecialchars(strip_tags($row['user'])) . '</a>';
                 } else {
                     $user = htmlspecialchars(strip_tags($row['user']));
@@ -222,13 +226,12 @@ class serendipity_plugin_comments extends serendipity_plugin
                 printf(
                   '<div class="plugin_comment_wrap">' . PLUGIN_COMMENTS_ABOUT . '</div>',
 
-                  '<span class="plugin_comment_author">' . $user . '</span>',
+                  '<div class="plugin_comment_subject"><span class="plugin_comment_author">' . $user . '</span>',
                   ' <a class="highlight" href="' . serendipity_archiveURL($row['entry_id'], $row['subject'], 'baseURL', true, array('timestamp' => $row['entrystamp'])) .'#c' . $row['comment_id'] . '" title="' . htmlspecialchars($row['subject']) . '">'
                       . htmlspecialchars($row['subject'])
-                      . '</a><br />' . "\n"
-                      . '<span class="plugin_comment_date">' . htmlspecialchars(serendipity_strftime($dateformat, $row['stamp'])) . '</span><br />' . "\n"
-                      . '<span class="plugin_comment_body">' . strip_tags($entry['comment'], '<br /><img><a>') . '</span>'
-                      . '<br /><br /><br />' . "\n\n"
+                      . '</a></div>' . "\n"
+                      . '<div class="plugin_comment_date">' . htmlspecialchars(serendipity_strftime($dateformat, $row['stamp'])) . '</div>' . "\n"
+                      . '<div class="plugin_comment_body">' . strip_tags($entry['comment'], '<br /><img><a>') . '</div>' . "\n\n"
                 );
             }
         }
