@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_history.php 1935 2007-09-17 09:06:08Z garvinhicking $
+<?php # $Id: serendipity_plugin_history.php 2420 2009-01-02 09:34:27Z yellowled $
 
 // Probe for a language include with constants. Still include defines later on, if some constants were missing
 $probelang = dirname(__FILE__) . '/' . $serendipity['charset'] . 'lang_' . $serendipity['lang'] . '.inc.php';
@@ -22,7 +22,7 @@ class serendipity_plugin_history extends serendipity_plugin
         $propbag->add('description',   PLUGIN_HISTORY_DESC);
         $propbag->add('stackable',     true);
         $propbag->add('author',        'Jannis Hermanns');
-        $propbag->add('version',       '1.4');
+        $propbag->add('version',       '1.5');
         $propbag->add('requirements',  array(
             'serendipity' => '0.8',
             'smarty'      => '2.6.7',
@@ -97,25 +97,22 @@ class serendipity_plugin_history extends serendipity_plugin
                 $propbag->add('default', 5);
             break;
             case 'full':
-                $propbag->add('type',         'select');
+                $propbag->add('type',         'boolean');
                 $propbag->add('name',         PLUGIN_HISTORY_SHOWFULL);
                 $propbag->add('description',  PLUGIN_HISTORY_SHOWFULL_DESC);
-                $propbag->add('select_values', array('false','true'));
-                $propbag->add('default',     'false');
+                $propbag->add('default',     false);
             break;
             case 'displaydate':
-                $propbag->add('type',         'select');
+                $propbag->add('type',         'boolean');
                 $propbag->add('name',         PLUGIN_HISTORY_DISPLAYDATE);
                 $propbag->add('description',  PLUGIN_HISTORY_DISPLAYDATE_DESC);
-                $propbag->add('select_values', array('false','true'));
-                $propbag->add('default',     'true');
+                $propbag->add('default',      true);
             break;
             case 'displayauthor':
-                $propbag->add('type',         'select');
+                $propbag->add('type',         'boolean');
                 $propbag->add('name',         PLUGIN_HISTORY_DISPLAYAUTHOR);
                 $propbag->add('description',  '');
-                $propbag->add('select_values', array('false','true'));
-                $propbag->add('default',     'false');
+                $propbag->add('default',      false);
             break;
             case 'dateformat':
                 $propbag->add('type', 'string');
@@ -142,7 +139,7 @@ class serendipity_plugin_history extends serendipity_plugin
         $specialage  = $this->get_config('specialage');
         $displaydate = $this->get_config('displaydate', 'true');
         $dateformat  = $this->get_config('dateformat');
-        $full        = ($this->get_config('full', 'false') != 'true') ? false : true;
+        $full        = serendipity_db_bool($this->get_config('full'));
         $displayauthor = serendipity_db_bool($this->get_config('displayauthor', false));
 
         if (!is_numeric($min_age) || $min_age < 0 || $specialage == 'year') {
@@ -171,7 +168,7 @@ class serendipity_plugin_history extends serendipity_plugin
         $e     = serendipity_fetchEntries(array(($mints-$max_age*86400),
                                             ($maxts-$min_age*86400)), $full, $max_entries);
         $serendipity['fetchLimit'] = $oldLim;
-        echo (empty($intro)) ? '' : "$intro<br />";
+        echo (empty($intro)) ? '' : '<div class="serendipity_history_intro">' . $intro . '</div>' . "\n";
 
         if (!is_array($e)) {
             return false;
@@ -190,13 +187,18 @@ class serendipity_plugin_history extends serendipity_plugin
             );
             $date   = ($displaydate=='0') ? '' : serendipity_strftime($dateformat,$e[$x]['timestamp']);
             $author = ($displayauthor) ? $e[$x]['author'] . ': ' : '';
+            echo '<div class="serendipity_history_info">';
+            if ($displayauthor)
+                { echo '<span class="serendipity_history_author">' . $author . '</span>'; }
+            if ($displaydate)
+                { echo '<span class="serendipity_history_date">' . $date . '</span>'; } 
             $t = ($maxlength==0 || strlen($e[$x]['title'])<=$maxlength) ?
                     $e[$x]['title'] :
                     (trim(serendipity_mb('substr', $e[$x]['title'], 0, $maxlength-3)).' [...]');
-            echo $author . $date . "<a href='$url' title='".str_replace("'", '`', htmlspecialchars($e[$x]['title']))."'>". htmlspecialchars($t) ."</a> " .
-                 strip_tags($e[$x]['body']) . '<br />';
+            echo "<a href=" . $url . " title='".str_replace("'", "`", htmlspecialchars($e[$x]['title']))."'>". htmlspecialchars($t) . "</a></div>";
+            echo '<div class="serendipity_history_body">' . strip_tags($e[$x]['body']) . '</div>';
         }
-        echo $outro;
+        echo (empty($outro)) ? '' : '<div class="serendipity_history_outro">' . $outro . '</div>';
     }
 }
 
