@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_plugin_recententries.php 2155 2008-03-02 15:23:01Z donchambers $
+<?php # $Id: serendipity_plugin_recententries.php 2229 2008-04-15 16:52:53Z yellowled $
 
 // Contributed by Christian Machmeier <cm@redsplash.de>
 // Randomizing contributed by Christian Brabandt <cb@256bit.org>
@@ -209,6 +209,7 @@ class serendipity_plugin_recententries extends serendipity_plugin {
         $entries = serendipity_db_query($entries_query);
 
         if (isset($entries) && is_array($entries)) {
+            echo '<dl>' . "\n";
             foreach ($entries as $k => $entry) {
                 $entryLink = serendipity_archiveURL(
                                $entry['id'],
@@ -221,12 +222,13 @@ class serendipity_plugin_recententries extends serendipity_plugin {
                 if (empty($entry['title'])) {
                     $entry['title'] = '#' . $entry['id'];
                 }
-                
-                echo '<a href="' . $entryLink . '" title="' . htmlspecialchars($entry['title']) . '">' . $entry['title'] . '</a><br />'
-                     . '<div class="serendipitySideBarDate">'
+
+                echo '<dt class="serendipity_recententries_entrylink"><a href="' . $entryLink . '" title="' . htmlspecialchars($entry['title']) . '">' . $entry['title'] . '</a></dt>' . "\n"
+                     . '<dd class="serendipity_recententries_entrydate serendipitySideBarDate">'
                      . htmlspecialchars(serendipity_strftime($dateformat, $entry['timestamp']))
-                     . '</div><br />';
+                     . '</dd>' . "\n";
             }
+            echo '</dl>' . "\n\n";
         }
     }
 }
