@@ -1,7 +1,7 @@
-<?php # $Id: lang_en.inc.php 1427 2006-09-14 08:45:13Z garvinhicking $
+<?php # $Id: lang_en.inc.php 2291 2008-06-30 10:10:10Z garvinhicking $
 
 /**
- *  @version $Revision: 1427 $
+ *  @version $Revision: 2291 $
  *  @author Translator Name <yourmail@example.com>
  *  EN-Revision: Revision of lang_en.inc.php
  */
@@ -33,4 +33,5 @@
 @define('PLUGIN_REMOTERSS_RSSESCAPE', 'Escape HTML output');
 @define('PLUGIN_REMOTERSS_RSSESCAPE_DESC', 'If enabled, HTML in RSS-feeds will be escaped and no XSS is possible. If this option is disabled, HTML in the feeds can be interpretated. This is a possible security issue, if the embedded feed is not yours!');
 
-?>
+@define('PLUGIN_REMOTERSS_TEMPLATE', 'Output Template to use for this feed');
+@define('PLUGIN_REMOTERSS_TEMPLATE_DESC', 'Here you can choose a template file inside the plugin\'s directory that is used to render the output of the feed in the sidebar. You can add custom template files to the plugin directory. If a template file with the same name is placed inside your own template directory, it will be used instead of the file supplied with the plugin. Selecting any template here other than the defualt one automatically enables Smarty templating.');
