@@ -1,4 +1,4 @@
-<?php # $Id: serendipity_admin.php 2231 2008-04-16 10:11:12Z garvinhicking $
+<?php # $Id: serendipity_admin.php 2387 2008-12-02 12:07:46Z garvinhicking $
 # Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
 # All rights reserved.  See LICENSE file for licensing details
 
@@ -215,6 +215,25 @@ if (!$use_installer && $is_logged_in) {
             echo LOGGEDOUT;
             break;
 
+        case 'integrity':
+            echo '<div class="serendipity_admin_title">' . INTEGRITY . '</div>';
+            $badsums = array();
+            if (!is_readable(S9Y_INCLUDE_PATH . 'checksums.inc.php')) {
+                echo '<span class="serendipityAdminMsgNote">' . CHECKSUMS_NOT_FOUND . '</span>';
+                break;
+            }
+            $badsums = serendipity_verifyFTPChecksums();
+            if (count($badsums) == 0) {
+                echo '<span class="serendipityAdminMsgSuccess">' . CHECKSUMS_PASS . '</span>';
+            } else {
+                echo '<ul>';
+                foreach ($badsums as $rpath => $calcsum) {
+                    echo '<li class="serendipityAdminMsgError">' . sprintf(CHECKSUM_FAILED, $rpath) . '</li>';
+                }
+                echo '</ul>';
+            }
+            break;
+
         default:
             include S9Y_INCLUDE_PATH . 'include/admin/overview.inc.php';
             break;
@@ -269,7 +288,7 @@ if (!$use_installer && !$_SESSION['no_smarty'] && serendipity_smarty_init()) {
         function SetCookie(name, value) {
             var today  = new Date();
             var expire = new Date();
-            expire.setTime(today.getTime() + (60*60*24*30));
+            expire.setTime(today.getTime() + (60*60*24*30*1000));
             document.cookie = 'serendipity[' + name + ']='+escape(value) + ';expires=' + expire.toGMTString();
         }
 
@@ -401,7 +420,7 @@ if ($use_installer) {
                         <li class="serendipitySideBarMenuLink serendipitySideBarMenuMediaLinks"><a href="serendipity_admin.php?serendipity[adminModule]=media&amp;serendipity[adminAction]=directorySelect"><?php echo MANAGE_DIRECTORIES; ?></a></li>
 <?php } ?>
 <?php if (serendipity_checkPermission('adminImagesSync')) { ?>
-                        <li class="serendipitySideBarMenuLink serendipitySideBarMenuMediaLinks"><a href="serendipity_admin.php?serendipity[adminModule]=media&amp;serendipity[adminAction]=sync" onclick="return confirm('<?php echo WARNING_THIS_BLAHBLAH; ?>');"><?php echo CREATE_THUMBS; ?></a></li>
+                        <li class="serendipitySideBarMenuLink serendipitySideBarMenuMediaLinks"><a href="serendipity_admin.php?serendipity[adminModule]=media&amp;serendipity[adminAction]=sync"><?php echo CREATE_THUMBS; ?></a></li>
 <?php } ?>
                         <?php if ($serendipity['no_create'] !== true) serendipity_plugin_api::hook_event('backend_sidebar_entries_images', $serendipity); ?>
                         <li class="serendipitySideBarMenuFoot serendipitySideBarMenuMediaLinks" style="display:none"></li>
@@ -435,6 +454,9 @@ if ($use_installer) {
 <?php if (serendipity_checkPermission('adminImport')) { ?>
                         <li class="serendipitySideBarMenuLink serendipitySideBarMenuUserManagementLinks"><a href="serendipity_admin.php?serendipity[adminModule]=import"><?php echo IMPORT_ENTRIES; ?></a></li>
                         <li class="serendipitySideBarMenuLink serendipitySideBarMenuUserManagementLinks"><a href="serendipity_admin.php?serendipity[adminModule]=export"><?php echo EXPORT_ENTRIES; ?></a></li>
+<?php } ?>
+<?php if (serendipity_checkPermission('siteConfiguration') || serendipity_checkPermission('blogConfiguration')) { ?>
+                        <li class="serendipitySideBarMenuLink serendipitySideBarMenuUserManagementLinks"><a href="serendipity_admin.php?serendipity[adminModule]=integrity"><?php echo INTEGRITY; ?></a></li>
 <?php } ?>
                         <?php if ($serendipity['no_create'] !== true) serendipity_plugin_api::hook_event('backend_sidebar_admin', $serendipity); ?>
                         <li class="serendipitySideBarMenuFoot serendipitySideBarMenuUserManagement" style="display:none"></li>
@@ -476,4 +498,4 @@ if ($use_installer) {
     </body>
 </html>
 <?php
-}
\ No newline at end of file
+}
