@@ -28,7 +28,7 @@ $template_config = array(
         'var'           => 'colorset',
         'name'          => THEME_COLORSET,
         'type'          => 'select',
-        'default'       => 'purple',
+        'default'       => 'default',
         'select_values' => $colorsets
     ),
     array(
@@ -205,7 +205,14 @@ $template_config = array(
         'default'       => 'text',
         'select_values' => array('text' => PREV_NEXT_TEXT,
                                  'texticon' => PREV_NEXT_TEXT_ICON,
-                                 'icon' => PREV_NEXT_ICON)
+                                 'icon' => PREV_NEXT_ICON,
+                                 'none' => NONE)
+    ),
+    array(
+        'var'           => 'show_pagination',
+        'name'          => SHOW_PAGINATION,
+        'type'          => 'boolean',
+        'default'       => 'false',
     ),
     array(
         'var'           => 'counter_code',
@@ -268,7 +275,7 @@ $template_config = array(
     )
 );
 
-$template_loaded_config = &serendipity_loadThemeOptions($template_config, $serendipity['smarty_vars']['template_option']);
+$template_loaded_config = serendipity_loadThemeOptions($template_config, $serendipity['smarty_vars']['template_option']);
 
 $navlinks = array();
 
@@ -291,6 +298,22 @@ for ($i = 0; $i < $template_loaded_config['amount']; $i++) {
     );
 }
 
+if ($template_loaded_config['headerimage'] != '' && is_dir($_SERVER['DOCUMENT_ROOT'] . '/' . $template_loaded_config['headerimage'])) {
+    $files = array();
+    if ($d = opendir($_SERVER['DOCUMENT_ROOT'] . '/' . $template_loaded_config['headerimage'])) {
+        while (($file = readdir($d)) !== false) {
+            if (preg_match('@(\.jpe?g|\.png|\.gif)$@i', $file) && !preg_match('@' . preg_quote($serendipity['thumbSuffix']) . '@i', $file)) {
+                $files[] = $file;
+            }
+        }
+    }
+    
+    if (count($files) > 0) {
+        shuffle($files);
+        $serendipity['smarty']->assign('random_headerimage', $template_loaded_config['headerimage'] . '/' . $files[0]);
+    }
+}
+
 $serendipity['smarty']->assign_by_ref('navlinks', $navlinks);
 
 // Allow colorset authors to include license and attribution data
